@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,31 +24,44 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_ID_MANAGER_H
 #define G_ID_MANAGER_H
 
-
 #include "core/types.h"
 
-
-namespace giada {
-namespace m 
+namespace giada::m
 {
 class IdManager
 {
 public:
-
 	IdManager();
-	
+
+	/* set
+	Stores a new id, only if != 0 (valid) and greater than current id (unique). */
+
 	void set(ID id);
-	ID   get(ID id=0);
+
+	/* generate
+	Generates a new unique id. If 'id' parameter is passed in is valid, it just 
+	returns it with no unique id generation. Useful when loading things from the 
+	model that already have their own id. */
+
+	ID generate(ID id = 0);
+
+	/* get
+	Returns the current id, a.k.a. the last generated one. */
+
+	ID get() const;
+
+	/* getNext
+	Returns the upcoming ID, that is the ID that will be generated on the next
+	call. */
+
+	ID getNext() const;
 
 private:
-
 	ID m_id;
 };
-}} // giada::m::
-
+} // namespace giada::m
 
 #endif
