@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,135 +24,126 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cassert>
-#include "const.h"
 #include "midiEvent.h"
+#include "const.h"
+#include "utils/math.h"
+#include <cassert>
 
-
-namespace giada {
+namespace giada
+{
 namespace m
 {
-MidiEvent::MidiEvent()
-	: m_status  (0),
-	  m_channel (0),
-	  m_note    (0),
-	  m_velocity(0),
-	  m_delta   (0)
+namespace
+{
+constexpr int FLOAT_FACTOR = 10000;
+} // namespace
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+MidiEvent::MidiEvent(uint32_t raw, int delta)
+: m_status((raw & 0xF0000000) >> 24)
+, m_channel((raw & 0x0F000000) >> 24)
+, m_note((raw & 0x00FF0000) >> 16)
+, m_velocity((raw & 0x0000FF00) >> 8)
+, m_delta(delta)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-MidiEvent::MidiEvent(uint32_t raw)
-	: m_status  ((raw & 0xF0000000) >> 24),
-	  m_channel ((raw & 0x0F000000) >> 24),
-	  m_note    ((raw & 0x00FF0000) >> 16),
-	  m_velocity((raw & 0x0000FF00) >> 8),
-	  m_delta   (0)  // not used
+/* static_cast to avoid ambiguity with MidiEvent(float). */
+MidiEvent::MidiEvent(int byte1, int byte2, int byte3, int delta)
+: MidiEvent(static_cast<uint32_t>((byte1 << 24) | (byte2 << 16) | (byte3 << 8) | (0x00)), delta)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-MidiEvent::MidiEvent(int byte1, int byte2, int byte3)
-	: MidiEvent((byte1 << 24) | (byte2 << 16) | (byte3 << 8) | (0x00))
+MidiEvent::MidiEvent(float v, int delta)
+: MidiEvent(ENVELOPE, 0, 0, delta)
 {
+	m_velocity = static_cast<int>(v * FLOAT_FACTOR);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void MidiEvent::setDelta(int d)
 {
 	m_delta = d;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void MidiEvent::setChannel(int c)
 {
 	assert(c >= 0 && c < G_MAX_MIDI_CHANS);
 	m_channel = c;
 }
 
-
 void MidiEvent::setVelocity(int v)
 {
 	assert(v >= 0 && v <= G_MAX_VELOCITY);
 	m_velocity = v;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void MidiEvent::fixVelocityZero()
 {
 	if (m_status == NOTE_ON && m_velocity == 0)
 		m_status = NOTE_OFF;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 int MidiEvent::getStatus() const
 {
 	return m_status;
-}	
-
+}
 
 int MidiEvent::getChannel() const
 {
 	return m_channel;
 }
 
-
 int MidiEvent::getNote() const
 {
 	return m_note;
-}	
-
+}
 
 int MidiEvent::getVelocity() const
 {
 	return m_velocity;
-}	
+}
 
+float MidiEvent::getVelocityFloat() const
+{
+	return m_velocity / static_cast<float>(FLOAT_FACTOR);
+}
 
 bool MidiEvent::isNoteOnOff() const
 {
 	return m_status == NOTE_ON || m_status == NOTE_OFF;
 }
 
-
 int MidiEvent::getDelta() const
 {
 	return m_delta;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 uint32_t MidiEvent::getRaw() const
 {
 	return (m_status << 24) | (m_channel << 24) | (m_note << 16) | (m_velocity << 8) | (0x00);
 }
 
-
 uint32_t MidiEvent::getRawNoVelocity() const
 {
 	return (m_status << 24) | (m_channel << 24) | (m_note << 16) | (0x00 << 8) | (0x00);
 }
 
-
-}} // giada::m::
+} // namespace m
+} // namespace giada
