@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,36 +24,44 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_MIDI_EVENT_H
 #define G_MIDI_EVENT_H
 
-
 #include <cstdint>
 
-
-namespace giada {
+namespace giada
+{
 namespace m
 {
 class MidiEvent
 {
 public:
-
 	static const int NOTE_ON   = 0x90;
 	static const int NOTE_OFF  = 0x80;
 	static const int NOTE_KILL = 0x70;
 	static const int ENVELOPE  = 0xB0;
 
-	MidiEvent();
-	MidiEvent(uint32_t raw);
-	MidiEvent(int byte1, int byte2, int byte3);
+	/* MidiEvent (1)
+	Creates and empty and invalid MIDI event. */
 
-	int getStatus() const;	
-	int getChannel() const;	
-	int getNote() const;	
-	int getVelocity() const;	
-	bool isNoteOnOff() const;	
-	int getDelta() const;
+	MidiEvent() = default;
+
+	MidiEvent(uint32_t raw, int delta = 0);
+	MidiEvent(int byte1, int byte2, int byte3, int delta = 0);
+
+	/* MidiEvent (4)
+	A constructor that takes a float parameter. Useful to build ENVELOPE events 
+	for automations, volume and pitch. */
+
+	MidiEvent(float v, int delta = 0);
+
+	int   getStatus() const;
+	int   getChannel() const;
+	int   getNote() const;
+	int   getVelocity() const;
+	float getVelocityFloat() const;
+	bool  isNoteOnOff() const;
+	int   getDelta() const;
 
 	/* getRaw(), getRawNoVelocity()
 	Returns the raw MIDI message. If getRawNoVelocity(), the velocity value is
@@ -76,14 +84,13 @@ public:
 	void fixVelocityZero();
 
 private:
-
 	int m_status;
 	int m_channel;
 	int m_note;
 	int m_velocity;
 	int m_delta;
 };
-}} // giada::m::
-
+} // namespace m
+} // namespace giada
 
 #endif
