@@ -24,28 +24,18 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_MODEL_STORAGE_H
 #define G_MODEL_STORAGE_H
 
+#include "core/patch.h"
+#include "core/conf.h"
 
-namespace giada {
-namespace m {
-namespace patch
+namespace giada::m::model
 {
-struct Patch;
-}
-namespace conf
-{
-struct Conf;
-}
-namespace model
-{
-void store(conf::Conf& c);
-void store(patch::Patch& p);
-void load(const patch::Patch& p);
-void load(const conf::Conf& c);
-}}} // giada::m::model::
-
+void store(Conf::Data& c);
+void store(Patch::Data& p);
+void load(const Patch::Data& p);
+void load(const Conf::Data& c);
+} // namespace giada::m::model
 
 #endif
