@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,37 +24,96 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_TYPES_H
 #define G_TYPES_H
 
-
 namespace giada
 {
 using ID    = int;
 using Pixel = int;
 using Frame = int;
 
-enum class ClockStatus { STOPPED, WAITING, RUNNING };
+enum class Thread
+{
+	MAIN,
+	MIDI,
+	AUDIO,
+	EVENTS
+};
 
-enum class ChannelType : int { SAMPLE = 1, MIDI, MASTER, PREVIEW };
+/* Windows fix */
+#ifdef _WIN32
+#undef VOID
+#endif
+enum class SeqStatus
+{
+	STOPPED,
+	WAITING,
+	RUNNING,
+	ON_BEAT,
+	ON_BAR,
+	ON_FIRST_BEAT,
+	VOID
+};
+
+enum class ChannelType : int
+{
+	SAMPLE = 1,
+	MIDI,
+	MASTER,
+	PREVIEW
+};
 
 enum class ChannelStatus : int
 {
-	ENDING = 1, WAIT, PLAY, OFF, EMPTY, MISSING, WRONG  
+	ENDING = 1,
+	WAIT,
+	PLAY,
+	OFF,
+	EMPTY,
+	MISSING,
+	WRONG
 };
 
-enum class ChannelMode : int
+enum class SamplePlayerMode : int
 {
-	LOOP_BASIC = 1, LOOP_ONCE, LOOP_REPEAT, LOOP_ONCE_BAR,
-	SINGLE_BASIC, SINGLE_PRESS, SINGLE_RETRIG, SINGLE_ENDLESS
+	LOOP_BASIC = 1,
+	LOOP_ONCE,
+	LOOP_REPEAT,
+	LOOP_ONCE_BAR,
+	SINGLE_BASIC,
+	SINGLE_PRESS,
+	SINGLE_RETRIG,
+	SINGLE_ENDLESS,
+	SINGLE_BASIC_PAUSE
 };
 
-enum class RecTriggerMode : int { NORMAL = 0, SIGNAL };
-
-enum class PreviewMode : int { NONE = 0, NORMAL, LOOP };
-enum class EventType : int { AUTO = 0, MANUAL };
+enum class RecTriggerMode : int
+{
+	NORMAL = 0,
+	SIGNAL
 };
 
+enum class InputRecMode : int
+{
+	RIGID = 0,
+	FREE
+};
+
+enum class EventType : int
+{
+	AUTO = 0,
+	MANUAL
+};
+
+/* Peak
+Audio peak information for two In/Out channels. */
+
+struct Peak
+{
+	float left;
+	float right;
+};
+} // namespace giada
 
 #endif
