@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,149 +24,101 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cassert>
-#include <cstring>  // memcpy
+#include "wave.h"
+#include "const.h"
 #include "utils/fs.h"
 #include "utils/log.h"
 #include "utils/string.h"
-#include "const.h"
-#include "wave.h"
+#include <cassert>
 
-
-namespace giada {
-namespace m 
+namespace giada::m
 {
 Wave::Wave(ID id)
-: id       (id),
-  m_rate   (0),
-  m_bits   (0),
-  m_logical(false),
-  m_edited (false) 
+: id(id)
+, m_rate(0)
+, m_bits(0)
+, m_logical(false)
+, m_edited(false)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-float* Wave::operator [](int offset) const
-{
-	return buffer[offset];
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 Wave::Wave(const Wave& other)
-: id        (other.id), 
-  m_rate    (other.m_rate),
-  m_bits    (other.m_bits),	
-  m_logical (false),
-  m_edited  (false),
-  m_path    (other.m_path)
+: id(other.id)
+, m_buffer(other.getBuffer())
+, m_rate(other.m_rate)
+, m_bits(other.m_bits)
+, m_logical(false)
+, m_edited(false)
+, m_path(other.m_path)
 {
-	buffer.alloc(other.getSize(), other.getChannels());
-	buffer.copyData(other.getFrame(0), other.getSize());
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void Wave::alloc(int size, int channels, int rate, int bits, const std::string& path)
+void Wave::alloc(Frame size, int channels, int rate, int bits, const std::string& path)
 {
-	buffer.alloc(size, channels);
+	m_buffer.alloc(size, channels);
 	m_rate = rate;
 	m_bits = bits;
 	m_path = path;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 std::string Wave::getBasename(bool ext) const
 {
 	return ext ? u::fs::basename(m_path) : u::fs::stripExt(u::fs::basename(m_path));
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-int Wave::getRate() const { return m_rate; }
-int Wave::getChannels() const { return buffer.countChannels(); }
+int         Wave::getRate() const { return m_rate; }
 std::string Wave::getPath() const { return m_path; }
-int Wave::getSize() const { return buffer.countFrames(); }
-int Wave::getBits() const { return m_bits; }
-bool Wave::isLogical() const { return m_logical; }
-bool Wave::isEdited() const { return m_edited; }
-
+int         Wave::getBits() const { return m_bits; }
+bool        Wave::isLogical() const { return m_logical; }
+bool        Wave::isEdited() const { return m_edited; }
 
 /* -------------------------------------------------------------------------- */
 
+mcl::AudioBuffer&       Wave::getBuffer() { return m_buffer; }
+const mcl::AudioBuffer& Wave::getBuffer() const { return m_buffer; }
+
+/* -------------------------------------------------------------------------- */
 
 int Wave::getDuration() const
 {
-	return buffer.countFrames() / m_rate;
+	return m_buffer.countFrames() / m_rate;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 std::string Wave::getExtension() const
 {
 	return u::fs::getExt(m_path);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-float* Wave::getFrame(int f) const
-{
-	return buffer[f];
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void Wave::setRate(int v)     { m_rate = v; }
+void Wave::setRate(int v) { m_rate = v; }
 void Wave::setLogical(bool l) { m_logical = l; }
-void Wave::setEdited(bool e)  { m_edited = e; }
-
+void Wave::setEdited(bool e) { m_edited = e; }
 
 /* -------------------------------------------------------------------------- */
 
-
-void Wave::setPath(const std::string& p, int id) 
-{ 
-	if (id == -1)
-		m_path = p; 
-	else 
-		m_path = u::fs::stripExt(p) + "-" + std::to_string(id) + "." + u::fs::getExt(p);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void Wave::copyData(const float* data, int frames, int offset)
+void Wave::setPath(const std::string& p, int wid)
 {
-	buffer.copyData(data, frames, offset);
+	if (wid == -1)
+		m_path = p;
+	else
+		m_path = u::fs::stripExt(p) + "-" + std::to_string(wid) + u::fs::getExt(p);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void Wave::moveData(AudioBuffer& b)
+void Wave::replaceData(mcl::AudioBuffer&& b)
 {
-	buffer.moveData(b);
+	m_buffer = std::move(b);
 }
-
-}}; // giada::m::
+} // namespace giada::m
