@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,80 +24,66 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_WAVE_H
 #define G_WAVE_H
 
-
-#include <string>
-#include "core/audioBuffer.h"
 #include "core/types.h"
+#include "deps/mcl-audio-buffer/src/audioBuffer.hpp"
+#include <string>
 
-
-namespace giada {
-namespace m 
+namespace giada::m
 {
 class Wave
 {
 public:
-
 	Wave(ID id);
-	Wave(const Wave& other);
+	Wave(const Wave& o);
+	Wave(Wave&& o) = default;
 
-	float* operator [](int offset) const;
+	Wave& operator=(Wave&& o) = default;
 
-	/* getFrame
-	Works like operator []. See AudioBuffer for reference. */
-	
-	float* getFrame(int f) const;
-	
-	std::string getBasename(bool ext=false) const;
+	std::string getBasename(bool ext = false) const;
 	std::string getExtension() const;
-	int getRate() const;
-	int getChannels() const;
-	std::string getPath() const;	
-	int getBits() const;
-	int getSize() const;        // in frames
-	int getDuration() const;
-	bool isLogical() const;
-	bool isEdited() const;
+	int         getRate() const;
+	std::string getPath() const;
+	int         getBits() const;
+	int         getDuration() const;
+	bool        isLogical() const;
+	bool        isEdited() const;
+
+	/* getBuffer
+	Returns a (non-)const reference to the underlying audio buffer. */
+
+	mcl::AudioBuffer&       getBuffer();
+	const mcl::AudioBuffer& getBuffer() const;
 
 	/* setPath
 	Sets new path 'p'. If 'id' != -1 inserts a numeric id next to the file 
 	extension, e.g. : /path/to/sample-[id].wav */
 
-	void setPath(const std::string& p, int id=-1);
+	void setPath(const std::string& p, int id = -1);
 
 	void setRate(int v);
 	void setLogical(bool l);
 	void setEdited(bool e);
 
-	/* moveData
-	Moves data held by 'b' into this buffer. Then 'b' becomes an empty buffer. */
+	/* replaceData
+	Replaces internal audio buffer with 'b' by moving it. */
 
-	void moveData(AudioBuffer& b); 
-	
-	/* copyData
-	Copies 'frames' frames from the new 'data' into m_data, starting from frame 
-	'offset'. It takes for granted that the new data contains the same number of 
-	channels than m_channels. */
+	void replaceData(mcl::AudioBuffer&& b);
 
-	void copyData(const float* data, int frames, int offset=0);
-
-	void alloc(int size, int channels, int rate, int bits, const std::string& path);
+	void alloc(Frame size, int channels, int rate, int bits, const std::string& path);
 
 	ID id;
 
 private:
-
-	AudioBuffer buffer;
-	int m_rate;
-	int m_bits;
-	bool m_logical;     // memory only (a take)
-	bool m_edited;      // edited via editor
-	std::string m_path; // E.g. /path/to/my/sample.wav
+	mcl::AudioBuffer m_buffer;
+	int              m_rate;
+	int              m_bits;
+	bool             m_logical; // memory only (a take)
+	bool             m_edited;  // edited via editor
+	std::string      m_path;    // E.g. /path/to/my/sample.wav
 };
-}}; // giada::m::
-
+} // namespace giada::m
 
 #endif
