@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,49 +24,73 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_GLUE_ACTION_EDITOR_H
 #define G_GLUE_ACTION_EDITOR_H
 
-
-#include <vector>
 #include "core/types.h"
+#include <optional>
+#include <string>
+#include <vector>
 
-
-namespace giada {
-namespace m
+namespace giada::m
 {
 struct Action;
-class SampleChannel;
-class MidiChannel;
-}
-namespace c {
-namespace actionEditor 
+class SamplePlayer;
+class Channel;
+} // namespace giada::m
+
+namespace giada::c::actionEditor
 {
-std::vector<m::Action> getActions(ID channelId);
+struct SampleData
+{
+	SampleData(const m::SamplePlayer&);
+
+	SamplePlayerMode channelMode;
+	bool             isLoopMode;
+};
+
+struct Data
+{
+	Data() = default;
+	Data(const m::Channel&);
+
+	Frame getCurrentFrame() const;
+	bool  isChannelPlaying() const;
+
+	ID                     channelId;
+	std::string            channelName;
+	Frame                  framesInSeq;
+	Frame                  framesInBeat;
+	Frame                  framesInBar;
+	Frame                  framesInLoop;
+	std::vector<m::Action> actions;
+
+	std::optional<SampleData> sample;
+};
+
+Data getData(ID channelId);
 
 /* MIDI actions.  */
 
-void recordMidiAction(ID channelId, int note, int velocity, Frame f1, 
-	Frame f2=0);
+void recordMidiAction(ID channelId, int note, int velocity, Frame f1,
+    Frame f2 = 0);
 void deleteMidiAction(ID channelId, const m::Action& a);
-void updateMidiAction(ID channelId, const m::Action& a, int note, int velocity, 
-	Frame f1, Frame f2);
+void updateMidiAction(ID channelId, const m::Action& a, int note, int velocity,
+    Frame f1, Frame f2);
 void updateVelocity(const m::Action& a, int value);
 
 /* Sample Actions. */
 
-void recordSampleAction(ID channelId, int type, Frame f1, Frame f2=0);
+void recordSampleAction(ID channelId, int type, Frame f1, Frame f2 = 0);
 void deleteSampleAction(ID channelId, const m::Action& a);
-void updateSampleAction(ID channelId, const m::Action& a, int type, 
-    Frame f1, Frame f2=0);
+void updateSampleAction(ID channelId, const m::Action& a, int type,
+    Frame f1, Frame f2 = 0);
 
 /* Envelope actions (only volume for now). */
 
 void recordEnvelopeAction(ID channelId, Frame f, int value);
 void deleteEnvelopeAction(ID channelId, const m::Action& a);
 void updateEnvelopeAction(ID channelId, const m::Action& a, Frame f, int value);
-}}}; // giada::c::actionEditor::
-
+} // namespace giada::c::actionEditor
 
 #endif
