@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,82 +24,69 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cassert>
+#include "glue/recorder.h"
+#include "core/actions/actionRecorder.h"
+#include "core/channels/channel.h"
+#include "core/const.h"
+#include "core/engine.h"
+#include "core/kernelMidi.h"
+#include "core/mixer.h"
+#include "core/model/model.h"
 #include "gui/dialogs/warnings.h"
 #include "gui/elems/mainWindow/keyboard/channel.h"
 #include "gui/elems/mainWindow/keyboard/sampleChannel.h"
-#include "core/channels/channel.h"
-#include "core/channels/sampleChannel.h"
-#include "core/channels/midiChannel.h"
-#include "core/const.h"
-#include "core/clock.h"
-#include "core/model/model.h"
-#include "core/kernelMidi.h"
-#include "core/recorderHandler.h"
-#include "core/recorder.h"
-#include "core/action.h"
-#include "core/mixer.h"
+#include "gui/ui.h"
+#include "src/core/actions/action.h"
+#include "src/core/actions/actionRecorder.h"
+#include "src/core/actions/actions.h"
 #include "utils/gui.h"
 #include "utils/log.h"
-#include "recorder.h"
+#include <cassert>
 
+extern giada::m::Engine g_engine;
+extern giada::v::Ui     g_ui;
 
-namespace giada {
-namespace c {
-namespace recorder 
+namespace giada::c::recorder
 {
 void clearAllActions(ID channelId)
 {
 	if (!v::gdConfirmWin("Warning", "Clear all actions: are you sure?"))
 		return;
-	m::recorder::clearChannel(channelId);
+	g_engine.actionRecorder.clearChannel(channelId);
 	updateChannel(channelId, /*updateActionEditor=*/true);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void clearVolumeActions(ID channelId)
 {
 	if (!v::gdConfirmWin("Warning", "Clear all volume actions: are you sure?"))
 		return;
-	m::recorder::clearActions(channelId, m::MidiEvent::ENVELOPE);
+	g_engine.actionRecorder.clearActions(channelId, m::MidiEvent::ENVELOPE);
 	updateChannel(channelId, /*updateActionEditor=*/true);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void clearStartStopActions(ID channelId)
 {
 	if (!v::gdConfirmWin("Warning", "Clear all start/stop actions: are you sure?"))
 		return;
-	m::recorder::clearActions(channelId, m::MidiEvent::NOTE_ON);
-	m::recorder::clearActions(channelId, m::MidiEvent::NOTE_OFF);
-	m::recorder::clearActions(channelId, m::MidiEvent::NOTE_KILL);
+	g_engine.actionRecorder.clearActions(channelId, m::MidiEvent::NOTE_ON);
+	g_engine.actionRecorder.clearActions(channelId, m::MidiEvent::NOTE_OFF);
+	g_engine.actionRecorder.clearActions(channelId, m::MidiEvent::NOTE_KILL);
 	updateChannel(channelId, /*updateActionEditor=*/true);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void updateChannel(ID channelId, bool updateActionEditor)
 {
-	/* TODO - optimization needed. This functions swaps a channel only to set a 
-	boolean flag. Query the channel first and swap it only if the flag has
-	actually changed. */
+	/* TODO - move somewhere else in the core area */
+	g_engine.model.get().getChannel(channelId).hasActions = g_engine.actionRecorder.hasActions(channelId);
+	g_engine.model.swap(m::model::SwapType::HARD);
 
-	m::model::onSwap(m::model::channels, channelId, [&](m::Channel& c)
-	{
-		c.hasActions = m::recorder::hasActions(channelId);
-	});
-				
 	if (updateActionEditor)
-		u::gui::refreshActionEditor();
+		g_ui.refreshSubWindow(WID_ACTION_EDITOR);
 }
-
-}}} // giada::c::recorder::
+} // namespace giada::c::recorder
