@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,19 +24,15 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_GLUE_STORAGE_H
 #define G_GLUE_STORAGE_H
 
-
-namespace giada {
-namespace c {
-namespace storage
+namespace giada::c::storage
 {
 void loadProject(void* data);
 void saveProject(void* data);
-void saveSample (void* data);
-void loadSample (void* data);
-}}} // giada::c::storage::
+void saveSample(void* data);
+void loadSample(void* data);
+} // namespace giada::c::storage
 
 #endif
