@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,24 +24,21 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <FL/Fl_Pixmap.H>
-#include <FL/fl_draw.H>
 #include "core/conf.h"
 #include "core/const.h"
 #include "core/graphics.h"
+#include <FL/Fl_Pixmap.H>
+#include <FL/fl_draw.H>
 #ifdef WITH_VST
 #include "deps/juce-config.h"
 #endif
+#include "about.h"
+#include "gui/elems/basics/box.h"
+#include "gui/elems/basics/button.h"
 #include "utils/gui.h"
 #include "utils/string.h"
-#include "gui/elems/basics/button.h"
-#include "gui/elems/basics/box.h"
-#include "about.h"
 
-
-namespace giada {
-namespace v 
+namespace giada::v
 {
 gdAbout::gdAbout()
 #ifdef WITH_VST
@@ -49,59 +46,58 @@ gdAbout::gdAbout()
 #else
 : gdWindow(340, 330, "About Giada")
 #endif
+, logo(8, 20, 324, 86)
+, text(8, 120, 324, 140)
+, close(252, h() - 28, 80, 20, "Close")
+#ifdef WITH_VST
+, vstText(8, 315, 324, 46)
+, vstLogo(8, 265, 324, 50)
+#endif
 {
+	end();
 	set_modal();
 
-	logo  = new geBox(8, 20, 324, 86);
-	text  = new geBox(8, 120, 324, 140);
-	close = new geButton(252, h()-28, 80, 20, "Close");
-#ifdef WITH_VST
-	vstLogo = new geBox(8, 265, 324, 50);
-	vstText = new geBox(8, 315, 324, 46);
+	std::string version = G_VERSION_STR;
+#ifdef G_DEBUG_MODE
+	version += " (debug build)";
 #endif
-	end();
 
-	logo->image(new Fl_Pixmap(giada_logo_xpm));
-	text->align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE | FL_ALIGN_TOP);
-	text->copy_label(std::string(
-		"Version " + std::string(G_VERSION_STR) + " (" BUILD_DATE ")\n\n"
-		"Developed by Monocasual Laboratories\n\n"
-		"Released under the terms of the GNU General\n"
-		"Public License (GPL v3)\n\n"
-		"News, infos, contacts and documentation:\n"
-		"www.giadamusic.com").c_str());
+	logo.image(new Fl_Pixmap(giada_logo_xpm));
+	text.align(FL_ALIGN_CENTER | FL_ALIGN_INSIDE | FL_ALIGN_TOP);
+	text.copy_label(std::string(
+	    "Version " + version + " (" BUILD_DATE ")\n\n"
+	                           "Developed by Monocasual Laboratories\n\n"
+	                           "Released under the terms of the GNU General\n"
+	                           "Public License (GPL v3)\n\n"
+	                           "News, infos, contacts and documentation:\n"
+	                           "www.giadamusic.com")
+	                    .c_str());
 
 #ifdef WITH_VST
 
-	vstLogo->image(new Fl_Pixmap(vstLogo_xpm));
-	vstLogo->position(vstLogo->x(), text->y() + text->h() + 8);
-	vstText->label(
-		"VST Plug-In Technology by Steinberg\n"
-		"VST is a trademark of Steinberg\nMedia Technologies GmbH"
-	);
-	vstText->position(vstText->x(), vstLogo->y()+vstLogo->h());
+	vstLogo.image(new Fl_Pixmap(vstLogo_xpm));
+	vstLogo.position(vstLogo.x(), text.y() + text.h() + 8);
+	vstText.label(
+	    "VST Plug-In Technology by Steinberg\n"
+	    "VST is a trademark of Steinberg\nMedia Technologies GmbH");
+	vstText.position(vstText.x(), vstLogo.y() + vstLogo.h());
 
 #endif
 
-	close->callback(cb_close, (void*)this);
+	close.callback(cb_close, (void*)this);
 	u::gui::setFavicon(this);
 	setId(WID_ABOUT);
 	show();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdAbout::cb_close(Fl_Widget* w, void* p) { ((gdAbout*)p)->cb_close(); }
-
+void gdAbout::cb_close(Fl_Widget* /*w*/, void* p) { ((gdAbout*)p)->cb_close(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void gdAbout::cb_close()
 {
 	do_callback();
 }
-
-}} // giada::v::
\ No newline at end of file
+} // namespace giada::v
\ No newline at end of file
