@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,83 +24,90 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_BASE_ACTION_EDITOR_H
 #define GD_BASE_ACTION_EDITOR_H
 
-
-#include "core/types.h"
+#include "core/conf.h"
+#include "glue/actionEditor.h"
 #include "gui/dialogs/window.h"
+#include "gui/elems/actionEditor/gridTool.h"
+#include "gui/elems/actionEditor/splitScroll.h"
+#include "gui/elems/basics/button.h"
+#include "gui/elems/basics/pack.h"
 
-
-class geChoice;
-class geButton;
-class geScroll;
-
-
-namespace giada {
-namespace m
+namespace giada::m
 {
 class Channel;
 struct Action;
-}
-namespace v
+} // namespace giada::m
+
+namespace giada::v
 {
-class geGridTool;
-
-
 class gdBaseActionEditor : public gdWindow
 {
 public:
-
 	virtual ~gdBaseActionEditor();
 
-	int handle(int e) override;
+	int  handle(int e) override;
+	void draw() override;
 
 	Pixel frameToPixel(Frame f) const;
-	Frame pixelToFrame(Pixel p, bool snap=true) const;
-	int getActionType() const;
-	std::vector<m::Action> getActions() const;
-
-	geChoice*   actionType;
-	geGridTool* gridTool;
-	geButton*   zoomInBtn;
-	geButton*   zoomOutBtn;
-	geScroll*   viewport;       // widget container
+	Frame pixelToFrame(Pixel p, bool snap = true) const;
 
 	ID channelId;
 
-	float ratio;
-	Pixel fullWidth;     // Full widgets width, i.e. scaled-down full sequencer
-	Pixel loopWidth; 	 // Loop width, i.e. scaled-down sequencer range
+	geGridTool gridTool;
+	geButton   zoomInBtn;
+	geButton   zoomOutBtn;
+
+	Pixel fullWidth; // Full widgets width, i.e. scaled-down full sequencer
+	Pixel loopWidth; // Loop width, i.e. scaled-down sequencer range
 
 protected:
+	static constexpr float MIN_RATIO  = 25.0f;
+	static constexpr float MAX_RATIO  = 40000.0f;
+	static constexpr float RATIO_STEP = 1.5f;
 
-	static constexpr Pixel RESIZER_BAR_H = 20;
-	static constexpr Pixel MIN_WIDGET_H  = 10;
-	static constexpr float MIN_RATIO     = 25.0f;
-	static constexpr float MAX_RATIO     = 40000.0f;
+	gdBaseActionEditor(ID channelId, m::Conf::Data&, Frame framesInBeat);
 
-	std::vector<m::Action> m_actions;
+	/* getMouseOverContent
+	Returns mouse x-position relative to the viewport content. */
 
-	gdBaseActionEditor(ID channelId);
+	int getMouseOverContent() const;
 
-	void zoomIn();
-	void zoomOut();
 	static void cb_zoomIn(Fl_Widget* w, void* p);
 	static void cb_zoomOut(Fl_Widget* w, void* p);
-	
+	void        zoomIn();
+	void        zoomOut();
+
 	/* computeWidth
 	Computes total width, in pixel. */
 
-	void computeWidth();
+	void computeWidth(Frame framesInSeq, Frame framesInLoop);
 
-	void centerViewportIn();
-	void centerViewportOut();
+	/* prepareWindow
+	Initializes window (favicon, limits, ...). */
 
 	void prepareWindow();
+
+	gePack        m_barTop;
+	geSplitScroll m_splitScroll;
+
+	c::actionEditor::Data m_data;
+	m::Conf::Data&        m_conf;
+
+private:
+	void refresh() override;
+
+	/* zoomAbout
+	Zooms and centers the viewport around the mouse cursor. Wants a function to 
+	apply to the current ratio. */
+
+	void zoomAbout(std::function<float()> f);
+
+	Pixel currentFrameToPixel() const;
+
+	float m_ratio;
 };
-}} // giada::v::
-
-
+} // namespace giada::v
 #endif
