@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,40 +24,29 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_MIDI_ACTION_EDITOR_H
 #define GD_MIDI_ACTION_EDITOR_H
 
-
 #include "baseActionEditor.h"
+#include "gui/elems/actionEditor/pianoRoll.h"
+#include "gui/elems/actionEditor/velocityEditor.h"
+#include "gui/elems/basics/box.h"
 
-
-class geResizerBar;
-
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-class geNoteEditor;
-class geVelocityEditor;
-
 class gdMidiActionEditor : public gdBaseActionEditor
 {
 public:
+	gdMidiActionEditor(ID channelId, m::Conf::Data&, Frame framesInBeat);
+	~gdMidiActionEditor();
 
-    gdMidiActionEditor(ID channelId);
-
-    void rebuild() override;
+	void rebuild() override;
 
 private:
-
-    geNoteEditor*     m_ne;
-	geResizerBar*     m_ner;
-
-	geVelocityEditor* m_ve;
-    geResizerBar*     m_ver;
+	geBox            m_barPadding;
+	gePianoRoll      m_pianoRoll;
+	geVelocityEditor m_velocityEditor;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
