@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,42 +24,35 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_SAMPLE_ACTION_EDITOR_H
 #define GD_SAMPLE_ACTION_EDITOR_H
 
-
 #include "baseActionEditor.h"
+#include "gui/elems/actionEditor/envelopeEditor.h"
+#include "gui/elems/actionEditor/sampleActionEditor.h"
+#include "gui/elems/basics/box.h"
+#include "gui/elems/basics/choice.h"
 
-
-class geResizerBar;
-
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-class geSampleActionEditor;
-class geEnvelopeEditor;
-
 class gdSampleActionEditor : public gdBaseActionEditor
-{  
+{
 public:
+	gdSampleActionEditor(ID channelId, m::Conf::Data&, Frame framesInBeat);
+	~gdSampleActionEditor();
 
-    gdSampleActionEditor(ID channelId);
+	void rebuild() override;
 
-    void rebuild() override;
+	int getActionType() const;
 
 private:
-
-	geSampleActionEditor* m_ae;
-    geResizerBar*         m_aer;
-
-	geEnvelopeEditor*     m_ee;
-    geResizerBar*         m_eer;
-
 	bool canChangeActionType();
-};
-}} // giada::v::
 
+	geBox                m_barPadding;
+	geSampleActionEditor m_sampleActionEditor;
+	geEnvelopeEditor     m_envelopeEditor;
+	geChoice             m_actionType;
+};
+} // namespace giada::v
 
 #endif
