@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,48 +24,41 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cstring>
+#include "bpmInput.h"
 #include "core/conf.h"
 #include "core/const.h"
 #include "core/mixer.h"
-#include "core/clock.h"
 #include "glue/main.h"
-#include "utils/gui.h"
-#include "utils/string.h"
 #include "gui/elems/basics/button.h"
 #include "gui/elems/basics/input.h"
-#include "bpmInput.h"
 #include "mainWindow.h"
-
+#include "utils/gui.h"
+#include "utils/string.h"
+#include <cstring>
 
 extern giada::v::gdMainWindow* mainWin;
 
-
-namespace giada {
-namespace v 
+namespace giada::v
 {
 gdBpmInput::gdBpmInput(const char* label)
 : gdWindow(u::gui::centerWindowX(144), u::gui::centerWindowY(36), 144, 36, "Bpm")
 {
 	set_modal();
 
-	input_a = new geInput(8,  8, 30, G_GUI_UNIT);
+	input_a = new geInput(8, 8, 30, G_GUI_UNIT);
 	input_b = new geInput(42, 8, 20, G_GUI_UNIT);
-	ok 		= new geButton(66, 8, 70, G_GUI_UNIT, "Ok");
+	ok      = new geButton(66, 8, 70, G_GUI_UNIT, "Ok");
 	end();
 
+	std::vector<std::string> parts = u::string::split(label, ".");
+
 	input_a->maximum_size(3);
 	input_a->type(FL_INT_INPUT);
-	input_a->value(u::string::fToString(m::clock::getBpm(), 0).c_str());
+	input_a->value(parts[0].c_str());
 
-	/* Use the decimal value from the string label. */
-
-	std::vector<std::string> tokens = u::string::split(label, ".");
-	
 	input_b->maximum_size(1);
 	input_b->type(FL_INT_INPUT);
-	input_b->value(tokens[1].c_str());
+	input_b->value(parts[1].c_str());
 
 	ok->shortcut(FL_Enter);
 	ok->callback(cb_update, (void*)this);
@@ -75,16 +68,12 @@ gdBpmInput::gdBpmInput(const char* label)
 	show();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdBpmInput::cb_update(Fl_Widget* w, void* p) { ((gdBpmInput*)p)->cb_update(); }
-
+void gdBpmInput::cb_update(Fl_Widget* /*w*/, void* p) { ((gdBpmInput*)p)->cb_update(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void gdBpmInput::cb_update()
 {
 	if (strcmp(input_a->value(), "") == 0)
@@ -92,6 +81,4 @@ void gdBpmInput::cb_update()
 	c::main::setBpm(input_a->value(), input_b->value());
 	do_callback();
 }
-
-
-}} // giada::v::
\ No newline at end of file
+} // namespace giada::v
\ No newline at end of file
