@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,37 +24,29 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_BPMINPUT_H
 #define GD_BPMINPUT_H
 
-
 #include "window.h"
 
-
 class geInput;
 class geButton;
 
-
-namespace giada {
-namespace v 
+namespace giada::v
 {
 class gdBpmInput : public gdWindow
 {
 public:
-
 	gdBpmInput(const char* label); // pointer to mainWin->timing->bpm->label()
 
 private:
+	static void cb_update(Fl_Widget* /*w*/, void* p);
+	void        cb_update();
 
-    static void cb_update(Fl_Widget* w, void* p);
-    void cb_update();
-
-    geInput* input_a;
-    geInput* input_b;
-    geButton* ok;
+	geInput*  input_a;
+	geInput*  input_b;
+	geButton* ok;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
