@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,65 +24,61 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "core/graphics.h"
+#include "gui/dialogs/browser/browserBase.h"
 #include "core/conf.h"
 #include "core/const.h"
-#include "utils/gui.h"
-#include "utils/fs.h"
-#include "gui/elems/browser.h"
+#include "core/graphics.h"
+#include "gui/elems/basics/box.h"
 #include "gui/elems/basics/button.h"
+#include "gui/elems/basics/check.h"
 #include "gui/elems/basics/input.h"
 #include "gui/elems/basics/progress.h"
-#include "gui/elems/basics/check.h"
-#include "browserBase.h"
+#include "gui/elems/browser.h"
+#include "utils/fs.h"
+#include "utils/gui.h"
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-gdBrowserBase::gdBrowserBase(const std::string& title, const std::string& path, 
-	std::function<void(void*)> callback, ID channelId)
-: gdWindow   (m::conf::conf.browserX, m::conf::conf.browserY, m::conf::conf.browserW, 
-	          m::conf::conf.browserH, title.c_str()),
-  m_callback (callback),
-  m_channelId(channelId)
+gdBrowserBase::gdBrowserBase(const std::string& title, const std::string& path,
+    std::function<void(void*)> callback, ID channelId, m::Conf::Data& c)
+: gdWindow(c.browserX, c.browserY, c.browserW,
+      c.browserH, title.c_str())
+, m_callback(callback)
+, m_conf(c)
+, m_channelId(channelId)
 {
 	set_non_modal();
 
-	groupTop = new Fl_Group(8, 8, w()-16, 48);
-    hiddenFiles = new geCheck(groupTop->x(), groupTop->y(), 400, 20, "Show hidden files");
-		where   = new geInput(groupTop->x(), hiddenFiles->y()+hiddenFiles->h()+8, 20, 20);
-		updir   = new geButton(groupTop->x()+groupTop->w()-20, where->y(), 20, 20, "", updirOff_xpm, updirOn_xpm);
+	groupTop    = new Fl_Group(8, 8, w() - 16, 48);
+	hiddenFiles = new geCheck(groupTop->x(), groupTop->y(), 400, 20, "Show hidden files");
+	where       = new geInput(groupTop->x(), hiddenFiles->y() + hiddenFiles->h() + 8, 20, 20);
+	updir       = new geButton(groupTop->x() + groupTop->w() - 20, where->y(), 20, 20, "", updirOff_xpm, updirOn_xpm);
 	groupTop->end();
 	groupTop->resizable(where);
 
-	hiddenFiles->callback(cb_toggleHiddenFiles, (void*) this);
+	hiddenFiles->callback(cb_toggleHiddenFiles, (void*)this);
 
 	where->readonly(true);
 	where->cursor_color(G_COLOR_BLACK);
 	where->value(path.c_str());
 
-	updir->callback(cb_up, (void*) this);
+	updir->callback(cb_up, (void*)this);
 
-	browser = new geBrowser(8, groupTop->y()+groupTop->h()+8, w()-16, h()-101);
+	browser = new geBrowser(8, groupTop->y() + groupTop->h() + 8, w() - 16, h() - 101);
 	browser->loadDir(path);
-	if (path == m::conf::conf.browserLastPath)
-		browser->preselect(m::conf::conf.browserPosition, m::conf::conf.browserLastValue);
+	if (path == m_conf.browserLastPath)
+		browser->preselect(m_conf.browserPosition, m_conf.browserLastValue);
 
-	Fl_Group* groupButtons = new Fl_Group(8, browser->y()+browser->h()+8, w()-16, 20);
-		ok      = new geButton(w()-88, groupButtons->y(), 80, 20);
-		cancel  = new geButton(w()-ok->w()-96, groupButtons->y(), 80, 20, "Cancel");
-		status  = new geProgress(8, groupButtons->y(), cancel->x()-16, 20);
-		status->minimum(0);
-		status->maximum(1);
-		status->hide();   // show the bar only if necessary
-	groupButtons->resizable(status);
+	Fl_Group* groupButtons = new Fl_Group(8, browser->y() + browser->h() + 8, w() - 16, 20);
+	ok                     = new geButton(w() - 88, groupButtons->y(), 80, 20);
+	cancel                 = new geButton(w() - ok->w() - 96, groupButtons->y(), 80, 20, "Cancel");
+	geBox* spacer          = new geBox(8, groupButtons->y(), cancel->x() - 16, 20);
+	groupButtons->resizable(spacer);
 	groupButtons->end();
 
 	end();
 
-	cancel->callback(cb_close, (void*) this);
+	cancel->callback(cb_close, (void*)this);
 
 	resizable(browser);
 	size_range(320, 200);
@@ -91,113 +87,68 @@ gdBrowserBase::gdBrowserBase(const std::string& title, const std::string& path,
 	show();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 gdBrowserBase::~gdBrowserBase()
 {
-	m::conf::conf.browserX = x();
-	m::conf::conf.browserY = y();
-	m::conf::conf.browserW = w();
-	m::conf::conf.browserH = h();
-	m::conf::conf.browserPosition  = browser->position();
-	m::conf::conf.browserLastPath  = browser->getCurrentDir();
-	m::conf::conf.browserLastValue = browser->value();
+	m_conf.browserX         = x();
+	m_conf.browserY         = y();
+	m_conf.browserW         = w();
+	m_conf.browserH         = h();
+	m_conf.browserPosition  = browser->position();
+	m_conf.browserLastPath  = browser->getCurrentDir();
+	m_conf.browserLastValue = browser->value();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdBrowserBase::cb_up(Fl_Widget* v, void* p) { ((gdBrowserBase*)p)->cb_up(); }
-void gdBrowserBase::cb_close(Fl_Widget* v, void* p) { ((gdBrowserBase*)p)->cb_close(); }
-void gdBrowserBase::cb_toggleHiddenFiles(Fl_Widget *v, void *p) { ((gdBrowserBase*)p)->cb_toggleHiddenFiles(); }
-
+void gdBrowserBase::cb_up(Fl_Widget* /*v*/, void* p) { ((gdBrowserBase*)p)->cb_up(); }
+void gdBrowserBase::cb_close(Fl_Widget* /*v*/, void* p) { ((gdBrowserBase*)p)->cb_close(); }
+void gdBrowserBase::cb_toggleHiddenFiles(Fl_Widget* /*v*/, void* p) { ((gdBrowserBase*)p)->cb_toggleHiddenFiles(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void gdBrowserBase::cb_up()
 {
 	browser->loadDir(u::fs::getUpDir(browser->getCurrentDir()));
 	where->value(browser->getCurrentDir().c_str());
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdBrowserBase::cb_close()
 {
 	do_callback();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdBrowserBase::cb_toggleHiddenFiles()
 {
 	browser->toggleHiddenFiles();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdBrowserBase::setStatusBar(float v)
+std::string gdBrowserBase::getCurrentPath() const
 {
-	status->value(status->value() + v);
-	Fl::wait(0);
+	return where->value();
 }
 
-
-/* -------------------------------------------------------------------------- */
-
-
-void gdBrowserBase::showStatusBar()
+ID gdBrowserBase::getChannelId() const
 {
-	status->show();
+	return m_channelId;
 }
 
-
-/* -------------------------------------------------------------------------- */
-
-
-void gdBrowserBase::hideStatusBar()
-{
-	status->hide();
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-std::string gdBrowserBase::getCurrentPath() const 
-{ 
-	return where->value(); 
-}
-
-
-ID gdBrowserBase::getChannelId() const 
-{ 
-	return m_channelId; 
-}
-
-
-std::string gdBrowserBase::getSelectedItem() const 
+std::string gdBrowserBase::getSelectedItem() const
 {
 	return browser->getSelectedItem();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdBrowserBase::fireCallback() const
-{ 
+{
 	m_callback((void*)this);
 }
-
-}} // giada::v::
+} // namespace giada::v
\ No newline at end of file
