@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,35 +24,31 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_BROWSER_BASE_H
 #define GD_BROWSER_BASE_H
 
-
-#include<functional>
-#include "gui/dialogs/window.h"
+#include "core/conf.h"
 #include "core/types.h"
-
+#include "gui/dialogs/window.h"
+#include <functional>
+#include <string>
 
 class Fl_Group;
 class geCheck;
-class geBrowser;
 class geButton;
 class geInput;
-class geProgress;
 
-
-namespace giada {
-namespace m 
-{ 
-class Channel; 
-}
-namespace v
+namespace giada::m
 {
+class Channel;
+}
+
+namespace giada::v
+{
+class geBrowser;
 class gdBrowserBase : public gdWindow
 {
 public:
-
 	~gdBrowserBase();
 
 	/* getSelectedItem
@@ -61,46 +57,36 @@ public:
 	std::string getSelectedItem() const;
 
 	std::string getCurrentPath() const;
-	ID getChannelId() const;
-	void fireCallback() const;
-	
-	/* setStatusBar
-	Increments status bar for progress tracking. */
-
-	void setStatusBar(float v);
-
-	void showStatusBar();
-	void hideStatusBar();
+	ID          getChannelId() const;
+	void        fireCallback() const;
 
 protected:
+	gdBrowserBase(const std::string& title, const std::string& path,
+	    std::function<void(void*)> f, ID channelId, m::Conf::Data&);
 
-	gdBrowserBase(const std::string& title, const std::string& path, 
-		std::function<void(void*)> f, ID channelId);
-
-	static void cb_up(Fl_Widget* v, void* p);
-	static void cb_close(Fl_Widget* w, void* p);
-	static void cb_toggleHiddenFiles(Fl_Widget* w, void* p);
-	void cb_up();
-	void cb_close();
-	void cb_toggleHiddenFiles();
+	static void cb_up(Fl_Widget* /*w*/, void* p);
+	static void cb_close(Fl_Widget* /*w*/, void* p);
+	static void cb_toggleHiddenFiles(Fl_Widget* /*w*/, void* p);
+	void        cb_up();
+	void        cb_close();
+	void        cb_toggleHiddenFiles();
 
 	/* m_callback
 	Fired when the save/load button is pressed. */
 
 	std::function<void(void*)> m_callback;
 
-	ID m_channelId;
+	m::Conf::Data& m_conf;
+	ID             m_channelId;
 
-	Fl_Group*   groupTop;
-	geCheck*    hiddenFiles;
-	geBrowser*  browser;
-	geButton*   ok;
-	geButton*   cancel;
-	geInput*    where;
-	geButton*   updir;
-	geProgress* status;
+	Fl_Group*  groupTop;
+	geCheck*   hiddenFiles;
+	geBrowser* browser;
+	geButton*  ok;
+	geButton*  cancel;
+	geInput*   where;
+	geButton*  updir;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
