@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,55 +24,46 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "utils/fs.h"
-#include "gui/elems/browser.h"
+#include "browserDir.h"
 #include "gui/elems/basics/button.h"
 #include "gui/elems/basics/input.h"
-#include "browserDir.h"
+#include "gui/elems/browser.h"
+#include "utils/fs.h"
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-gdBrowserDir::gdBrowserDir(const std::string& title, const std::string& path, 
-	std::function<void(void*)> cb)
-: gdBrowserBase(title, path, cb, 0)
+gdBrowserDir::gdBrowserDir(const std::string& title, const std::string& path,
+    std::function<void(void*)> cb, m::Conf::Data& conf)
+: gdBrowserBase(title, path, cb, 0, conf)
 {
-	where->size(groupTop->w()-updir->w()-8, 20);
+	where->size(groupTop->w() - updir->w() - 8, 20);
 
-	browser->callback(cb_down, (void*) this);
+	browser->callback(cb_down, (void*)this);
 
 	ok->label("Select");
-	ok->callback(cb_load, (void*) this);
+	ok->callback(cb_load, (void*)this);
 	ok->shortcut(FL_ENTER);
 
 	/* On OS X the 'where' input doesn't get resized properly on startup. Let's 
 	force it. */
-	
+
 	where->redraw();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdBrowserDir::cb_load(Fl_Widget* v, void* p) { ((gdBrowserDir*)p)->cb_load(); }
-void gdBrowserDir::cb_down(Fl_Widget* v, void* p) { ((gdBrowserDir*)p)->cb_down(); }
-
+void gdBrowserDir::cb_load(Fl_Widget* /*v*/, void* p) { ((gdBrowserDir*)p)->cb_load(); }
+void gdBrowserDir::cb_down(Fl_Widget* /*v*/, void* p) { ((gdBrowserDir*)p)->cb_down(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void gdBrowserDir::cb_load()
 {
 	fireCallback();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdBrowserDir::cb_down()
 {
 	std::string path = browser->getSelectedItem();
@@ -83,5 +74,4 @@ void gdBrowserDir::cb_down()
 	browser->loadDir(path);
 	where->value(browser->getCurrentDir().c_str());
 }
-
-}} // giada::v::
+} // namespace giada::v
\ No newline at end of file
