@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,55 +24,46 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "utils/fs.h"
-#include "gui/elems/browser.h"
+#include "browserLoad.h"
 #include "gui/elems/basics/button.h"
 #include "gui/elems/basics/input.h"
-#include "browserLoad.h"
+#include "gui/elems/browser.h"
+#include "utils/fs.h"
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-gdBrowserLoad::gdBrowserLoad(const std::string& title, const std::string& path, 
-	std::function<void(void*)> cb, ID channelId)
-: gdBrowserBase(title, path, cb, channelId)
+gdBrowserLoad::gdBrowserLoad(const std::string& title, const std::string& path,
+    std::function<void(void*)> cb, ID channelId, m::Conf::Data& conf)
+: gdBrowserBase(title, path, cb, channelId, conf)
 {
-	where->size(groupTop->w()-updir->w()-8, 20);
+	where->size(groupTop->w() - updir->w() - 8, 20);
 
-	browser->callback(cb_down, (void*) this);
+	browser->callback(cb_down, (void*)this);
 
 	ok->label("Load");
-	ok->callback(cb_load, (void*) this);
+	ok->callback(cb_load, (void*)this);
 	ok->shortcut(FL_ENTER);
 
 	/* On OS X the 'where' input doesn't get resized properly on startup. Let's 
 	force it. */
-	
+
 	where->redraw();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdBrowserLoad::cb_load(Fl_Widget* v, void* p) { ((gdBrowserLoad*)p)->cb_load(); }
-void gdBrowserLoad::cb_down(Fl_Widget* v, void* p) { ((gdBrowserLoad*)p)->cb_down(); }
-
+void gdBrowserLoad::cb_load(Fl_Widget* /*v*/, void* p) { ((gdBrowserLoad*)p)->cb_load(); }
+void gdBrowserLoad::cb_down(Fl_Widget* /*v*/, void* p) { ((gdBrowserLoad*)p)->cb_down(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void gdBrowserLoad::cb_load()
 {
 	fireCallback();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdBrowserLoad::cb_down()
 {
 	std::string path = browser->getSelectedItem();
@@ -83,5 +74,4 @@ void gdBrowserLoad::cb_down()
 	browser->loadDir(path);
 	where->value(browser->getCurrentDir().c_str());
 }
-
-}} // giada::v::
+} // namespace giada::v
\ No newline at end of file
