@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,37 +24,31 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "glue/channel.h"
-#include "utils/gui.h"
-#include "core/channels/channel.h"
-#include "core/model/model.h"
-#include "core/const.h"
+#include "channelNameInput.h"
 #include "core/conf.h"
+#include "core/const.h"
+#include "core/model/model.h"
+#include "glue/channel.h"
 #include "gui/elems/basics/button.h"
 #include "gui/elems/basics/input.h"
-#include "channelNameInput.h"
+#include "utils/gui.h"
 
-
-
-namespace giada {
-namespace v 
+namespace giada
 {
-gdChannelNameInput::gdChannelNameInput(ID channelId)
-: gdWindow   (u::gui::centerWindowX(400), u::gui::centerWindowY(64), 400, 64, "New channel name"),
-  m_channelId(channelId)
+namespace v
+{
+gdChannelNameInput::gdChannelNameInput(const c::channel::Data& d)
+: gdWindow(u::gui::centerWindowX(400), u::gui::centerWindowY(64), 400, 64, "New channel name")
+, m_data(d)
 {
 	set_modal();
 
 	m_name   = new geInput(G_GUI_OUTER_MARGIN, G_GUI_OUTER_MARGIN, w() - (G_GUI_OUTER_MARGIN * 2), G_GUI_UNIT);
-	m_ok     = new geButton(w() - 70 - G_GUI_OUTER_MARGIN, m_name->y()+m_name->h() + G_GUI_OUTER_MARGIN, 70, G_GUI_UNIT, "Ok");
+	m_ok     = new geButton(w() - 70 - G_GUI_OUTER_MARGIN, m_name->y() + m_name->h() + G_GUI_OUTER_MARGIN, 70, G_GUI_UNIT, "Ok");
 	m_cancel = new geButton(m_ok->x() - 70 - G_GUI_OUTER_MARGIN, m_ok->y(), 70, G_GUI_UNIT, "Cancel");
 	end();
 
-	m::model::onGet(m::model::channels, m_channelId, [&](m::Channel& c)
-	{
-		m_name->value(c.name.c_str());
-	});
+	m_name->value(m_data.name.c_str());
 
 	m_ok->shortcut(FL_Enter);
 	m_ok->callback(cb_update, (void*)this);
@@ -66,30 +60,25 @@ gdChannelNameInput::gdChannelNameInput(ID channelId)
 	show();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdChannelNameInput::cb_update(Fl_Widget* w, void* p) { ((gdChannelNameInput*)p)->cb_update(); }
-void gdChannelNameInput::cb_cancel(Fl_Widget* w, void* p) { ((gdChannelNameInput*)p)->cb_cancel(); }
-
+void gdChannelNameInput::cb_update(Fl_Widget* /*w*/, void* p) { ((gdChannelNameInput*)p)->cb_update(); }
+void gdChannelNameInput::cb_cancel(Fl_Widget* /*w*/, void* p) { ((gdChannelNameInput*)p)->cb_cancel(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void gdChannelNameInput::cb_cancel()
 {
 	do_callback();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdChannelNameInput::cb_update()
 {
-	c::channel::setName(m_channelId, m_name->value());
+	c::channel::setName(m_data.id, m_name->value());
 	do_callback();
 }
 
-}} // giada::v::
+} // namespace v
+} // namespace giada
