@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,14 +24,20 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_CONFIG_H
 #define GD_CONFIG_H
 
-
+#include "core/conf.h"
 #include "window.h"
 
+class geButton;
+class geCheck;
+class geInput;
+class geBox;
 
+namespace giada::v
+{
+class geChoice;
 class geTabAudio;
 class geTabBehaviors;
 class geTabMidi;
@@ -39,44 +45,27 @@ class geTabMisc;
 #ifdef WITH_VST
 class geTabPlugins;
 #endif
-class geButton;
-class geChoice;
-class geCheck;
-class geInput;
-class geRadio;
-class geBox;
-
-
-namespace giada {
-namespace v 
-{
 class gdConfig : public gdWindow
 {
 public:
-
-	gdConfig(int w, int h);
-
-#ifdef WITH_VST
-	void refreshVstPath();
-#endif
+	gdConfig(int w, int h, m::Conf::Data&);
 
 	geTabAudio*     tabAudio;
 	geTabBehaviors* tabBehaviors;
 	geTabMidi*      tabMidi;
 	geTabMisc*      tabMisc;
 #ifdef WITH_VST
-	geTabPlugins*   tabPlugins;
+	geTabPlugins* tabPlugins;
 #endif
-	geButton*       save;
-	geButton*       cancel;
+	geButton* save;
+	geButton* cancel;
 
 private:
-
-	static void cb_save_config(Fl_Widget* w, void* p);
-	static void cb_cancel(Fl_Widget* w, void* p);
-	void cb_save_config();
-	void cb_cancel();
+	static void cb_save_config(Fl_Widget* /*w*/, void* p);
+	static void cb_cancel(Fl_Widget* /*w*/, void* p);
+	void        cb_save_config();
+	void        cb_cancel();
 };
-}} // giada::v::
+} // namespace giada::v
 
 #endif
