@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,48 +24,45 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_KEYGRABBER_H
 #define GD_KEYGRABBER_H
 
-
-#include <FL/Fl.H>
 #include "window.h"
-
+#include <FL/Fl.H>
 
 class geBox;
 class geButton;
 
+namespace giada::c::channel
+{
+struct Data;
+}
 
-namespace giada {
-namespace v 
+namespace giada::v
 {
 class gdKeyGrabber : public gdWindow
 {
 public:
+	gdKeyGrabber(const c::channel::Data& d);
 
-	gdKeyGrabber(ID channelId);
-
-	int handle(int e) override;
+	int  handle(int e) override;
 	void rebuild() override;
 
 private:
-
-	static void cb_clear (Fl_Widget* w, void* p);
-	static void cb_cancel(Fl_Widget* w, void* p);
-	void cb_clear ();
-	void cb_cancel();
+	static void cb_clear(Fl_Widget* /*w*/, void* p);
+	static void cb_cancel(Fl_Widget* /*w*/, void* p);
+	void        cb_clear();
+	void        cb_cancel();
 
 	void setButtonLabel(int key);
 	void updateText(int key);
-	
-	ID m_channelId;
+
+	const c::channel::Data& m_data;
 
 	geBox*    m_text;
 	geButton* m_clear;
 	geButton* m_cancel;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
