@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,72 +24,100 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <FL/Fl.H>
-#include "core/const.h"
+#include "mainWindow.h"
 #include "core/conf.h"
+#include "core/const.h"
 #include "core/init.h"
-#include "utils/gui.h"
 #include "gui/elems/basics/boxtypes.h"
+#include "gui/elems/mainWindow/keyboard/keyboard.h"
 #include "gui/elems/mainWindow/mainIO.h"
 #include "gui/elems/mainWindow/mainMenu.h"
 #include "gui/elems/mainWindow/mainTimer.h"
 #include "gui/elems/mainWindow/mainTransport.h"
-#include "gui/elems/mainWindow/beatMeter.h"
-#include "gui/elems/mainWindow/keyboard/keyboard.h"
+#include "gui/elems/mainWindow/sequencer.h"
+#include "utils/gui.h"
 #include "warnings.h"
-#include "mainWindow.h"
+#include <FL/Fl.H>
+#include <FL/Fl_Tooltip.H>
 
+namespace giada::v
+{
+gdMainWindow::ScopedProgress::ScopedProgress(gdProgress& p, const char* msg)
+: m_progress(p)
+{
+	m_progress.popup(msg);
+}
 
-namespace giada {
-namespace v 
+/* -------------------------------------------------------------------------- */
+
+gdMainWindow::ScopedProgress::~ScopedProgress()
 {
-gdMainWindow::gdMainWindow(int W, int H, const char* title, int argc, char** argv)
-	: gdWindow(W, H, title)
+	m_progress.hide();
+}
+
+/* -------------------------------------------------------------------------- */
+
+gdProgress& gdMainWindow::ScopedProgress::get()
 {
+	return m_progress;
+}
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+gdMainWindow::gdMainWindow(int W, int H, const char* title, int argc, char** argv, m::Conf::Data& c)
+: gdWindow(W, H, title)
+, m_conf(c)
+{
+
 	Fl::visible_focus(0);
 
 	Fl::background(25, 25, 25); // TODO use G_COLOR_GREY_1
 
 	Fl::set_boxtype(G_CUSTOM_BORDER_BOX, g_customBorderBox, 1, 1, 2, 2);
-	Fl::set_boxtype(G_CUSTOM_UP_BOX,     g_customUpBox,     1, 1, 2, 2);
-	Fl::set_boxtype(G_CUSTOM_DOWN_BOX,   g_customDownBox,   1, 1, 2, 2);
+	Fl::set_boxtype(G_CUSTOM_UP_BOX, g_customUpBox, 1, 1, 2, 2);
+	Fl::set_boxtype(G_CUSTOM_DOWN_BOX, g_customDownBox, 1, 1, 2, 2);
 
 	Fl::set_boxtype(FL_BORDER_BOX, G_CUSTOM_BORDER_BOX);
-	Fl::set_boxtype(FL_UP_BOX,     G_CUSTOM_UP_BOX);
-	Fl::set_boxtype(FL_DOWN_BOX,   G_CUSTOM_DOWN_BOX);
+	Fl::set_boxtype(FL_UP_BOX, G_CUSTOM_UP_BOX);
+	Fl::set_boxtype(FL_DOWN_BOX, G_CUSTOM_DOWN_BOX);
+
+	Fl_Tooltip::color(G_COLOR_GREY_1);
+	Fl_Tooltip::textcolor(G_COLOR_LIGHT_2);
+	Fl_Tooltip::size(G_GUI_FONT_SIZE_BASE);
+	Fl_Tooltip::enable(m_conf.showTooltips);
 
 	size_range(G_MIN_GUI_WIDTH, G_MIN_GUI_HEIGHT);
 
-	mainMenu      = new v::geMainMenu(8, 0);
+	mainMenu = new v::geMainMenu(8, 0);
 #if defined(WITH_VST)
-	mainIO        = new v::geMainIO(408, 8);
+	mainIO = new v::geMainIO(412, 8);
 #else
-	mainIO        = new v::geMainIO(476, 8);
+	mainIO = new v::geMainIO(460, 8);
 #endif
 	mainTransport = new v::geMainTransport(8, 39);
-	mainTimer     = new v::geMainTimer(598, 44);
-	beatMeter     = new v::geBeatMeter(100, 83, 609, 20);
-	keyboard      = new v::geKeyboard(8, 122, w()-16, 380);
+	mainTimer     = new v::geMainTimer(571, 44);
+	sequencer     = new v::geSequencer(100, 78, 609, 30);
+	keyboard      = new v::geKeyboard(8, 122, w() - 16, 380);
 
 	/* zone 1 - menus, and I/O tools */
 
-	Fl_Group* zone1 = new Fl_Group(8, 0, W-16, 28);
+	Fl_Group* zone1 = new Fl_Group(8, 0, W - 16, 28);
 	zone1->add(mainMenu);
 	zone1->resizable(new Fl_Box(300, 8, 80, 20));
 	zone1->add(mainIO);
 
 	/* zone 2 - mainTransport and timing tools */
 
-	Fl_Group* zone2 = new Fl_Group(8, mainTransport->y(), W-16, mainTransport->h());
+	Fl_Group* zone2 = new Fl_Group(8, mainTransport->y(), W - 16, mainTransport->h());
 	zone2->add(mainTransport);
-	zone2->resizable(new Fl_Box(mainTransport->x()+mainTransport->w()+4, zone2->y(), 80, 20));
+	zone2->resizable(new Fl_Box(mainTransport->x() + mainTransport->w() + 4, zone2->y(), 80, 20));
 	zone2->add(mainTimer);
 
 	/* zone 3 - beat meter */
 
-	Fl_Group* zone3 = new Fl_Group(8, beatMeter->y(), W-16, beatMeter->h());
-	zone3->add(beatMeter);
+	Fl_Group* zone3 = new Fl_Group(8, sequencer->y(), W - 16, sequencer->h());
+	zone3->add(sequencer);
 
 	/* zone 4 - the keyboard (Fl_Group is unnecessary here, keyboard is
 	 * a group by itself) */
@@ -100,43 +128,39 @@ gdMainWindow::gdMainWindow(int W, int H, const char* title, int argc, char** arg
 	add(zone2);
 	add(zone3);
 	add(keyboard);
-	callback([](Fl_Widget* w, void* v) {
+	callback([](Fl_Widget* /*w*/, void* /*v*/) {
 		m::init::closeMainWindow();
 	});
 	u::gui::setFavicon(this);
 
+	refresh();
+
 	show(argc, argv);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 gdMainWindow::~gdMainWindow()
 {
-	m::conf::conf.mainWindowX = x();
-	m::conf::conf.mainWindowY = y();
-	m::conf::conf.mainWindowW = w();
-	m::conf::conf.mainWindowH = h();
+	m_conf.mainWindowX = x();
+	m_conf.mainWindowY = y();
+	m_conf.mainWindowW = w();
+	m_conf.mainWindowH = h();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdMainWindow::refresh()
 {
 	mainIO->refresh();
 	mainTimer->refresh();
 	mainTransport->refresh();
-	beatMeter->refresh();
+	sequencer->refresh();
 	keyboard->refresh();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdMainWindow::rebuild()
 {
 	keyboard->rebuild();
@@ -144,12 +168,18 @@ void gdMainWindow::rebuild()
 	mainTimer->rebuild();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdMainWindow::clearKeyboard()
 {
 	keyboard->init();
 }
-}} // giada::v::
+
+/* -------------------------------------------------------------------------- */
+
+gdMainWindow::ScopedProgress gdMainWindow::getScopedProgress(const char* msg)
+{
+	return {m_progress, msg};
+}
+
+} // namespace giada::v
\ No newline at end of file
