@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,47 +24,36 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_MIDI_INPUT_BASE_H
 #define GD_MIDI_INPUT_BASE_H
 
-
+#include "core/conf.h"
 #include "gui/dialogs/window.h"
-#include "gui/elems/midiIO/midiLearnerBase.h"
-
+#include "gui/elems/midiIO/midiLearner.h"
 
 class geButton;
 class geCheck;
-class geChoice;
 
-
-namespace giada {
-namespace v 
+namespace giada::v
 {
+class geChoice;
 class gdMidiInputBase : public gdWindow
 {
 public:
-
 	virtual ~gdMidiInputBase();
 
-	void refresh() override;
-
 protected:
+	gdMidiInputBase(int x, int y, int w, int h, const char* title, m::Conf::Data&);
 
-	gdMidiInputBase(int x, int y, int w, int h, const char* title);
+	static void cb_close(Fl_Widget* /*w*/, void* p);
+	void        cb_close();
 
-	static const int LEARNER_WIDTH = 284;
-
-	static void cb_close(Fl_Widget* w, void* p);
-	void cb_close();
-
-	std::vector<geMidiLearnerBase*> m_learners;
+	m::Conf::Data& m_conf;
 
 	geButton* m_ok;
 	geCheck*  m_enable;
 	geChoice* m_channel;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
