@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,52 +26,66 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_MIDI_INPUT_CHANNEL_H
 #define GD_MIDI_INPUT_CHANNEL_H
 
-
+#include "core/conf.h"
+#include "glue/io.h"
+#include "gui/elems/midiIO/midiLearnerPack.h"
 #include "midiInputBase.h"
 
-
-class geScroll;
 class geCheck;
-class geChoice;
 
-
-namespace giada {
-namespace v 
+namespace giada::v
 {
-class geMidiLearner;
-class gdMidiInputChannel : public gdMidiInputBase
+class geChoice;
+class geScrollPack;
+class geChannelLearnerPack : public geMidiLearnerPack
 {
 public:
+	geChannelLearnerPack(int x, int y, const c::io::Channel_InputData& d);
 
-	gdMidiInputChannel(ID channelId);
+	void update(const c::io::Channel_InputData&);
+};
 
-private:
-
-	static void cb_enable(Fl_Widget* w, void* p);
-	static void cb_setChannel(Fl_Widget* w, void* p);
-	static void cb_veloAsVol(Fl_Widget* w, void* p);
-	void cb_enable();
-	void cb_setChannel();
-	void cb_veloAsVol();
-
-	void addChannelLearners();
+/* -------------------------------------------------------------------------- */
 
 #ifdef WITH_VST
 
-	void addPluginLearners();
+class gePluginLearnerPack : public geMidiLearnerPack
+{
+public:
+	gePluginLearnerPack(int x, int y, const c::io::PluginData&);
+
+	void update(const c::io::PluginData&, bool enabled);
+};
 
 #endif
 
+/* -------------------------------------------------------------------------- */
+
+class gdMidiInputChannel : public gdMidiInputBase
+{
+public:
+	gdMidiInputChannel(ID channelId, m::Conf::Data&);
+
+	void rebuild() override;
+
+private:
+	static void cb_enable(Fl_Widget* /*w*/, void* p);
+	static void cb_setChannel(Fl_Widget* /*w*/, void* p);
+	static void cb_veloAsVol(Fl_Widget* /*w*/, void* p);
+	void        cb_enable();
+	void        cb_setChannel();
+	void        cb_veloAsVol();
+
 	ID m_channelId;
 
-	geScroll* m_container;
-	geCheck*  m_veloAsVol;
-};
-}} // giada::v::
+	c::io::Channel_InputData m_data;
 
+	geScrollPack* m_container;
+	geCheck*      m_veloAsVol;
+};
+} // namespace giada::v
 
 #endif
