@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,20 +24,18 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_MIDI_OUTPUT_BASE_H
 #define GD_MIDI_OUTPUT_BASE_H
 
-
 #include "core/types.h"
+#include "glue/io.h"
 #include "gui/dialogs/window.h"
-#include "gui/elems/midiIO/midiLearnerBase.h"
-
+#include "gui/elems/midiIO/midiLearner.h"
+#include "gui/elems/midiIO/midiLearnerPack.h"
 
 class geButton;
 class geCheck;
 
-
 /* There's no such thing as a gdMidiOutputMaster vs gdMidiOutputChannel. MIDI
 output master is managed by the configuration window, hence gdMidiOutput deals
 only with channels.
@@ -45,46 +43,50 @@ only with channels.
 Both MidiOutputMidiCh and MidiOutputSampleCh have the MIDI lighting widget set.
 In addition MidiOutputMidiCh has the MIDI message output box. */
 
-/* TODO - gdMidiOutput is almost the same thing of gdMidiInput. Create another
-parent class gdMidiIO to inherit from */
-
-namespace giada {
-namespace v 
+namespace giada
 {
-class geMidiLearner;
+namespace v
+{
+class geLightningLearnerPack : public geMidiLearnerPack
+{
+public:
+	geLightningLearnerPack(int x, int y, ID channelId);
+
+	void update(const c::io::Channel_OutputData&);
+};
+
+/* -------------------------------------------------------------------------- */
+
 class gdMidiOutputBase : public gdWindow
 {
 public:
-
 	gdMidiOutputBase(int w, int h, ID channelId);
 	~gdMidiOutputBase();
 
-	void refresh() override;
-
-protected:
-
+  protected:
 	/* cb_close
 	close current window. */
 
-	static void cb_close(Fl_Widget* w, void* p);
-	void cb_close();
+	static void cb_close(Fl_Widget* /*w*/, void* p);
+	void        cb_close();
 
-	static void cb_enableLightning(Fl_Widget* w, void* p);
-	void cb_enableLightning();
+	static void cb_enableLightning(Fl_Widget* /*w*/, void* p);
+	void        cb_enableLightning();
 
 	/* setTitle
 	 * set window title. */
 
-	void setTitle(int chanNum);
+	void setTitle(ID channelId);
 
 	ID m_channelId;
 
-	std::vector<geMidiLearnerBase*> m_learners;
-	
-	geButton* m_close;
-	geCheck*  m_enableLightning;
-};
-}} // giada::v::
+	c::io::Channel_OutputData m_data;
 
+	geLightningLearnerPack* m_learners;
+	geButton*               m_close;
+	geCheck*                m_enableLightning;
+};
+} // namespace v
+} // namespace giada
 
 #endif
