@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,24 +24,23 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_MIDI_OUTPUT_SAMPLE_CH_H
 #define GD_MIDI_OUTPUT_SAMPLE_CH_H
 
-
 #include "midiOutputBase.h"
 
-
-namespace giada {
-namespace v 
+namespace giada
+{
+namespace v
 {
 class gdMidiOutputSampleCh : public gdMidiOutputBase
 {
 public:
+	gdMidiOutputSampleCh(ID channelId);
 
-    gdMidiOutputSampleCh(ID channelId);
+	void rebuild() override;
 };
-}} // giada::v::
-
+} // namespace v
+} // namespace giada
 
 #endif
