@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,52 +24,49 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifdef WITH_VST
 
 #ifndef GD_PLUGIN_CHOOSER_H
 #define GD_PLUGIN_CHOOSER_H
 
-
+#include "core/conf.h"
+#include "core/types.h"
+#include "window.h"
 #include <FL/Fl.H>
 #include <FL/Fl_Scroll.H>
-#include "window.h"
 
-
-class geChoice;
 class geButton;
 class geButton;
 
-namespace giada {
-namespace v
+namespace giada::v
 {
+class geChoice;
 class gePluginBrowser;
 
 class gdPluginChooser : public gdWindow
 {
 public:
-
-	gdPluginChooser(int x, int y, int w, int h, ID chanID);
+	gdPluginChooser(int x, int y, int w, int h, ID channelId, m::Conf::Data&);
 	~gdPluginChooser();
 
 private:
+	static void cb_close(Fl_Widget* /*w*/, void* p);
+	static void cb_add(Fl_Widget* /*w*/, void* p);
+	static void cb_sort(Fl_Widget* /*w*/, void* p);
+	void        cb_close();
+	void        cb_add();
+	void        cb_sort();
 
-	static void cb_close(Fl_Widget* w, void* p);
-	static void cb_add  (Fl_Widget* w, void* p);
-	static void cb_sort (Fl_Widget* w, void* p);
-	void cb_close();
-	void cb_add  ();
-	void cb_sort ();
+	m::Conf::Data& m_conf;
 
 	geChoice*        sortMethod;
 	geButton*        addBtn;
 	geButton*        cancelBtn;
 	gePluginBrowser* browser;
 
-	ID m_chanID;
+	ID m_channelId;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
 
