@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,122 +24,96 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifdef WITH_VST
 
-
-#include <cassert>
-#include <string>
-#include "core/model/model.h"
-#include "core/channels/channel.h"
+#include "gui/dialogs/pluginList.h"
 #include "core/conf.h"
 #include "core/const.h"
-#include "core/pluginHost.h"
-#include "utils/string.h"
-#include "utils/gui.h"
-#include "gui/elems/basics/liquidScroll.h"
+#include "glue/layout.h"
 #include "gui/elems/basics/boxtypes.h"
 #include "gui/elems/basics/button.h"
+#include "gui/elems/basics/liquidScroll.h"
 #include "gui/elems/basics/statusButton.h"
-#include "gui/elems/mainWindow/mainIO.h"
 #include "gui/elems/mainWindow/keyboard/channel.h"
+#include "gui/elems/mainWindow/mainIO.h"
 #include "gui/elems/plugin/pluginElement.h"
-#include "pluginChooser.h"
-#include "mainWindow.h"
-#include "pluginList.h"
+#include "utils/gui.h"
+#include "utils/string.h"
+#include <cassert>
+#include <string>
 
-
-extern giada::v::gdMainWindow* G_MainWin;
-
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-gdPluginList::gdPluginList(ID chanID)
-: gdWindow(m::conf::conf.pluginListX, m::conf::conf.pluginListY, 468, 204), 
-  m_channelId(chanID)
+gdPluginList::gdPluginList(ID channelId, m::Conf::Data& c)
+: gdWindow(c.pluginListX, c.pluginListY, 468, 204)
+, m_conf(c)
+, m_channelId(channelId)
 {
 	end();
 
-	list = new geLiquidScroll(G_GUI_OUTER_MARGIN, G_GUI_OUTER_MARGIN, 
-		w() - (G_GUI_OUTER_MARGIN*2), h() - (G_GUI_OUTER_MARGIN*2));
+	list = new geLiquidScroll(G_GUI_OUTER_MARGIN, G_GUI_OUTER_MARGIN,
+	    w() - (G_GUI_OUTER_MARGIN * 2), h() - (G_GUI_OUTER_MARGIN * 2),
+	    Direction::VERTICAL);
 	list->end();
 	add(list);
-
-	rebuild();
-
-	if (m_channelId == m::mixer::MASTER_OUT_CHANNEL_ID)
-		label("Master Out Plug-ins");
-	else
-	if (m_channelId == m::mixer::MASTER_IN_CHANNEL_ID)
-		label("Master In Plug-ins");
-	else {
-		std::string l = "Channel " + u::string::iToString(m_channelId + 1) + " Plug-ins";
-		copy_label(l.c_str());
-	}
+	resizable(list);
 
 	u::gui::setFavicon(this);
 	set_non_modal();
+	rebuild();
 	show();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 gdPluginList::~gdPluginList()
 {
-	m::conf::conf.pluginListX = x();
-	m::conf::conf.pluginListY = y();
+	m_conf.pluginListX = x();
+	m_conf.pluginListY = y();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdPluginList::cb_addPlugin(Fl_Widget* v, void* p) { ((gdPluginList*)p)->cb_addPlugin(); }
-
+void gdPluginList::cb_addPlugin(Fl_Widget* /*v*/, void* p) { ((gdPluginList*)p)->cb_addPlugin(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void gdPluginList::rebuild()
 {
+	m_plugins = c::plugin::getPlugins(m_channelId);
+
+	if (m_plugins.channelId == m::Mixer::MASTER_OUT_CHANNEL_ID)
+		label("Master Out Plug-ins");
+	else if (m_plugins.channelId == m::Mixer::MASTER_IN_CHANNEL_ID)
+		label("Master In Plug-ins");
+	else
+	{
+		std::string l = "Channel " + u::string::iToString(m_plugins.channelId) + " Plug-ins";
+		copy_label(l.c_str());
+	}
+
 	/* Clear the previous list. */
 
 	list->clear();
 	list->scroll_to(0, 0);
 
-	m::model::ChannelsLock l(m::model::channels);
+	for (m::Plugin* plugin : m_plugins.plugins)
+		list->addWidget(new gePluginElement(0, 0, c::plugin::getPlugin(*plugin, m_plugins.channelId)));
 
-	const m::Channel& ch = m::model::get(m::model::channels, m_channelId);
-
-	for (ID pluginId : ch.pluginIds)
-		list->addWidget(new gePluginElement(pluginId, m_channelId, 0, 0, 0));
-	
 	addPlugin = list->addWidget(new geButton(0, 0, 0, G_GUI_UNIT, "-- add new plugin --"));
-	
+
 	addPlugin->callback(cb_addPlugin, (void*)this);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdPluginList::cb_addPlugin()
 {
-	int wx = m::conf::conf.pluginChooserX;
-	int wy = m::conf::conf.pluginChooserY;
-	int ww = m::conf::conf.pluginChooserW;
-	int wh = m::conf::conf.pluginChooserH;
-	u::gui::openSubWindow(G_MainWin, new v::gdPluginChooser(wx, wy, ww, wh, 
-		m_channelId), WID_FX_CHOOSER);
+	c::layout::openPluginChooser(m_plugins.channelId);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 const gePluginElement& gdPluginList::getNextElement(const gePluginElement& currEl) const
 {
 	int curr = list->find(currEl);
@@ -149,7 +123,6 @@ const gePluginElement& gdPluginList::getNextElement(const gePluginElement& currE
 	return *static_cast<gePluginElement*>(list->child(next));
 }
 
-
 const gePluginElement& gdPluginList::getPrevElement(const gePluginElement& currEl) const
 {
 	int curr = list->find(currEl);
@@ -158,7 +131,6 @@ const gePluginElement& gdPluginList::getPrevElement(const gePluginElement& currE
 		prev = 0;
 	return *static_cast<gePluginElement*>(list->child(prev));
 }
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif // #ifdef WITH_VST
