@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,31 +24,25 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifdef WITH_VST
 
-
 #ifndef GD_PLUGINLIST_H
 #define GD_PLUGINLIST_H
 
-
-#include "core/pluginHost.h"
+#include "core/conf.h"
+#include "glue/plugin.h"
 #include "window.h"
 
-
-class geLiquidScroll;
 class geButton;
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
+class geLiquidScroll;
 class gePluginElement;
 class gdPluginList : public gdWindow
 {
 public:
-
-	gdPluginList(ID chanID);
+	gdPluginList(ID channelId, m::Conf::Data&);
 	~gdPluginList();
 
 	void rebuild() override;
@@ -57,18 +51,18 @@ public:
 	const gePluginElement& getPrevElement(const gePluginElement& curr) const;
 
 private:
+	static void cb_addPlugin(Fl_Widget* /*w*/, void* p);
+	void        cb_addPlugin();
 
-	static void cb_addPlugin(Fl_Widget* v, void* p);
-	void cb_addPlugin();
+	m::Conf::Data& m_conf;
 
 	geButton*       addPlugin;
-	geLiquidScroll* list;	
+	geLiquidScroll* list;
 
-	ID m_channelId;
+	ID                 m_channelId;
+	c::plugin::Plugins m_plugins;
 };
-
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
 
