@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,48 +24,40 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifdef WITH_VST
 
-
 #ifndef GD_PLUGIN_WINDOW_H
 #define GD_PLUGIN_WINDOW_H
 
-
 #include "window.h"
 
-
 class geBox;
 class geSlider;
-class geLiquidScroll;
 
-
-namespace giada {
-namespace m
+namespace giada::c::plugin
+{
+struct Plugin;
+}
+namespace giada::m
 {
 class Plugin;
 }
-namespace v
+namespace giada::v
 {
+class geLiquidScroll;
 class gdPluginWindow : public gdWindow
 {
 public:
+	gdPluginWindow(const c::plugin::Plugin&);
 
-	gdPluginWindow(ID pluginId);
-
-	void updateParameter(int index, bool changeSlider=false);
-	void updateParameters(bool changeSlider=false);
+	void updateParameters(bool changeSlider = false);
 
 private:
+	const c::plugin::Plugin& m_plugin;
 
-	int getLabelWidth() const;
-	
-	ID m_pluginId;
-		
 	geLiquidScroll* m_list;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
 
