@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,147 +24,91 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifdef WITH_VST
 
-
-#include <FL/x.H>
-#include "utils/log.h"
-#include "utils/gui.h"
-#include "core/pluginHost.h"
-#include "core/model/model.h"
-#include "core/plugin.h"
+#include "gui/dialogs/pluginWindowGUI.h"
 #include "core/const.h"
-#include "pluginWindowGUI.h"
+#include "glue/plugin.h"
+#include "utils/gui.h"
+#include "utils/log.h"
+#include <FL/x.H>
 #ifdef G_OS_MAC
 #import "utils/cocoa.h" // objective-c
 #endif
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-gdPluginWindowGUI::gdPluginWindowGUI(ID pluginId)
+gdPluginWindowGUI::gdPluginWindowGUI(c::plugin::Plugin& p)
 #ifdef G_OS_MAC
-: gdWindow     (Fl::w(), Fl::h()),
+: gdWindow(Fl::w(), Fl::h())
 #else
-: gdWindow     (320, 200),
+: gdWindow(320, 200)
 #endif
-  m_pluginId(pluginId),
-  m_ui         (nullptr)
+, m_plugin(p)
 {
+	/* Make sure to wait_for_expose() before opening the editor: the window must
+	be exposed and visible first. Don't fuck with multithreading! */
+
+	copy_label(m_plugin.name.c_str());
 	show();
-
-#if defined(G_OS_LINUX) || defined(G_OS_MAC) || defined(G_OS_FREEBSD)
-
-	/*  Fl_Window::show() is not guaranteed to show and draw the window on all 
-	platforms immediately. Instead this is done in the background; particularly on 
-	X11 it will take a few messages (client server roundtrips) to display the 
-	window. Usually this small delay doesn't matter, but in some cases you may 
-	want to have the window instantiated and displayed synchronously. Currently 
-	(as of FLTK 1.3.4) this method has an effect on X11 and Mac OS. 
-
-	http://www.fltk.org/doc-1.3/classFl__Window.html#aafbec14ca8ff8abdaff77a35ebb23dd8 */
-
 	wait_for_expose();
+	openEditor();
 	Fl::flush();
-
-#endif
-
-	u::log::print("[gdPluginWindowGUI] opening GUI, this=%p, xid=%p\n",
-		(void*) this, (void*) fl_xid(this));
-
-#ifdef G_OS_MAC
-
-	void* cocoaWindow = (void*) fl_xid(this);
-	openEditor(cocoa_getViewFromWindow(cocoaWindow));
-
-#else
-
-	openEditor((void*) fl_xid(this));
-
-	int pluginW = m_ui->getWidth();
-	int pluginH = m_ui->getHeight();
-
-	resize((Fl::w() - pluginW) / 2, (Fl::h() - pluginH) / 2, pluginW, pluginH);
-
-
-#endif
-
-	Fl::add_timeout(G_GUI_PLUGIN_RATE, cb_refresh, (void*) this);
-
-	m::model::onGet(m::model::plugins, m_pluginId, [&](m::Plugin& p)
-	{
-		copy_label(p.getName().c_str());
-	});
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 gdPluginWindowGUI::~gdPluginWindowGUI()
 {
-	cb_close();
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void gdPluginWindowGUI::cb_close(Fl_Widget* v, void* p) { ((gdPluginWindowGUI*)p)->cb_close(); }
-void gdPluginWindowGUI::cb_refresh(void* data) { ((gdPluginWindowGUI*)data)->cb_refresh(); }
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void gdPluginWindowGUI::cb_close()
-{
-	Fl::remove_timeout(cb_refresh);
+	c::plugin::stopDispatchLoop();
 	closeEditor();
-	u::log::print("[gdPluginWindowGUI::__cb_close] GUI closed, this=%p\n", (void*) this);
+	u::log::print("[gdPluginWindowGUI::__cb_close] GUI closed, this=%p\n", (void*)this);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdPluginWindowGUI::cb_refresh()
+void gdPluginWindowGUI::openEditor()
 {
-	m::pluginHost::runDispatchLoop();
-	Fl::repeat_timeout(G_GUI_PLUGIN_RATE, cb_refresh, (void*) this);
-}
+	u::log::print("[gdPluginWindowGUI] Opening editor, this=%p, xid=%p\n",
+	    this, reinterpret_cast<void*>(fl_xid(this)));
 
-
-/* -------------------------------------------------------------------------- */
-
-
-void gdPluginWindowGUI::openEditor(void* parent)
-{
-	m::model::onGet(m::model::plugins, m_pluginId, [&](m::Plugin& p)
+	m_editor.reset(m_plugin.createEditor());
+	if (m_editor == nullptr)
 	{
-		m_ui = p.createEditor();
-	});
-	if (m_ui == nullptr) {
 		u::log::print("[gdPluginWindowGUI::openEditor] unable to create editor!\n");
 		return;
 	}
-	m_ui->setOpaque(true);
-	m_ui->addToDesktop(0, parent);	
-}
+	m_editor->setOpaque(true);
 
+#ifdef G_OS_MAC
+
+	void* cocoaWindow = (void*)fl_xid(this);
+	m_editor->addToDesktop(0, cocoa_getViewFromWindow(cocoaWindow));
+
+#else
+
+	m_editor->addToDesktop(0, reinterpret_cast<void*>(fl_xid(this)));
+
+#endif
+
+	const int pluginW = m_editor->getWidth();
+	const int pluginH = m_editor->getHeight();
+
+	resize((Fl::w() - pluginW) / 2, (Fl::h() - pluginH) / 2, pluginW, pluginH);
+
+	m_plugin.setResizeCallback([this](int w, int h) {
+		resize(x(), y(), w, h);
+	});
+
+	c::plugin::startDispatchLoop();
+}
 
 /* -------------------------------------------------------------------------- */
 
-
 void gdPluginWindowGUI::closeEditor()
 {
-	delete m_ui;
-	m_ui = nullptr;
+	m_editor.reset();
 }
-
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif // #ifdef WITH_VST
