@@ -7,7 +7,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,47 +27,38 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifdef WITH_VST
 
-
 #ifndef GD_PLUGIN_WINDOW_GUI_H
 #define GD_PLUGIN_WINDOW_GUI_H
 
-
+#include "deps/juce-config.h"
+#include "window.h"
 #include <FL/Fl.H>
 #include <FL/Fl_Window.H>
-#include "window.h"
 
+namespace giada::c::plugin
+{
+struct Plugin;
+}
 
-namespace giada {
-namespace v
+namespace giada::v
 {
 class gdPluginWindowGUI : public gdWindow
 {
 public:
-
-	gdPluginWindowGUI(ID pluginId);
+	gdPluginWindowGUI(c::plugin::Plugin&);
 	~gdPluginWindowGUI();
 
+	void openEditor();
+	void closeEditor();
+
 private:
-
-	static void cb_close(Fl_Widget* v, void* p);
-	static void cb_refresh(void* data);
-	void cb_close();
-	void cb_refresh();
-
-	void openEditor(void* parent); 
-	void closeEditor(); 
-
-	ID m_pluginId;
-
-	juce::AudioProcessorEditor* m_ui;
+	c::plugin::Plugin&                          m_plugin;
+	std::unique_ptr<juce::AudioProcessorEditor> m_editor;
 };
-}} // giada::v::
-
-
-#endif // include guard
+} // namespace giada::v
 
+#endif
 
 #endif // #ifdef WITH_VST
