@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,16 +24,16 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_WARNINGS_H
 #define GD_WARNINGS_H
 
-
-namespace giada {
-namespace v 
+namespace giada
 {
-void gdAlert(const char *c);
-int  gdConfirmWin(const char *title, const char *msg);
-}} // giada::v::
+namespace v
+{
+void gdAlert(const char* c);
+int  gdConfirmWin(const char* title, const char* msg);
+} // namespace v
+} // namespace giada
 
 #endif
