@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,179 +24,146 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "utils/log.h"
 #include "window.h"
+#include "utils/log.h"
 
-
-namespace giada {
-namespace v 
+namespace giada::v
 {
-void cb_window_closer(Fl_Widget* v, void* p)
+void cb_window_closer(Fl_Widget* /*v*/, void* p)
 {
-  delete (Fl_Window*) p;
+	delete (Fl_Window*)p;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 gdWindow::gdWindow(int x, int y, int w, int h, const char* title, int id)
-	: Fl_Double_Window(x, y, w, h, title), id(id), parent(nullptr)
+: Fl_Double_Window(x, y, w, h, title)
+, id(id)
+, parent(nullptr)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 gdWindow::gdWindow(int w, int h, const char* title, int id)
-	: Fl_Double_Window(w, h, title), id(id), parent(nullptr)
+: Fl_Double_Window(w, h, title)
+, id(id)
+, parent(nullptr)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 gdWindow::~gdWindow()
 {
 	/* delete all subwindows in order to empty the stack */
 
-	for (unsigned i=0; i<subWindows.size(); i++)
-		delete subWindows.at(i);
+	for (unsigned j = 0; j < subWindows.size(); j++)
+		delete subWindows.at(j);
 	subWindows.clear();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
 /* this is the default callback of each window, fired when the user closes
  * the window with the 'x'. Watch out: is the parent that calls delSubWIndow */
 
-void gdWindow::cb_closeChild(Fl_Widget* v, void* p)
+void gdWindow::cb_closeChild(Fl_Widget* w, void* /*p*/)
 {
-	gdWindow* child = (gdWindow*) v;
+	gdWindow* child = (gdWindow*)w;
 	if (child->getParent() != nullptr)
 		(child->getParent())->delSubWindow(child);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdWindow::addSubWindow(gdWindow* w)
 {
-	/** TODO - useless: delete ---------------------------------------- */
-	for (unsigned i=0; i<subWindows.size(); i++)
-		if (w->getId() == subWindows.at(i)->getId()) {
-			//u::log::print("[gdWindow] window %p (id=%d) exists, not added (and deleted)\n", (void*)w, w->getId());
-			delete w;
-			return;
-		}
-	/** --------------------------------------------------------------- */
-
 	w->setParent(this);
 	w->callback(cb_closeChild); // you can pass params: w->callback(cb_closeChild, (void*)params)
 	subWindows.push_back(w);
 	//debug();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdWindow::delSubWindow(gdWindow* w)
 {
-	for (unsigned i=0; i<subWindows.size(); i++)
-		if (w->getId() == subWindows.at(i)->getId()) {
-			delete subWindows.at(i);
-			subWindows.erase(subWindows.begin() + i);
-			//debug();
+	for (unsigned j = 0; j < subWindows.size(); j++)
+		if (w->getId() == subWindows.at(j)->getId())
+		{
+			delete subWindows.at(j);
+			subWindows.erase(subWindows.begin() + j);
 			return;
 		}
-	//debug();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdWindow::delSubWindow(int id)
+void gdWindow::delSubWindow(int wid)
 {
-	for (unsigned i=0; i<subWindows.size(); i++)
-		if (subWindows.at(i)->getId() == id) {
-			delete subWindows.at(i);
-			subWindows.erase(subWindows.begin() + i);
-			//debug();
+	for (unsigned j = 0; j < subWindows.size(); j++)
+		if (subWindows.at(j)->getId() == wid)
+		{
+			delete subWindows.at(j);
+			subWindows.erase(subWindows.begin() + j);
 			return;
 		}
-	//debug();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 int gdWindow::getId() const
 {
 	return id;
 }
 
-
-void gdWindow::setId(int id)
+void gdWindow::setId(int wid)
 {
-	this->id = id;
+	id = wid;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdWindow::debug() const
 {
+	/* TODO - use G_DEBUG
 	u::log::print("---- window stack (id=%d): ----\n", getId());
 	for (unsigned i=0; i<subWindows.size(); i++)
 		u::log::print("[gdWindow] %p (id=%d)\n", (void*)subWindows.at(i), subWindows.at(i)->getId());
 	u::log::print("----\n");
+	*/
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 gdWindow* gdWindow::getParent()
 {
 	return parent;
 }
 
-
 void gdWindow::setParent(gdWindow* w)
 {
 	parent = w;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-bool gdWindow::hasWindow(int id) const
+bool gdWindow::hasWindow(int wid) const
 {
-	for (unsigned i=0; i<subWindows.size(); i++)
-		if (id == subWindows.at(i)->getId())
+	for (unsigned j = 0; j < subWindows.size(); j++)
+		if (wid == subWindows.at(j)->getId())
 			return true;
 	return false;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-gdWindow* gdWindow::getChild(int id)
+gdWindow* gdWindow::getChild(int wid)
 {
-	for (unsigned i=0; i<subWindows.size(); i++)
-		if (id == subWindows.at(i)->getId())
-			return subWindows.at(i);
+	for (unsigned j = 0; j < subWindows.size(); j++)
+		if (wid == subWindows.at(j)->getId())
+			return subWindows.at(j);
 	return nullptr;
 }
-}} // giada::v::
\ No newline at end of file
+} // namespace giada::v
