@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,64 +24,57 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_WINDOW_H
 #define GD_WINDOW_H
 
-
-#include <vector>
 #include <FL/Fl_Double_Window.H>
+#include <vector>
 
-
-namespace giada {
-namespace v 
+namespace giada::v
 {
 /* cb_window_closer
 Callback for closing windows. Deletes the widget (delete). */
 
-void cb_window_closer(Fl_Widget* v, void* p);
+void cb_window_closer(Fl_Widget* /*w*/, void* p);
 
 class gdWindow : public Fl_Double_Window
 {
 public:
-
-	gdWindow(int x, int y, int w, int h, const char* title=0, int id=0);
-	gdWindow(int w, int h, const char* title=0, int id=0);
+	gdWindow(int x, int y, int w, int h, const char* title = 0, int id = 0);
+	gdWindow(int w, int h, const char* title = 0, int id = 0);
 	~gdWindow();
 
-	static void cb_closeChild(Fl_Widget* v, void* p);
+	static void cb_closeChild(Fl_Widget* /*w*/, void* p);
 
 	/* rebuild, refresh
 	Rebuild() is called by the View Updater when something structural changes
 	(e.g. a new channel added). Refresh() is called periodically by the View 
 	Updater during the refresh loop. */
-	
-	virtual void rebuild() {};
-	virtual void refresh() {};
+
+	virtual void rebuild(){};
+	virtual void refresh(){};
 
 	/* hasWindow
 	True if the window with id 'id' exists in the stack. */
 
 	bool hasWindow(int id) const;
-	
+
 	int  getId() const;
 	void debug() const;
 
-	void addSubWindow(gdWindow* w);
-	void delSubWindow(gdWindow* w);
-	void delSubWindow(int id);
-	void setId(int id);
-	void setParent(gdWindow* w);
+	void      addSubWindow(gdWindow* w);
+	void      delSubWindow(gdWindow* w);
+	void      delSubWindow(int id);
+	void      setId(int id);
+	void      setParent(gdWindow* w);
 	gdWindow* getParent();
 	gdWindow* getChild(int id);
 
 protected:
-
 	std::vector<gdWindow*> subWindows;
-	int id;
-	gdWindow* parent;
+	int                    id;
+	gdWindow*              parent;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
