@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,158 +24,130 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cassert>
-#include <FL/Fl.H>
-#include "core/channels/channel.h"
+#include "dispatcher.h"
 #include "core/init.h"
-#include "core/const.h"
-#include "core/mixer.h"
-#include "core/mixerHandler.h"
-#include "core/recManager.h"
-#include "core/conf.h"
-#include "glue/io.h"
-#include "glue/main.h"
+#include "glue/events.h"
 #include "gui/dialogs/mainWindow.h"
 #include "gui/elems/mainWindow/keyboard/channel.h"
 #include "gui/elems/mainWindow/keyboard/keyboard.h"
-#include "dispatcher.h"
+#include "gui/ui.h"
+#include <FL/Fl.H>
+#include <cassert>
 
+extern giada::v::Ui g_ui;
 
-extern giada::v::gdMainWindow* G_MainWin;
-
-
-namespace giada {
-namespace v {
-namespace dispatcher
+namespace giada::v
 {
-namespace
+Dispatcher::Dispatcher()
+: m_backspace(false)
+, m_end(false)
+, m_enter(false)
+, m_space(false)
+, m_esc(false)
+, m_key(false)
 {
-bool backspace_ = false;
-bool end_       = false;
-bool enter_     = false;
-bool space_     = false;
-bool esc_       = false;
-bool key_       = false;
-
-
-std::function<void()> signalCb_ = nullptr;
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void perform_(const geChannel* gch, int event)
-{
-	if (event == FL_KEYDOWN)
-		c::io::keyPress(gch->channelId, Fl::event_ctrl(), Fl::event_shift(), G_MAX_VELOCITY);
-	else
-	if (event == FL_KEYUP)	
-		c::io::keyRelease(gch->channelId, Fl::event_ctrl(), Fl::event_shift());
 }
 
-
 /* -------------------------------------------------------------------------- */
 
+void Dispatcher::perform(ID channelId, int event) const
+{
+	if (event == FL_KEYDOWN)
+	{
+		if (Fl::event_ctrl())
+			c::events::toggleMuteChannel(channelId, Thread::MAIN);
+		else if (Fl::event_shift())
+			c::events::killChannel(channelId, Thread::MAIN);
+		else
+			c::events::pressChannel(channelId, G_MAX_VELOCITY, Thread::MAIN);
+	}
+	else if (event == FL_KEYUP)
+		c::events::releaseChannel(channelId, Thread::MAIN);
+}
+
+/* -------------------------------------------------------------------------- */
 
 /* Walk channels array, trying to match button's bound key with the event. If 
 found, trigger the key-press/key-release function. */
 
-void dispatchChannels_(int event)
+void Dispatcher::dispatchChannels(int event) const
 {
-	G_MainWin->keyboard->forEachChannel([=](geChannel& c)
-	{
+	g_ui.mainWindow->keyboard->forEachChannel([=](geChannel& c) {
 		if (c.handleKey(event))
-			perform_(&c, event);
+			perform(c.getData().id, event);
 	});
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void triggerSignalCb_()
+void Dispatcher::dispatchKey(int event)
 {
-	if (signalCb_ == nullptr) 
-		return;
-	signalCb_();
-	signalCb_ = nullptr;
-}
-} // {anonymous}
+	assert(onEventOccured != nullptr);
 
-
-/* -------------------------------------------------------------------------- */
-/* -------------------------------------------------------------------------- */
-/* -------------------------------------------------------------------------- */
-
-
-void dispatchKey(int event)
-{
 	/* These events come from the keyboard, not from a direct interaction on the 
-	UI with the mouse/touch. So the 'gui' parameter is set to false. */
+	UI with the mouse/touch. */
 
-	if (event == FL_KEYDOWN) {
-		if (Fl::event_key() == FL_BackSpace && !backspace_) {
-			backspace_ = true;
-			m::mh::rewindSequencer();
+	if (event == FL_KEYDOWN)
+	{
+		if (Fl::event_key() == FL_BackSpace && !m_backspace)
+		{
+			m_backspace = true;
+			c::events::rewindSequencer(Thread::MAIN);
 		}
-		else if (Fl::event_key() == FL_End && !end_) {
-			end_ = true;
-			c::main::toggleInputRec();
+		else if (Fl::event_key() == FL_End && !m_end)
+		{
+			m_end = true;
+			c::events::toggleInputRecording();
 		}
-		else if (Fl::event_key() == FL_Enter && !enter_) {
-			enter_ = true;
-			m::recManager::toggleActionRec(static_cast<RecTriggerMode>(m::conf::conf.recTriggerMode));
+		else if (Fl::event_key() == FL_Enter && !m_enter)
+		{
+			m_enter = true;
+			c::events::toggleActionRecording();
 		}
-		else if (Fl::event_key() == ' ' && !space_) {
-			space_ = true;
-			m::mh::toggleSequencer();
+		else if (Fl::event_key() == ' ' && !m_space)
+		{
+			m_space = true;
+			c::events::toggleSequencer(Thread::MAIN);
 		}
-		else if (Fl::event_key() == FL_Escape && !esc_) {
-			esc_ = true;
+		else if (Fl::event_key() == FL_Escape && !m_esc)
+		{
+			m_esc = true;
 			m::init::closeMainWindow();
 		}
-		else if (!key_) {
-			key_ = true;
-			triggerSignalCb_();
-			dispatchChannels_(event);
+		else if (!m_key)
+		{
+			m_key = true;
+			onEventOccured();
+			dispatchChannels(event);
 		}
 	}
-	else if (event == FL_KEYUP) {
+	else if (event == FL_KEYUP)
+	{
 		if (Fl::event_key() == FL_BackSpace)
-			backspace_ = false;
+			m_backspace = false;
 		else if (Fl::event_key() == FL_End)
-			end_ = false;
+			m_end = false;
 		else if (Fl::event_key() == ' ')
-			space_ = false;
+			m_space = false;
 		else if (Fl::event_key() == FL_Enter)
-			enter_ = false;
+			m_enter = false;
 		else if (Fl::event_key() == FL_Escape)
-			esc_ = false;
-		else {
-			key_ = false;
-			dispatchChannels_(event);
+			m_esc = false;
+		else
+		{
+			m_key = false;
+			dispatchChannels(event);
 		}
 	}
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void dispatchTouch(const geChannel* gch, bool status)
+void Dispatcher::dispatchTouch(const geChannel& gch, bool status)
 {
-	triggerSignalCb_();
-	perform_(gch, status ? FL_KEYDOWN : FL_KEYUP);
+	assert(onEventOccured != nullptr);
+
+	onEventOccured();
+	perform(gch.getData().id, status ? FL_KEYDOWN : FL_KEYUP);
 }
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void setSignalCallback(std::function<void()> f)
-{
-	signalCb_ = f;
-}
-
-}}} // giada::v::dispatcher
+} // namespace giada::v
\ No newline at end of file
