@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,77 +24,78 @@
  *
  * -------------------------------------------------------------------------- */
 
-
+#include "baseAction.h"
 #include <FL/Fl.H>
 #include <FL/fl_draw.H>
-#include "baseAction.h"
 
-
-namespace giada {
+namespace giada
+{
 namespace v
 {
 geBaseAction::geBaseAction(Pixel X, Pixel Y, Pixel W, Pixel H, bool resizable,
-	m::Action a1, m::Action a2)
-: Fl_Box     (X, Y, W, H),
-  m_resizable(resizable),
-  onRightEdge(false),
-  onLeftEdge (false),
-  hovered    (false),
-  altered    (false),
-  pick       (0),
-  a1         (a1),
-  a2         (a2)
+    m::Action a1, m::Action a2)
+: Fl_Box(X, Y, W, H)
+, onRightEdge(false)
+, onLeftEdge(false)
+, hovered(false)
+, altered(false)
+, pick(0)
+, a1(a1)
+, a2(a2)
+, m_resizable(resizable)
 {
 	if (w() < MIN_WIDTH)
 		size(MIN_WIDTH, h());
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 int geBaseAction::handle(int e)
 {
-	switch (e) {
-		case FL_ENTER: {
-			hovered = true;
-			redraw();
-			return 1;
-		}
-		case FL_LEAVE: {
-			fl_cursor(FL_CURSOR_DEFAULT, FL_WHITE, FL_BLACK);
-			hovered = false;
-			redraw();
-			return 1;
-		}
-		case FL_MOVE: {
-			if (m_resizable) {
-				onLeftEdge  = false;
-				onRightEdge = false;
-				if (Fl::event_x() >= x() && Fl::event_x() < x() + HANDLE_WIDTH) {
-					onLeftEdge = true;
-					fl_cursor(FL_CURSOR_WE, FL_WHITE, FL_BLACK);
-				}
-				else
-				if (Fl::event_x() >= x() + w() - HANDLE_WIDTH && 
-					  Fl::event_x() <= x() + w()) {
-					onRightEdge = true;
-					fl_cursor(FL_CURSOR_WE, FL_WHITE, FL_BLACK);
-				}
-				else
-					fl_cursor(FL_CURSOR_DEFAULT, FL_WHITE, FL_BLACK);
+	switch (e)
+	{
+	case FL_ENTER:
+	{
+		hovered = true;
+		redraw();
+		return 1;
+	}
+	case FL_LEAVE:
+	{
+		fl_cursor(FL_CURSOR_DEFAULT, FL_WHITE, FL_BLACK);
+		hovered = false;
+		redraw();
+		return 1;
+	}
+	case FL_MOVE:
+	{
+		if (m_resizable)
+		{
+			onLeftEdge  = false;
+			onRightEdge = false;
+			if (Fl::event_x() >= x() && Fl::event_x() < x() + HANDLE_WIDTH)
+			{
+				onLeftEdge = true;
+				fl_cursor(FL_CURSOR_WE, FL_WHITE, FL_BLACK);
 			}
-			return 1;
+			else if (Fl::event_x() >= x() + w() - HANDLE_WIDTH &&
+			         Fl::event_x() <= x() + w())
+			{
+				onRightEdge = true;
+				fl_cursor(FL_CURSOR_WE, FL_WHITE, FL_BLACK);
+			}
+			else
+				fl_cursor(FL_CURSOR_DEFAULT, FL_WHITE, FL_BLACK);
 		}
-		default:
-			return Fl_Widget::handle(e);
+		return 1;
+	}
+	default:
+		return Fl_Widget::handle(e);
 	}
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geBaseAction::setLeftEdge(Pixel p)
 {
 	resize(p, y(), x() - p + w(), h());
@@ -102,10 +103,8 @@ void geBaseAction::setLeftEdge(Pixel p)
 		size(MIN_WIDTH, h());
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geBaseAction::setRightEdge(Pixel p)
 {
 	size(p, h());
@@ -113,21 +112,18 @@ void geBaseAction::setRightEdge(Pixel p)
 		size(MIN_WIDTH, h());
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geBaseAction::setPosition(Pixel p)
 {
 	position(p, y());
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 bool geBaseAction::isOnEdges() const
 {
 	return onLeftEdge || onRightEdge;
 }
-}} // giada::v::
\ No newline at end of file
+} // namespace v
+} // namespace giada
\ No newline at end of file
