@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,32 +24,27 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_BASE_ACTION_H
 #define GE_BASE_ACTION_H
 
-
-#include <FL/Fl_Box.H>
-#include "core/recorder.h"
 #include "core/types.h"
+#include "src/core/actions/actions.h"
+#include <FL/Fl_Box.H>
 
-
-namespace giada {
-namespace m 
+namespace giada::m
 {
 struct Action;
 }
-namespace v
+namespace giada::v
 {
 class geBaseAction : public Fl_Box
 {
 public:
-
 	static const Pixel MIN_WIDTH    = 12;
 	static const Pixel HANDLE_WIDTH = 6;
 
-	geBaseAction(Pixel x, Pixel y, Pixel w, Pixel h, bool resizable, 
-		m::Action a1, m::Action a2);
+	geBaseAction(Pixel x, Pixel y, Pixel w, Pixel h, bool resizable,
+	    m::Action a1, m::Action a2);
 
 	int handle(int e) override;
 
@@ -63,19 +58,18 @@ public:
 
 	void setPosition(Pixel p);
 
-	bool onRightEdge;
-	bool onLeftEdge;
-	bool hovered;
-	bool altered;
+	bool  onRightEdge;
+	bool  onLeftEdge;
+	bool  hovered;
+	bool  altered;
 	Pixel pick;
 
 	m::Action a1;
 	m::Action a2;
-	
+
 protected:
-	
 	bool m_resizable;
 };
-}} // giada::v::
+} // namespace giada::v
 
 #endif
