@@ -5,7 +5,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -25,34 +25,32 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_BASE_ACTION_EDITOR_H
 #define GE_BASE_ACTION_EDITOR_H
 
-
+#include "core/types.h"
 #include <FL/Fl_Group.H>
 
+namespace giada::c::actionEditor
+{
+struct Data;
+}
 
-namespace giada {
-namespace v
+namespace giada::v
 {
 class gdBaseActionEditor;
 class geBaseAction;
-
 class geBaseActionEditor : public Fl_Group
 {
 public:
+	/* updateActions
+	Rebuild the actions widgets from scratch. */
 
-	geBaseActionEditor(Pixel x, Pixel y, Pixel w, Pixel h);
-
-  /* updateActions
-  Rebuild the actions widgets from scratch. */
-  
-	virtual void rebuild() = 0;
+	virtual void rebuild(c::actionEditor::Data& d) = 0;
 
 	/* handle
 	Override base FL_Group events. */
-	
+
 	int handle(int e) override;
 
 	/* getActionAtCursor
@@ -62,6 +60,12 @@ public:
 	geBaseAction* getActionAtCursor() const;
 
 protected:
+	geBaseActionEditor(Pixel x, Pixel y, Pixel w, Pixel h, gdBaseActionEditor*);
+
+	c::actionEditor::Data* m_data;
+
+	/* m_base
+	Pointer to parent class. */
 
 	gdBaseActionEditor* m_base;
 
@@ -73,7 +77,7 @@ protected:
 	/* baseDraw
 	Draws basic things like borders and grids. Optional background clear. */
 
-  void baseDraw(bool clear=true) const;
+	void baseDraw(bool clear = true) const;
 
 	virtual void onAddAction()     = 0;
 	virtual void onDeleteAction()  = 0;
@@ -82,17 +86,15 @@ protected:
 	virtual void onRefreshAction() = 0;
 
 private:
-	
 	/* drawVerticals
 	Draws generic vertical lines (beats, bars, grid lines...). */
-	
+
 	void drawVerticals(int steps) const;
-	
+
 	int push();
 	int drag();
 	int release();
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
