@@ -4,7 +4,7 @@
 *
 * ------------------------------------------------------------------------------
 *
-* Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+* Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
@@ -24,21 +24,19 @@
 *
 * --------------------------------------------------------------------------- */
 
-
-#include <FL/Fl_Double_Window.H>
+#include "gui/elems/actionEditor/gridTool.h"
 #include "core/conf.h"
-#include "core/clock.h"
-#include "utils/math.h"
-#include "gui/elems/basics/choice.h"
 #include "gui/elems/basics/check.h"
-#include "gridTool.h"
+#include "gui/elems/basics/choice.h"
+#include "utils/math.h"
+#include <FL/Fl_Double_Window.H>
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-geGridTool::geGridTool(Pixel x, Pixel y)
-:	Fl_Group(x, y, 80, 20)
+geGridTool::geGridTool(Pixel x, Pixel y, m::Conf::Data& c, Frame framesInBeat)
+: Fl_Group(x, y, 80, 20)
+, m_conf(c)
+, m_framesInBeat(framesInBeat)
 {
 	gridType = new geChoice(x, y, 40, 20);
 	gridType->add("1");
@@ -54,69 +52,69 @@ geGridTool::geGridTool(Pixel x, Pixel y)
 
 	active = new geCheck(gridType->x() + gridType->w() + 4, y, 20, 20);
 
-	gridType->value(m::conf::conf.actionEditorGridVal);
-	active->value(m::conf::conf.actionEditorGridOn);
+	gridType->value(m_conf.actionEditorGridVal);
+	active->value(m_conf.actionEditorGridOn);
 
 	end();
+
+	gridType->copy_tooltip("Grid resolution");
+	active->copy_tooltip("Snap to grid");
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 geGridTool::~geGridTool()
 {
-	m::conf::conf.actionEditorGridVal = gridType->value();
-	m::conf::conf.actionEditorGridOn  = active->value();
+	m_conf.actionEditorGridVal = gridType->value();
+	m_conf.actionEditorGridOn  = active->value();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void geGridTool::cb_changeType(Fl_Widget *w, void *p) { ((geGridTool*)p)->cb_changeType(); }
-
+void geGridTool::cb_changeType(Fl_Widget* /*w*/, void* p) { ((geGridTool*)p)->cb_changeType(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void geGridTool::cb_changeType()
 {
 	window()->redraw();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 bool geGridTool::isOn() const
 {
 	return active->value();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 int geGridTool::getValue() const
 {
-	switch (gridType->value()) {
-		case 0:	return 1;
-		case 1: return 2;
-		case 2: return 3;
-		case 3: return 4;
-		case 4: return 6;
-		case 5: return 8;
-		case 6: return 16;
-		case 7: return 32;
+	switch (gridType->value())
+	{
+	case 0:
+		return 1;
+	case 1:
+		return 2;
+	case 2:
+		return 3;
+	case 3:
+		return 4;
+	case 4:
+		return 6;
+	case 5:
+		return 8;
+	case 6:
+		return 16;
+	case 7:
+		return 32;
 	}
 	return 0;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 Frame geGridTool::getSnapFrame(Frame v) const
 {
 	if (!isOn())
@@ -124,12 +122,10 @@ Frame geGridTool::getSnapFrame(Frame v) const
 	return u::math::quantize(v, getCellSize());
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 Frame geGridTool::getCellSize() const
 {
-	return m::clock::getFramesInBeat() / getValue();
+	return m_framesInBeat / getValue();
 }
-}} // giada::v::
\ No newline at end of file
+} // namespace giada::v
\ No newline at end of file
