@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,40 +24,35 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <FL/fl_draw.H>
-#include "core/const.h"
-#include "core/action.h"
-#include "core/midiEvent.h"
-#include "utils/math.h"
 #include "pianoItem.h"
+#include "core/const.h"
+#include "core/midiEvent.h"
+#include "src/core/actions/action.h"
+#include "utils/math.h"
+#include <FL/fl_draw.H>
 
-
-namespace giada {
+namespace giada
+{
 namespace v
 {
 gePianoItem::gePianoItem(Pixel X, Pixel Y, Pixel W, Pixel H, m::Action a1,
-	m::Action a2)
-: geBaseAction(X, Y, W, H, /*resizable=*/true, a1, a2),
-  m_ringLoop  (a2.isValid() && a1.frame > a2.frame),
-  m_orphaned  (!a2.isValid())
+    m::Action a2)
+: geBaseAction(X, Y, W, H, /*resizable=*/true, a1, a2)
+, m_ringLoop(a2.isValid() && a1.frame > a2.frame)
+, m_orphaned(!a2.isValid())
 {
 	m_resizable = isResizable();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 bool gePianoItem::isResizable() const
 {
 	return !(m_ringLoop || m_orphaned);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gePianoItem::draw()
 {
 	Fl_Color color = hovered ? G_COLOR_LIGHT_2 : G_COLOR_LIGHT_1;
@@ -65,31 +60,34 @@ void gePianoItem::draw()
 	Pixel by = y() + 2;
 	Pixel bh = h() - 3;
 
-	if (m_orphaned) {
+	if (m_orphaned)
+	{
 		fl_rect(x(), by, w(), bh, color);
 		fl_line(x(), by, x() + w(), by + bh);
 	}
-	else {
+	else
+	{
 		Pixel vh = calcVelocityH();
-		if (m_ringLoop) {
+		if (m_ringLoop)
+		{
 			fl_rect(x(), by, MIN_WIDTH, bh, color);
-			fl_line(x() + MIN_WIDTH, by + bh/2, x() + w(), by + bh/2);
+			fl_line(x() + MIN_WIDTH, by + bh / 2, x() + w(), by + bh / 2);
 			fl_rectf(x(), by + (bh - vh), MIN_WIDTH, vh, color);
 		}
-		else {
+		else
+		{
 			fl_rect(x(), by, w(), bh, color);
 			fl_rectf(x(), by + (bh - vh), w(), vh, color);
 		}
 	}
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 Pixel gePianoItem::calcVelocityH() const
 {
 	int v = a1.event.getVelocity();
 	return u::math::map<int, Pixel>(v, 0, G_MAX_VELOCITY, 0, h() - 3);
 }
-}} // giada::v::
\ No newline at end of file
+} // namespace v
+} // namespace giada
\ No newline at end of file
