@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,41 +24,33 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_PIANO_ITEM_H
 #define GE_PIANO_ITEM_H
 
-
 #include "baseAction.h"
 
-
-namespace giada {
-namespace m 
+namespace giada::m
 {
 struct Action;
 }
-namespace v
-{
-class gdActionEditor;
 
+namespace giada::v
+{
 class gePianoItem : public geBaseAction
 {
 public:
-
 	gePianoItem(int x, int y, int w, int h, m::Action a1, m::Action a2);
- 
+
 	void draw() override;
 
 	bool isResizable() const;
 
 private:
+	bool m_ringLoop;
+	bool m_orphaned;
 
-    bool m_ringLoop;
-    bool m_orphaned;
-
-    Pixel calcVelocityH() const;
+	Pixel calcVelocityH() const;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
