@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,56 +24,56 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_PIANO_ROLL_H
 #define GE_PIANO_ROLL_H
 
-
-#include <FL/fl_draw.H>
 #include "baseActionEditor.h"
+#include <FL/fl_draw.H>
 
-
-namespace giada {
-namespace m
+namespace giada::m
 {
-class MidiChannel;
-}	
-namespace v
+struct Action;
+}
+
+namespace giada::v
 {
 class gePianoRoll : public geBaseActionEditor
 {
 public:
+	static const int   MAX_KEYS    = 127;
+	static const int   MAX_OCTAVES = 9;
+	static const int   KEYS        = 12;
+	static const Pixel CELL_H      = 20;
+	static const Pixel CELL_W      = 40;
 
-	static const int MAX_KEYS    = 127;
-	static const int MAX_OCTAVES = 9;
-	static const int KEYS        = 12;
-	static const Pixel CELL_H    = 20;
-	static const Pixel CELL_W    = 40;
-
-	gePianoRoll(Pixel x, Pixel y, Pixel w);
+	gePianoRoll(Pixel x, Pixel y, gdBaseActionEditor* b);
 
 	void draw() override;
 	int  handle(int e) override;
 
-	void rebuild() override;
-
-	Pixel pick;
+	void rebuild(c::actionEditor::Data& d) override;
 
 private:
-
 	enum class Notes
 	{
-		G = 1, FS = 2, F = 3, E = 4, DS = 5, D = 6, CS = 7, C = 8, B = 9, AS = 10,
-		A = 11, GS = 0
+		G  = 1,
+		FS = 2,
+		F  = 3,
+		E  = 4,
+		DS = 5,
+		D  = 6,
+		CS = 7,
+		C  = 8,
+		B  = 9,
+		AS = 10,
+		A  = 11,
+		GS = 0
 	};
 
-	Fl_Offscreen surface1;  // notes, no repeat
-	Fl_Offscreen surface2;  // lines, x-repeat
-
-	void onAddAction()     override;
-	void onDeleteAction()  override;
-	void onMoveAction()    override;
-	void onResizeAction()  override;
+	void onAddAction() override;
+	void onDeleteAction() override;
+	void onMoveAction() override;
+	void onResizeAction() override;
 	void onRefreshAction() override;
 
 	/* drawSurface*
@@ -84,15 +84,23 @@ private:
 	containing the rest of the piano roll. The latter will then be tiled during
 	the ::draw() call. */
 
-	void drawSurface1();
-	void drawSurface2();
+	void drawSurfaceY();
+	void drawSurfaceX();
 
 	Pixel snapToY(Pixel p) const;
 	int   yToNote(Pixel y) const;
 	Pixel noteToY(int n) const;
 	Pixel getPianoItemW(Pixel x, const m::Action& a1, const m::Action& a2) const;
-};
-}} // giada::v::
 
+	Fl_Offscreen surfaceY; // vertical notes, no x-repeat
+	Fl_Offscreen surfaceX; // lines, x-repeat
+
+	/* m_pick
+	Y-coordinate of the click event when the user clicks on an empty area of the
+	piano roll. Used for right mouse button scrolling. */
+
+	Pixel m_pick;
+};
+} // namespace giada::v
 
 #endif
