@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,46 +24,45 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <FL/fl_draw.H>
-#include "core/channels/sampleChannel.h"
-#include "core/const.h"
-#include "core/action.h"
 #include "sampleAction.h"
+#include "core/const.h"
+#include "src/core/actions/action.h"
+#include <FL/fl_draw.H>
 
-
-namespace giada {
+namespace giada
+{
 namespace v
 {
-geSampleAction::geSampleAction(Pixel X, Pixel Y, Pixel W, Pixel H, 
-	bool singlePress, m::Action a1, m::Action a2)
-: geBaseAction (X, Y, W, H, singlePress, a1, a2),
-  m_singlePress(singlePress)
+geSampleAction::geSampleAction(Pixel X, Pixel Y, Pixel W, Pixel H,
+    bool singlePress, m::Action a1, m::Action a2)
+: geBaseAction(X, Y, W, H, singlePress, a1, a2)
+, m_singlePress(singlePress)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geSampleAction::draw()
 {
-	Fl_Color color = hovered ? G_COLOR_LIGHT_2 : G_COLOR_LIGHT_1; 
+	Fl_Color color = hovered ? G_COLOR_LIGHT_2 : G_COLOR_LIGHT_1;
 
-	if (m_singlePress) {
+	if (m_singlePress)
+	{
 		fl_rectf(x(), y(), w(), h(), color);
 	}
-	else {
+	else
+	{
 		if (a1.event.getStatus() == m::MidiEvent::NOTE_KILL)
 			fl_rect(x(), y(), MIN_WIDTH, h(), color);
-		else {
+		else
+		{
 			fl_rectf(x(), y(), MIN_WIDTH, h(), color);
 			if (a1.event.getStatus() == m::MidiEvent::NOTE_ON)
-				fl_rectf(x()+3, y()+h()-11, w()-6, 8, G_COLOR_GREY_4);
-			else
-			if (a1.event.getStatus() == m::MidiEvent::NOTE_OFF)
-				fl_rectf(x()+3, y()+3, w()-6, 8, G_COLOR_GREY_4);
+				fl_rectf(x() + 3, y() + h() - 11, w() - 6, 8, G_COLOR_GREY_4);
+			else if (a1.event.getStatus() == m::MidiEvent::NOTE_OFF)
+				fl_rectf(x() + 3, y() + 3, w() - 6, 8, G_COLOR_GREY_4);
 		}
 	}
 }
-}} // giada::v::
+} // namespace v
+} // namespace giada
