@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,36 +24,25 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_SAMPLE_ACTION_H
 #define GE_SAMPLE_ACTION_H
 
-
-#include "core/recorder.h"
 #include "baseAction.h"
+#include "src/core/actions/actions.h"
 
-
-namespace giada {
-namespace m
-{
-class SampleChannel;
-}
-namespace v
+namespace giada::v
 {
 class geSampleAction : public geBaseAction
 {
 public:
-
-	geSampleAction(Pixel x, Pixel y, Pixel w, Pixel h, bool singlePress, 
-		m::Action a1, m::Action a2);
+	geSampleAction(Pixel x, Pixel y, Pixel w, Pixel h, bool singlePress,
+	    m::Action a1, m::Action a2);
 
 	void draw() override;
 
 private:
-
 	bool m_singlePress;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
