@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,45 +24,37 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_SAMPLE_ACTION_EDITOR_H
 #define GE_SAMPLE_ACTION_EDITOR_H
 
-
 #include "baseActionEditor.h"
 
-
-namespace giada {
-namespace m
+namespace giada::m
 {
-class SampleChannel;
 struct Action;
 }
-namespace v
+
+namespace giada::v
 {
 class geSampleAction;
-
 class geSampleActionEditor : public geBaseActionEditor
 {
 public:
-
-	geSampleActionEditor(Pixel x, Pixel y);
-	~geSampleActionEditor();
+	geSampleActionEditor(Pixel x, Pixel y, gdBaseActionEditor*);
 
 	void draw() override;
 
-	void rebuild() override;
+	void rebuild(c::actionEditor::Data& d) override;
 
 private:
-
-	void onAddAction()     override;
-	void onDeleteAction()  override;
-	void onMoveAction()    override;
-	void onResizeAction()  override;
+	void onAddAction() override;
+	void onDeleteAction() override;
+	void onMoveAction() override;
+	void onResizeAction() override;
 	void onRefreshAction() override;
 
-    bool isNoteOffSinglePress(const m::Action& a);
+	bool isNoteOffSinglePress(const m::Action& a);
 };
-}} // giada::v::
+} // namespace giada::v
 
 #endif
