@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,95 +24,78 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cassert>
-#include <FL/Fl.H>
-#include <FL/fl_draw.H>
-#include "utils/log.h"
-#include "utils/math.h"
-#include "core/channels/midiChannel.h"
-#include "core/const.h"
+#include "velocityEditor.h"
 #include "core/conf.h"
-#include "core/action.h"
-#include "core/clock.h"
+#include "core/const.h"
+#include "envelopePoint.h"
 #include "glue/actionEditor.h"
 #include "gui/dialogs/actionEditor/baseActionEditor.h"
-#include "envelopePoint.h"
-#include "velocityEditor.h"
+#include "src/core/actions/action.h"
+#include "utils/log.h"
+#include "utils/math.h"
+#include <FL/Fl.H>
+#include <FL/fl_draw.H>
+#include <cassert>
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-geVelocityEditor::geVelocityEditor(Pixel x, Pixel y)
-:	geBaseActionEditor(x, y, 200, m::conf::conf.velocityEditorH)
+geVelocityEditor::geVelocityEditor(Pixel x, Pixel y, gdBaseActionEditor* b)
+: geBaseActionEditor(x, y, 200, 40, b)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-geVelocityEditor::~geVelocityEditor()
-{
-	m::conf::conf.velocityEditorH = h();
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void geVelocityEditor::draw() 
+void geVelocityEditor::draw()
 {
 	baseDraw();
 
+	if (h() < geEnvelopePoint::SIDE)
+		return;
+
 	/* Print label. */
 
 	fl_color(G_COLOR_GREY_4);
 	fl_font(FL_HELVETICA, G_GUI_FONT_SIZE_BASE);
-	fl_draw("Velocity", x()+4, y(), w(), h(), (Fl_Align) (FL_ALIGN_LEFT));
+	fl_draw("Velocity", x() + 4, y(), w(), h(), FL_ALIGN_LEFT);
 
 	if (children() == 0)
 		return;
 
-	Pixel side = geEnvelopePoint::SIDE / 2;
+	const Pixel side = geEnvelopePoint::SIDE / 2;
 
-	for (int i=0; i<children(); i++) {
+	for (int i = 0; i < children(); i++)
+	{
 		geEnvelopePoint* p = static_cast<geEnvelopePoint*>(child(i));
 		if (m_action == nullptr)
 			p->position(p->x(), valueToY(p->a1.event.getVelocity()));
-		Pixel x1 = p->x() + side;
-		Pixel y1 = p->y();
-		Pixel y2 = y() + h();
+		const Pixel x1 = p->x() + side;
+		const Pixel y1 = p->y();
+		const Pixel y2 = y() + h();
 		fl_line(x1, y1, x1, y2);
 	}
 
 	draw_children();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 Pixel geVelocityEditor::valueToY(int v) const
 {
 	/* Cast the input type of 'v' to float, to make the mapping more precise. */
 	return u::math::map<float, Pixel>(v, 0, G_MAX_VELOCITY, y() + (h() - geEnvelopePoint::SIDE), y());
 }
 
-
 int geVelocityEditor::yToValue(Pixel px) const
 {
-	return u::math::map<Pixel, int>(px, h() - geEnvelopePoint::SIDE, 0, 0, G_MAX_VELOCITY);	
+	return u::math::map<Pixel, int>(px, h() - geEnvelopePoint::SIDE, 0, 0, G_MAX_VELOCITY);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void geVelocityEditor::rebuild()
+void geVelocityEditor::rebuild(c::actionEditor::Data& d)
 {
-	namespace ca = c::actionEditor;
+	m_data = &d;
 
 	/* Remove all existing actions and set a new width, according to the current
 	zoom level. */
@@ -120,8 +103,9 @@ void geVelocityEditor::rebuild()
 	clear();
 	size(m_base->fullWidth, h());
 
-	for (const m::Action& action : m_base->getActions())
+	for (const m::Action& action : m_data->actions)
 	{
+
 		if (action.event.getStatus() == m::MidiEvent::NOTE_OFF)
 			continue;
 
@@ -130,36 +114,35 @@ void geVelocityEditor::rebuild()
 
 		add(new geEnvelopePoint(px, py, action));
 	}
-	
+
 	resizable(nullptr);
 	redraw();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void geVelocityEditor::onMoveAction()    
+void geVelocityEditor::onMoveAction()
 {
 	Pixel ey = Fl::event_y() - (geEnvelopePoint::SIDE / 2);
 
 	Pixel y1 = y();
 	Pixel y2 = y() + h() - geEnvelopePoint::SIDE;
 
-	if (ey < y1) ey = y1; else if (ey > y2) ey = y2;
+	if (ey < y1)
+		ey = y1;
+	else if (ey > y2)
+		ey = y2;
 
 	m_action->position(m_action->x(), ey);
 	redraw();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void geVelocityEditor::onRefreshAction() 
+void geVelocityEditor::onRefreshAction()
 {
 	c::actionEditor::updateVelocity(m_action->a1, yToValue(m_action->y() - y()));
 
-	m_base->rebuild();  // Rebuild pianoRoll as well
+	m_base->rebuild(); // Rebuild pianoRoll as well
 }
-}} // giada::v::
+} // namespace giada::v
\ No newline at end of file
