@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,18 +24,34 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "../../../core/const.h"
 #include "box.h"
+#include "core/const.h"
+#include "utils/gui.h"
+#include <FL/fl_draw.H>
 
-
-geBox::geBox(int x, int y, int w, int h, const char *l, Fl_Align al)
+geBox::geBox(int x, int y, int w, int h, const char* l, Fl_Align al)
 : Fl_Box(x, y, w, h)
 {
-  copy_label(l);
-  labelsize(G_GUI_FONT_SIZE_BASE);
-  box(FL_NO_BOX);
-  labelcolor(G_COLOR_LIGHT_2);
-  if (al != 0)
-    align(al | FL_ALIGN_INSIDE);
+	copy_label(l);
+	box(FL_NO_BOX);
+	align(al | FL_ALIGN_INSIDE);
 }
+
+/* -------------------------------------------------------------------------- */
+
+void geBox::draw()
+{
+	fl_rectf(x(), y(), w(), h(), G_COLOR_GREY_1); // Clear background
+
+	if (box() != FL_NO_BOX)
+		fl_rect(x(), y(), w(), h(), G_COLOR_GREY_4); // Border
+
+	if (image() != nullptr)
+		draw_label(); // draw_label also paints image, if any
+	else if (label() != nullptr)
+	{
+		fl_color(G_COLOR_LIGHT_2);
+		fl_font(FL_HELVETICA, G_GUI_FONT_SIZE_BASE);
+		fl_draw(giada::u::gui::truncate(label(), w() - 8).c_str(), x() + 4, y(), w() - 4, h(), align());
+	}
+}
\ No newline at end of file
