@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,22 +26,17 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_BOXTYPES_H
 #define GE_BOXTYPES_H
 
-
 #include <FL/Fl.H>
 
-
-#define G_CUSTOM_BORDER_BOX FL_FREE_BOXTYPE
-#define G_CUSTOM_UP_BOX     (Fl_Boxtype)(FL_FREE_BOXTYPE + 1)
-#define G_CUSTOM_DOWN_BOX   (Fl_Boxtype)(FL_FREE_BOXTYPE + 3)
-
+constexpr Fl_Boxtype G_CUSTOM_BORDER_BOX = FL_FREE_BOXTYPE;
+constexpr Fl_Boxtype G_CUSTOM_UP_BOX     = static_cast<Fl_Boxtype>(FL_FREE_BOXTYPE + 1);
+constexpr Fl_Boxtype G_CUSTOM_DOWN_BOX   = static_cast<Fl_Boxtype>(FL_FREE_BOXTYPE + 3);
 
 void g_customBorderBox(int x, int y, int w, int h, Fl_Color c);
-void g_customUpBox    (int x, int y, int w, int h, Fl_Color c);
-void g_customDownBox  (int x, int y, int w, int h, Fl_Color c);
-
+void g_customUpBox(int x, int y, int w, int h, Fl_Color c);
+void g_customDownBox(int x, int y, int w, int h, Fl_Color c);
 
 #endif
