@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,36 +24,52 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <FL/fl_draw.H>
-#include "core/const.h"
 #include "check.h"
-
+#include "core/const.h"
+#include <FL/fl_draw.H>
+#include <cstring>
 
 geCheck::geCheck(int x, int y, int w, int h, const char* l)
 : Fl_Check_Button(x, y, w, h, l)
 {
+	callback(cb_onChange, this);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
+void geCheck::cb_onChange(Fl_Widget* /*w*/, void* p) { (static_cast<geCheck*>(p))->cb_onChange(); }
+
+/* -------------------------------------------------------------------------- */
+
+void geCheck::cb_onChange()
+{
+	if (onChange != nullptr)
+		onChange(value());
+}
+
+/* -------------------------------------------------------------------------- */
 
 void geCheck::draw()
 {
-	int color = !active() ? FL_INACTIVE_COLOR : G_COLOR_GREY_4;
+	fl_rectf(x(), y(), w(), h(), FL_BACKGROUND_COLOR); // clearer
 
-	if (value()) {
-		fl_rect(x(), y(), 12, h(), (Fl_Color) color);
-		fl_rectf(x(), y(), 12, h(), (Fl_Color) color);
-	}
-	else {
-		fl_rectf(x(), y(), 12, h(), FL_BACKGROUND_COLOR);
-		fl_rect(x(), y(), 12, h(), (Fl_Color) color);
-	}
+	const Fl_Color boxColor  = !active() ? FL_INACTIVE_COLOR : G_COLOR_GREY_4;
+	const int      textColor = !active() ? FL_INACTIVE_COLOR : G_COLOR_LIGHT_2;
+	const Fl_Align textAlign = hasMultilineText() ? FL_ALIGN_LEFT | FL_ALIGN_TOP : FL_ALIGN_LEFT | FL_ALIGN_CENTER;
+
+	if (value())
+		fl_rectf(x(), y(), 12, h(), boxColor);
+	else
+		fl_rect(x(), y(), 12, h(), boxColor);
 
-	fl_rectf(x()+20, y(), w(), h(), FL_BACKGROUND_COLOR);  // clearer
 	fl_font(FL_HELVETICA, G_GUI_FONT_SIZE_BASE);
-	fl_color(!active() ? FL_INACTIVE_COLOR : G_COLOR_LIGHT_2);
-	fl_draw(label(), x()+20, y(), w(), h(), (Fl_Align) (FL_ALIGN_LEFT | FL_ALIGN_CENTER));
+	fl_color(textColor);
+	fl_draw(label(), x() + 20, y(), w(), h(), textAlign);
+}
+
+/* -------------------------------------------------------------------------- */
+
+bool geCheck::hasMultilineText() const
+{
+	return label() == nullptr ? false : std::strchr(label(), '\n') != nullptr;
 }
