@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,19 +24,23 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_INPUT_H
 #define GE_INPUT_H
 
-
 #include <FL/Fl_Input.H>
-
+#include <functional>
+#include <string>
 
 class geInput : public Fl_Input
 {
 public:
+	geInput(int x, int y, int w, int h, const char* l = 0);
 
-	geInput(int x, int y, int w, int h, const char *l=0);
+	std::function<void(const std::string&)> onChange = nullptr;
+
+private:
+	static void cb_onChange(Fl_Widget* w, void* p);
+	void        cb_onChange();
 };
 
 #endif
