@@ -9,7 +9,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -29,30 +29,32 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "core/const.h"
-#include "boxtypes.h"
 #include "liquidScroll.h"
+#include "boxtypes.h"
+#include "core/const.h"
 
-
-geLiquidScroll::geLiquidScroll(int x, int y, int w, int h)
-: geScroll(x, y, w, h, Fl_Scroll::VERTICAL_ALWAYS)
+namespace giada::v
+{
+geLiquidScroll::geLiquidScroll(int x, int y, int w, int h, Direction d)
+: geScroll(x, y, w, h, d == Direction::VERTICAL ? Fl_Scroll::VERTICAL_ALWAYS : Fl_Scroll::HORIZONTAL_ALWAYS)
+, m_direction(d)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geLiquidScroll::resize(int X, int Y, int W, int H)
 {
-	int nc = children()-2;               // skip hscrollbar and vscrollbar
-	for (int t=0; t<nc; t++) {           // tell children to resize to our new width
+	const int nc = children() - 2; // skip hscrollbar and vscrollbar
+	for (int t = 0; t < nc; t++)   // tell children to resize to our new width
+	{
 		Fl_Widget* c = child(t);
-		c->resize(c->x(), c->y(), W-24, c->h());    // W-24: leave room for scrollbar
+		if (m_direction == Direction::VERTICAL)
+			c->resize(c->x(), c->y(), W - 24, c->h()); // -24: leave room for scrollbar
+		else
+			c->resize(c->x(), c->y(), c->w(), H - 24); // -24: leave room for scrollbar
 	}
-	init_sizes();   // tell scroll children changed in size
-	Fl_Scroll::resize(X,Y,W,H);
+	init_sizes(); // tell scroll children changed in size
+	Fl_Scroll::resize(X, Y, W, H);
 }
-
-
+} // namespace giada::v
\ No newline at end of file
