@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,15 +24,16 @@
  *
  * -------------------------------------------------------------------------- */
 
+#include "gui/elems/basics/progress.h"
+#include "core/const.h"
+#include "gui/elems/basics/boxtypes.h"
 
-#include "../../../core/const.h"
-#include "boxtypes.h"
-#include "progress.h"
-
-
-geProgress::geProgress(int x, int y, int w, int h, const char *l)
+namespace giada::v
+{
+geProgress::geProgress(int x, int y, int w, int h, const char* l)
 : Fl_Progress(x, y, w, h, l)
 {
-  color(G_COLOR_GREY_2, G_COLOR_GREY_4);
-  box(G_CUSTOM_BORDER_BOX);
+	color(G_COLOR_GREY_2, G_COLOR_GREY_4);
+	box(G_CUSTOM_BORDER_BOX);
 }
+} // namespace giada::v
\ No newline at end of file
