@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,20 +24,18 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_PROGRESS_H
 #define GE_PROGRESS_H
 
-
 #include <FL/Fl_Progress.H>
 
-
+namespace giada::v
+{
 class geProgress : public Fl_Progress
 {
 public:
-
-	geProgress(int x, int y, int w, int h, const char *l=0);
+	geProgress(int x, int y, int w, int h, const char* l = 0);
 };
-
+} // namespace giada::v
 
 #endif
