@@ -7,7 +7,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,22 +27,27 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_SCROLL_H
 #define GE_SCROLL_H
 
-
 #include <FL/Fl_Scroll.H>
-
+#include <functional>
 
 class geScroll : public Fl_Scroll
 {
 public:
+	geScroll(int x, int y, int w, int h, int type = Fl_Scroll::BOTH);
 
-	geScroll(int x, int y, int w, int h, int type=Fl_Scroll::BOTH);
+	int countChildren() const;
 
-    int countChildren() const;
+	std::function<void(int)> onScrollV{nullptr};
+	std::function<void(int)> onScrollH{nullptr};
+
+private:
+	static void cb_onScrollV(Fl_Widget* w, void* p);
+	static void cb_onScrollH(Fl_Widget* w, void* p);
+	void        cb_onScrollV();
+	void        cb_onScrollH();
 };
 
-
 #endif
