@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,65 +24,68 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_TAB_AUDIO_H
 #define GE_TAB_AUDIO_H
 
-
+#include "glue/config.h"
+#include "gui/elems/basics/choice.h"
 #include <FL/Fl_Group.H>
 
-
-class geChoice;
 class geCheck;
 class geButton;
 class geInput;
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
 class geTabAudio : public Fl_Group
 {
 public:
+	struct geDeviceMenu : public geChoice
+	{
+		geDeviceMenu(int x, int y, int w, int h, const char* l, const std::vector<c::config::AudioDeviceData>&);
+	};
+
+	struct geChannelMenu : public geChoice
+	{
+		geChannelMenu(int x, int y, int w, int h, const char* l, const c::config::AudioDeviceData&);
+
+		int getChannelsCount() const;
+		int getChannelsStart() const;
+
+		void rebuild(const c::config::AudioDeviceData&);
+
+	private:
+		static constexpr int STEREO_OFFSET = 1000;
+
+		c::config::AudioDeviceData m_data;
+	};
 
 	geTabAudio(int x, int y, int w, int h);
 
 	void save();
 
-	geChoice* soundsys;
-	geChoice* buffersize;
-	geChoice* samplerate;
-	geChoice* sounddevOut;
-	geButton* devOutInfo;
-	geChoice* channelsOut;
-	geCheck*  limitOutput;
-	geChoice* sounddevIn;
-	geButton* devInInfo;
-	geChoice* channelsIn;
-	geInput*  recTriggerLevel;
-	geChoice* rsmpQuality;
+	geChoice*      soundsys;
+	geChoice*      buffersize;
+	geChoice*      samplerate;
+	geDeviceMenu*  sounddevOut;
+	geChannelMenu* channelsOut;
+	geCheck*       limitOutput;
+	geDeviceMenu*  sounddevIn;
+	geCheck*       enableIn;
+	geChannelMenu* channelsIn;
+	geInput*       recTriggerLevel;
+	geChoice*      rsmpQuality;
 
 private:
+	void invalidate();
+	void fetch();
+	void deactivateAll();
+	void activateAll();
 
-	static void cb_deactivate_sounddev(Fl_Widget* w, void* p);
-	static void cb_fetchInChans       (Fl_Widget* w, void* p);
-	static void cb_fetchOutChans      (Fl_Widget* w, void* p);
-	static void cb_showInputInfo      (Fl_Widget* w, void* p);
-	static void cb_showOutputInfo     (Fl_Widget* w, void* p);
-	void cb_deactivate_sounddev();
-	void cb_fetchInChans();
-	void cb_fetchOutChans();
-	void cb_showInputInfo();
-	void cb_showOutputInfo();
+	c::config::AudioData m_data;
 
-	void fetchSoundDevs();
-	void fetchInChans(int menuItem);
-	void fetchOutChans(int menuItem);
-	int  findMenuDevice(geChoice* m, int device);
-
-	int soundsysInitValue;
+	int m_initialApi;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
