@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,43 +24,32 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_TAB_BEHAVIORS_H
 #define GE_TAB_BEHAVIORS_H
 
-
+#include "core/conf.h"
+#include "gui/elems/basics/check.h"
+#include "gui/elems/basics/pack.h"
 #include <FL/Fl_Group.H>
 
-
-class geRadio;
-class geCheck;
-
-
-namespace giada {
-namespace v
+namespace giada::v
 {
 class geTabBehaviors : public Fl_Group
 {
 public:
-
-	geTabBehaviors(int x, int y, int w, int h);
+	geTabBehaviors(int x, int y, int w, int h, m::Conf::Data&);
 
 	void save();
 
-	geRadio *recsStopOnChanHalt_1;
-	geRadio *recsStopOnChanHalt_0;
-	geRadio *chansStopOnSeqHalt_1;
-	geRadio *chansStopOnSeqHalt_0;
-	geCheck *treatRecsAsLoops;
-	geCheck *inputMonitorDefaultOn;
-
-
 private:
+	gePack  m_container;
+	geCheck m_chansStopOnSeqHalt;
+	geCheck m_treatRecsAsLoops;
+	geCheck m_inputMonitorDefaultOn;
+	geCheck m_overdubProtectionDefaultOn;
 
-	static void cb_radio_mutex(Fl_Widget* w, void* p);
-	void cb_radio_mutex(Fl_Widget* w);
+	m::Conf::Data& m_conf;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
