@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,48 +24,45 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_TAB_MIDI_H
 #define GE_TAB_MIDI_H
 
-
+#include "glue/config.h"
+#include "gui/elems/basics/choice.h"
 #include <FL/Fl_Group.H>
 
-
-class geChoice;
 class geCheck;
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
 class geTabMidi : public Fl_Group
 {
 public:
+	struct geMenu : public geChoice
+	{
+		geMenu(int x, int y, int w, int h, const char* l, const std::vector<std::string>&,
+		    const std::string& msgIfNotFound);
+	};
 
 	geTabMidi(int x, int y, int w, int h);
 
-	void save();
+	void save() const;
 
 	geChoice* system;
-	geChoice* portOut;
-	geChoice* portIn;
-	geChoice* midiMap;
+	geMenu*   portOut;
+	geMenu*   portIn;
+	geCheck*  enableOut;
+	geCheck*  enableIn;
+	geMenu*   midiMap;
 	geChoice* sync;
 
 private:
+	void invalidate();
 
-	void fetchSystems();
-	void fetchOutPorts();
-	void fetchInPorts();
-	void fetchMidiMaps();
+	c::config::MidiData m_data;
 
-	static void cb_changeSystem(Fl_Widget* w, void* p);
-	void cb_changeSystem();
-
-	int systemInitValue;
+	int m_initialApi;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
