@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,59 +24,41 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "core/const.h"
-#include "core/conf.h"
-#include "gui/elems/basics/choice.h"
 #include "tabMisc.h"
+#include "core/const.h"
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-geTabMisc::geTabMisc(int X, int Y, int W, int H)
-: Fl_Group(X, Y, W, H, "Misc")
+geTabMisc::geTabMisc(int X, int Y, int W)
+: geGroup(X, Y)
+, m_data(c::config::getMiscData())
+, m_debugMsg(W - 230, 9, 230, 20, "Debug messages")
+, m_tooltips(W - 230, 37, 230, 20, "Tooltips")
 {
-	begin();
-	debugMsg = new geChoice(x()+w()-230, y()+9, 230, 20, "Debug messages");
-	end();
+	add(&m_debugMsg);
+	add(&m_tooltips);
 
-	debugMsg->add("(disabled)");
-	debugMsg->add("To standard output");
-	debugMsg->add("To file");
+	m_debugMsg.addItem("Disabled");
+	m_debugMsg.addItem("To standard output");
+	m_debugMsg.addItem("To file");
+	m_debugMsg.onChange = [this](ID id) { m_data.logMode = id; };
 
+	m_tooltips.addItem("Disabled");
+	m_tooltips.addItem("Enabled");
+	m_tooltips.onChange = [this](ID id) { m_data.showTooltips = id; };
+
+	m_debugMsg.showItem(m_data.logMode);
+	m_tooltips.showItem(m_data.showTooltips);
+
+	copy_label("Misc");
 	labelsize(G_GUI_FONT_SIZE_BASE);
 	selection_color(G_COLOR_GREY_4);
-
-	switch (m::conf::conf.logMode) {
-		case LOG_MODE_MUTE:
-			debugMsg->value(0);
-			break;
-		case LOG_MODE_STDOUT:
-			debugMsg->value(1);
-			break;
-		case LOG_MODE_FILE:
-			debugMsg->value(2);
-			break;
-	}
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geTabMisc::save()
 {
-	switch(debugMsg->value()) {
-		case 0:
-			m::conf::conf.logMode = LOG_MODE_MUTE;
-			break;
-		case 1:
-			m::conf::conf.logMode = LOG_MODE_STDOUT;
-			break;
-		case 2:
-			m::conf::conf.logMode = LOG_MODE_FILE;
-			break;
-	}
+	c::config::save(m_data);
 }
-}} // giada::v::
\ No newline at end of file
+} // namespace giada::v
\ No newline at end of file
