@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,31 +24,28 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_TAB_MISC_H
 #define GE_TAB_MISC_H
 
+#include "glue/config.h"
+#include "gui/elems/basics/choice.h"
+#include "gui/elems/basics/group.h"
 
-#include <FL/Fl_Group.H>
-
-
-class geChoice;
-
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-class geTabMisc : public Fl_Group
+class geTabMisc : public geGroup
 {
 public:
-
-	geTabMisc(int x, int y, int w, int h);
+	geTabMisc(int x, int y, int w);
 
 	void save();
 
-	geChoice* debugMsg;
-};
-}} // giada::v::
+private:
+	c::config::MiscData m_data;
 
+	geChoice m_debugMsg;
+	geChoice m_tooltips;
+};
+} // namespace giada::v
 
 #endif
