@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,52 +24,42 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_TAB_PLUGINS_H
 #define GE_TAB_PLUGINS_H
 
-
 #ifdef WITH_VST
 
-
+#include "glue/config.h"
+#include "gui/elems/basics/box.h"
+#include "gui/elems/basics/button.h"
+#include "gui/elems/basics/input.h"
 #include <FL/Fl_Group.H>
 
-
-class geInput;
-class geButton;
-class geBox;
-
-
-namespace giada {
-namespace v
+namespace giada::v
 {
 class geTabPlugins : public Fl_Group
 {
 public:
-
 	geTabPlugins(int x, int y, int w, int h);
 
 	void save();
-	void refreshVstPath();
+	void rebuild();
 
 private:
+	static void cb_scan(Fl_Widget* /*w*/, void* p);
+	static void cb_browse(Fl_Widget* /*w*/, void* p);
+	void        cb_scan();
+	void        cb_browse();
 
-	static void cb_scan(Fl_Widget* w, void* p);
-	static void cb_browse(Fl_Widget* w, void* p);
-	void cb_scan();
-	void cb_browse();
+	c::config::PluginData m_data;
 
-	void refreshCount();
-
-	geInput*  m_folderPath;
-	geButton* m_browse;
-	geButton* m_scanButton;
-	geBox*    m_info;
+	geButton m_browse;
+	geInput  m_folderPath;
+	geButton m_scanButton;
+	geBox    m_info;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif // WITH_VST
 
-
 #endif
