@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,35 +24,25 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_CHANNEL_H
 #define GE_CHANNEL_H
 
-
-#include <FL/Fl_Group.H>
 #include "core/types.h"
+#include "glue/channel.h"
+#include <FL/Fl_Group.H>
 
-
-class geChannelStatus;
 class geButton;
 class geDial;
+
+namespace giada::v
+{
+class geChannelStatus;
 class geStatusButton;
-
-
-namespace giada {
-namespace m
-{
-class Channel;
-}
-namespace v
-{
 class geChannelButton;
-
 class geChannel : public Fl_Group
 {
 public:
-
-	geChannel(int x, int y, int w, int h, ID channelId);
+	geChannel(int x, int y, int w, int h, c::channel::Data d);
 
 	void draw() override;
 
@@ -72,8 +62,11 @@ public:
 
 	bool handleKey(int e);
 
-	ID channelId;
- 
+	/* getData
+	Returns a reference to the internal data. Read-only. */
+
+	const c::channel::Data& getData() const;
+
 	geStatusButton*  playButton;
 	geButton*        arm;
 	geChannelStatus* status;
@@ -82,11 +75,10 @@ public:
 	geStatusButton*  solo;
 	geDial*          vol;
 #ifdef WITH_VST
-	geStatusButton*  fx;
+	geStatusButton* fx;
 #endif
 
 protected:
-
 	/* Define some breakpoints for dynamic resize. BREAK_DELTA: base amount of
 	pixels to shrink sampleButton. */
 
@@ -103,19 +95,19 @@ protected:
 
 	static const int MIN_ELEM_W = 20;
 
-	static void cb_arm(Fl_Widget* v, void* p);
-	static void cb_mute(Fl_Widget* v, void* p);
-	static void cb_solo(Fl_Widget* v, void* p);
-	static void cb_changeVol(Fl_Widget* v, void* p);
+	static void cb_arm(Fl_Widget* /*w*/, void* p);
+	static void cb_mute(Fl_Widget* /*w*/, void* p);
+	static void cb_solo(Fl_Widget* /*w*/, void* p);
+	static void cb_changeVol(Fl_Widget* /*w*/, void* p);
 #ifdef WITH_VST
-	static void cb_openFxWindow(Fl_Widget* v, void* p);
+	static void cb_openFxWindow(Fl_Widget* /*w*/, void* p);
 #endif
 	void cb_mute();
 	void cb_arm();
 	void cb_solo();
 	void cb_changeVol();
 #ifdef WITH_VST
-		void cb_openFxWindow();
+	void cb_openFxWindow();
 #endif
 
 	/* blink
@@ -127,8 +119,12 @@ protected:
 	Spread widgets across available space. */
 
 	void packWidgets();
-};
-}} // giada::v::
 
+	/* m_channel
+	Channel's data. */
+
+	c::channel::Data m_channel;
+};
+} // namespace giada::v
 
 #endif
