@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,108 +24,91 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <FL/fl_draw.H>
-#include "core/channels/channel.h"
-#include "core/model/model.h"
-#include "core/const.h"
-#include "core/recorder.h"
-#include "utils/string.h"
 #include "channelButton.h"
+#include "core/channels/channel.h"
+#include "core/const.h"
+#include "core/model/model.h"
+#include "glue/channel.h"
+#include "src/core/actions/actions.h"
+#include "utils/string.h"
+#include <FL/fl_draw.H>
 
-
-namespace giada {
+namespace giada
+{
 namespace v
 {
-geChannelButton::geChannelButton(int x, int y, int w, int h, ID channelId)
-: geButton   (x, y, w, h), 
-  m_channelId(channelId),
-  m_key      ("")
+geChannelButton::geChannelButton(int x, int y, int w, int h, const c::channel::Data& d)
+: geButton(x, y, w, h)
+, m_channel(d)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geChannelButton::refresh()
 {
-	m::model::onGet(m::model::channels, m_channelId, [&](m::Channel& c)
+	switch (m_channel.getPlayStatus())
 	{
-		switch (c.playStatus) {
-			case ChannelStatus::OFF:
-			case ChannelStatus::EMPTY:
-				setDefaultMode(); break;
-			case ChannelStatus::PLAY:
-				setPlayMode(); break;
-			case ChannelStatus::ENDING:
-				setEndingMode(); break;
-			default: break;
-		}
-
-		switch (c.recStatus) {
-			case ChannelStatus::ENDING:
-				setEndingMode(); break;
-			default: break;
-		}
-	});
+	case ChannelStatus::OFF:
+	case ChannelStatus::EMPTY:
+		setDefaultMode();
+		break;
+	case ChannelStatus::PLAY:
+		setPlayMode();
+		break;
+	case ChannelStatus::ENDING:
+		setEndingMode();
+		break;
+	default:
+		break;
+	}
+	switch (m_channel.getRecStatus())
+	{
+	case ChannelStatus::ENDING:
+		setEndingMode();
+		break;
+	default:
+		break;
+	}
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void geChannelButton::setKey(int k)
-{
-	m_key = k == 0 ? "" : std::string(1, k);
-	redraw();
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 void geChannelButton::draw()
 {
 	geButton::draw();
 
-	if (m_key == "")
+	if (m_channel.key == 0)
 		return;
 
 	/* draw background */
 
-	fl_rectf(x()+1, y()+1, 18, h()-2, bgColor0);
+	fl_rectf(x() + 1, y() + 1, 18, h() - 2, bgColor0);
 
 	/* draw m_key */
 
 	fl_color(G_COLOR_LIGHT_2);
 	fl_font(FL_HELVETICA, 11);
-	fl_draw(m_key.c_str(), x(), y(), 18, h(), FL_ALIGN_CENTER);
+	fl_draw(std::string(1, static_cast<wchar_t>(m_channel.key)).c_str(), x(), y(), 18, h(), FL_ALIGN_CENTER);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geChannelButton::setInputRecordMode()
 {
 	bgColor0 = G_COLOR_RED;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geChannelButton::setActionRecordMode()
 {
 	bgColor0 = G_COLOR_BLUE;
 	txtColor = G_COLOR_LIGHT_2;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geChannelButton::setDefaultMode(const char* l)
 {
 	bgColor0 = G_COLOR_GREY_2;
@@ -135,10 +118,8 @@ void geChannelButton::setDefaultMode(const char* l)
 		label(l);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geChannelButton::setPlayMode()
 {
 	bgColor0 = G_COLOR_LIGHT_1;
@@ -146,13 +127,11 @@ void geChannelButton::setPlayMode()
 	txtColor = G_COLOR_GREY_1;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geChannelButton::setEndingMode()
 {
 	bgColor0 = G_COLOR_GREY_4;
 }
-
-}} // giada::v::
+} // namespace v
+} // namespace giada
