@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,44 +24,41 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_CHANNEL_BUTTON_H
 #define GE_CHANNEL_BUTTON_H
 
-
 #include "gui/elems/basics/button.h"
 
-
-namespace giada {
-namespace m 
-{ 
-class Channel; 
+namespace giada
+{
+namespace c
+{
+namespace channel
+{
+struct Data;
 }
+} // namespace c
 namespace v
 {
 class geChannelButton : public geButton
 {
 public:
-
-	geChannelButton(int x, int y, int w, int h, ID channelId);
+	geChannelButton(int x, int y, int w, int h, const c::channel::Data& d);
 
 	virtual void refresh();
 
 	void draw() override;
-  
-	void setKey(int k);
+
 	void setPlayMode();
 	void setEndingMode();
-	void setDefaultMode(const char* l=0);
+	void setDefaultMode(const char* l = 0);
 	void setInputRecordMode();
 	void setActionRecordMode();
 
-protected:
-
-	ID          m_channelId;
-	std::string m_key;
+  protected:
+	const c::channel::Data& m_channel;
 };
-}} // giada::v::
-
+} // namespace v
+} // namespace giada
 
 #endif
