@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,91 +24,81 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cassert>
-#include <FL/fl_draw.H>
-#include <FL/Fl_Menu_Button.H>
-#include "core/channels/sampleChannel.h"
-#include "core/channels/midiChannel.h"
+#include "column.h"
 #include "core/model/model.h"
 #include "glue/channel.h"
-#include "utils/log.h"
-#include "utils/fs.h"
-#include "utils/string.h"
 #include "gui/dialogs/warnings.h"
 #include "gui/elems/basics/boxtypes.h"
 #include "gui/elems/basics/resizerBar.h"
 #include "keyboard.h"
-#include "sampleChannel.h"
 #include "midiChannel.h"
-#include "column.h"
+#include "sampleChannel.h"
+#include "utils/fs.h"
+#include "utils/gui.h"
+#include "utils/log.h"
+#include "utils/string.h"
+#include <FL/Fl_Menu_Button.H>
+#include <FL/fl_draw.H>
+#include <cassert>
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
 geColumn::geColumn(int X, int Y, int W, int H, ID id, geResizerBar* b)
-: Fl_Group  (X, Y, W, H), 
-  id        (id),
-  resizerBar(b)
+: Fl_Group(X, Y, W, H)
+, id(id)
+, resizerBar(b)
 {
 	end();
 	init();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geColumn::refresh()
 {
 	for (geChannel* c : m_channels)
 		c->refresh();
 }
 
+/* -------------------------------------------------------------------------- */
+
+void geColumn::cb_addChannel(Fl_Widget* /*w*/, void* p) { ((geColumn*)p)->cb_addChannel(); }
 
 /* -------------------------------------------------------------------------- */
 
-
-void geColumn::cb_addChannel(Fl_Widget* v, void* p) { ((geColumn*)p)->cb_addChannel(); }
-
-
-/* -------------------------------------------------------------------------- */
-
-
-geChannel* geColumn::addChannel(ID channelId, ChannelType t, int height)
+geChannel* geColumn::addChannel(c::channel::Data d)
 {
 	geChannel* gch  = nullptr;
 	Fl_Widget* last = m_channels.size() == 0 ? static_cast<Fl_Widget*>(m_addChannelBtn) : m_channels.back();
 
-	if (t == ChannelType::SAMPLE)
-		gch = new geSampleChannel(x(), last->y() + last->h() + G_GUI_INNER_MARGIN, w(), height, channelId);
+	if (d.type == ChannelType::SAMPLE)
+		gch = new geSampleChannel(x(), last->y() + last->h() + G_GUI_INNER_MARGIN, w(), d.height, d);
 	else
-		gch = new geMidiChannel  (x(), last->y() + last->h() + G_GUI_INNER_MARGIN, w(), height, channelId);
+		gch = new geMidiChannel(x(), last->y() + last->h() + G_GUI_INNER_MARGIN, w(), d.height, d);
 
-	geResizerBar* bar = new geResizerBar(x(), gch->y() + gch->h(), w(), 
-		G_GUI_INNER_MARGIN, G_GUI_UNIT, geResizerBar::VERTICAL, gch);
+	geResizerBar* bar = new geResizerBar(x(), gch->y() + gch->h(), w(),
+	    G_GUI_INNER_MARGIN, G_GUI_UNIT, geResizerBar::Direction::VERTICAL,
+	    geResizerBar::Mode::MOVE);
 
 	/* Update the column height while dragging the resizer bar. */
 
-	bar->onDrag = [=](const Fl_Widget* w)
-	{
-		resizable(nullptr);	
+	bar->onDrag = [this](const Fl_Widget& /*w*/) {
+		resizable(nullptr);
 		size(this->w(), (child(children() - 1)->y() - y()) + G_GUI_INNER_MARGIN);
-	};	
+	};
 
 	/* Store the channel height in model when the resizer bar is released. */
 
-	bar->onRelease = [=](const Fl_Widget* w)
-	{
-		storeChannelHeight(w, channelId);
+	bar->onRelease = [channelId = d.id, this](const Fl_Widget& w) {
+		resizable(this);
+		c::channel::setHeight(channelId, w.h());
 	};
 
 	m_channels.push_back(gch);
 
 	/* Temporarily disable the resizability, add new stuff, resize the group and 
 	bring the resizability back. This is needed to prevent weird vertical 
-	stretching on existing content. */ 
+	stretching on existing content. */
 
 	resizable(nullptr);
 	add(gch);
@@ -120,20 +110,17 @@ geChannel* geColumn::addChannel(ID channelId, ChannelType t, int height)
 	return gch;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geColumn::cb_addChannel()
 {
 	u::log::print("[geColumn::cb_addChannel] id = %d\n", id);
 
 	Fl_Menu_Item menu[] = {
-		{"Add Sample channel"},
-		{"Add MIDI channel"},
-		{"Remove"},
-		{0}
-	};
+	    u::gui::makeMenuItem("Add Sample channel"),
+	    u::gui::makeMenuItem("Add MIDI channel"),
+	    u::gui::makeMenuItem("Remove"),
+	    {}};
 
 	if (countChannels() > 0)
 		menu[2].deactivate();
@@ -145,34 +132,29 @@ void geColumn::cb_addChannel()
 	b.color(G_COLOR_GREY_2);
 
 	const Fl_Menu_Item* m = menu->popup(Fl::event_x(), Fl::event_y(), 0, 0, &b);
-	if (m == nullptr) return;
+	if (m == nullptr)
+		return;
 
 	if (strcmp(m->label(), "Add Sample channel") == 0)
 		c::channel::addChannel(id, ChannelType::SAMPLE);
-	else
-	if (strcmp(m->label(), "Add MIDI channel") == 0)
+	else if (strcmp(m->label(), "Add MIDI channel") == 0)
 		c::channel::addChannel(id, ChannelType::MIDI);
 	else
 		static_cast<geKeyboard*>(parent())->deleteColumn(id);
-		
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 geChannel* geColumn::getChannel(ID channelId) const
 {
 	for (geChannel* c : m_channels)
-		if (c->channelId == channelId)
+		if (c->getData().id == channelId)
 			return c;
 	return nullptr;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geColumn::init()
 {
 	Fl_Group::clear();
@@ -184,29 +166,23 @@ void geColumn::init()
 	add(m_addChannelBtn);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geColumn::forEachChannel(std::function<void(geChannel& c)> f) const
 {
 	for (geChannel* c : m_channels)
 		f(*c);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 int geColumn::countChannels() const
 {
 	return m_channels.size();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 int geColumn::computeHeight() const
 {
 	int out = 0;
@@ -214,17 +190,4 @@ int geColumn::computeHeight() const
 		out += c->h() + G_GUI_INNER_MARGIN;
 	return out + m_addChannelBtn->h() + G_GUI_INNER_MARGIN;
 }
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void geColumn::storeChannelHeight(const Fl_Widget* w, ID channelId) const
-{	
-	m::model::onSwap(m::model::channels, channelId, [&](m::Channel& c)
-	{	
-		c.height = w->h();
-	});
-}
-
-}} // giada::v::
+} // namespace giada::v
\ No newline at end of file
