@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,54 +24,39 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cassert>
-#include <FL/fl_draw.H>
-#include "core/model/model.h"
-#include "core/channels/sampleChannel.h"
-#include "glue/io.h"
+#include "keyboard.h"
+#include "channelButton.h"
+#include "column.h"
 #include "glue/channel.h"
-#include "utils/fs.h"
-#include "utils/log.h"
-#include "utils/vector.h"
-#include "utils/string.h"
-#include "gui/dispatcher.h"
+#include "glue/io.h"
 #include "gui/dialogs/warnings.h"
+#include "gui/dispatcher.h"
 #include "gui/elems/basics/boxtypes.h"
 #include "gui/elems/basics/resizerBar.h"
-#include "column.h"
+#include "gui/ui.h"
 #include "sampleChannel.h"
-#include "channelButton.h"
-#include "keyboard.h"
+#include "utils/fs.h"
+#include "utils/log.h"
+#include "utils/string.h"
+#include "utils/vector.h"
+#include <FL/fl_draw.H>
+#include <cassert>
 
+extern giada::v::Ui g_ui;
 
-namespace giada {
-namespace v
+namespace giada::v
 {
 geKeyboard::geKeyboard(int X, int Y, int W, int H)
-: Fl_Scroll     (X, Y, W, H),
-  m_addColumnBtn(nullptr)
+: geScroll(X, Y, W, H, Fl_Scroll::BOTH_ALWAYS)
+, m_addColumnBtn(nullptr)
 {
 	end();
-
-	color(G_COLOR_GREY_1);
-	type(Fl_Scroll::BOTH_ALWAYS);
-	scrollbar.color(G_COLOR_GREY_2);
-	scrollbar.selection_color(G_COLOR_GREY_4);
-	scrollbar.labelcolor(G_COLOR_LIGHT_1);
-	scrollbar.slider(G_CUSTOM_BORDER_BOX);
-	hscrollbar.color(G_COLOR_GREY_2);
-	hscrollbar.selection_color(G_COLOR_GREY_4);
-	hscrollbar.labelcolor(G_COLOR_LIGHT_1);
-	hscrollbar.slider(G_CUSTOM_BORDER_BOX);
-
 	init();
+	rebuild();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geKeyboard::init()
 {
 	m_columnId = m::IdManager();
@@ -89,109 +74,95 @@ void geKeyboard::init()
 	layout.push_back({6, G_DEFAULT_COLUMN_WIDTH});
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geKeyboard::rebuild()
 {
 	/* Wipe out all columns and add them according to the current layout. */
 
 	deleteAllColumns();
-	
+
 	for (ColumnLayout c : layout)
 		addColumn(c.width, c.id);
 
-	/* Parse the model and assign each channel to its column. */
+	for (const c::channel::Data& ch : c::channel::getChannels())
+		getColumn(ch.columnId)->addChannel(ch);
 
-	m::model::ChannelsLock lock(m::model::channels);
-
-	for (const m::Channel* ch : m::model::channels)
-		if (!ch->isInternal())
-			getColumn(ch->columnId)->addChannel(ch->id, ch->type, ch->height);
-	
 	redraw();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geKeyboard::deleteColumn(ID id)
 {
 	u::vector::removeIf(layout, [=](const ColumnLayout& c) { return c.id == id; });
 	rebuild();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geKeyboard::deleteAllColumns()
 {
 	Fl_Scroll::clear();
 	m_columns.clear();
 
 	m_addColumnBtn = new geButton(8, y(), 200, 20, "Add new column");
-	m_addColumnBtn->callback(cb_addColumn, (void*) this);
+	m_addColumnBtn->callback(cb_addColumn, (void*)this);
 	add(m_addColumnBtn);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void geKeyboard::cb_addColumn(Fl_Widget* v, void* p)
+void geKeyboard::cb_addColumn(Fl_Widget* /*w*/, void* p)
 {
 	((geKeyboard*)p)->cb_addColumn();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geKeyboard::refresh()
 {
 	for (geColumn* c : m_columns)
 		c->refresh();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 int geKeyboard::handle(int e)
 {
-	switch (e) {
-		case FL_FOCUS:
-		case FL_UNFOCUS: {
-			return 1;               // Enables receiving Keyboard events
-		}
-		case FL_SHORTCUT:           // In case widget that isn't ours has focus
-		case FL_KEYDOWN:            // Keyboard key pushed
-		case FL_KEYUP: {            // Keyboard key released
-			dispatcher::dispatchKey(e);
-			return 1;
-		}
-		case FL_DND_ENTER:          // return(1) for these events to 'accept' dnd
-		case FL_DND_DRAG:
-		case FL_DND_RELEASE: {
-			return 1;
-		}
-		case FL_PASTE: {            // handle actual drop (paste) operation
-			const geColumn* c = getColumnAtCursor(Fl::event_x());
-			if (c != nullptr)
-				c::channel::addAndLoadChannels(c->id, getDroppedFilePaths());
-			return 1;
-		}
+	switch (e)
+	{
+	case FL_FOCUS:
+	case FL_UNFOCUS:
+	{
+		return 1; // Enables receiving Keyboard events
 	}
-	return Fl_Group::handle(e);     // Assume the buttons won't handle the Keyboard events
+	case FL_SHORTCUT: // In case widget that isn't ours has focus
+	case FL_KEYDOWN:  // Keyboard key pushed
+	case FL_KEYUP:
+	{ // Keyboard key released
+		g_ui.dispatcher.dispatchKey(e);
+		return 1;
+	}
+	case FL_DND_ENTER: // return(1) for these events to 'accept' dnd
+	case FL_DND_DRAG:
+	case FL_DND_RELEASE:
+	{
+		return 1;
+	}
+	case FL_PASTE:
+	{ // handle actual drop (paste) operation
+		const geColumn* c = getColumnAtCursor(Fl::event_x());
+		if (c != nullptr)
+			c::channel::addAndLoadChannels(c->id, getDroppedFilePaths());
+		return 1;
+	}
+	}
+	return Fl_Group::handle(e); // Assume the buttons won't handle the Keyboard events
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geKeyboard::draw()
 {
 	Fl_Scroll::draw();
@@ -201,10 +172,10 @@ void geKeyboard::draw()
 	fl_color(G_COLOR_GREY_1_5);
 
 	fl_push_clip(
-		x(), 
-		y(), 
-		w() - scrollbar_size() - (G_GUI_OUTER_MARGIN * 2), 
-		h() - scrollbar_size() - (G_GUI_OUTER_MARGIN * 2));
+	    x(),
+	    y(),
+	    w() - scrollbar_size() - (G_GUI_OUTER_MARGIN * 2),
+	    h() - scrollbar_size() - (G_GUI_OUTER_MARGIN * 2));
 
 	for (const geColumn* c : m_columns)
 		fl_rectf(c->x(), c->y() + c->h(), c->w(), h() + yposition());
@@ -212,23 +183,19 @@ void geKeyboard::draw()
 	fl_pop_clip();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geKeyboard::cb_addColumn()
 {
 	addColumn();
 	storeLayout();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geKeyboard::addColumn(int width, ID id)
 {
-	int colx = x() - xposition();  // Mind the x-scroll offset with xposition()
+	int colx = x() - xposition(); // Mind the x-scroll offset with xposition()
 
 	/* If this is not the first column... */
 
@@ -241,13 +208,12 @@ void geKeyboard::addColumn(int width, ID id)
 
 	/* Add a new column + a new resizer bar. */
 
-	geResizerBar* bar    = new geResizerBar(colx + width, y(), COLUMN_GAP, h(), G_MIN_COLUMN_WIDTH, geResizerBar::HORIZONTAL);
-	geColumn*     column = new geColumn(colx, y(), width, G_GUI_UNIT, m_columnId.get(id), bar);
+	geResizerBar* bar    = new geResizerBar(colx + width, y(), COLUMN_GAP, h(), G_MIN_COLUMN_WIDTH, geResizerBar::Direction::HORIZONTAL);
+	geColumn*     column = new geColumn(colx, y(), width, G_GUI_UNIT, m_columnId.generate(id), bar);
 
 	/* Store the column width in layout when the resizer bar is released. */
 
-	bar->onRelease = [=](const Fl_Widget* w)
-	{
+	bar->onRelease = [=](const Fl_Widget& /*w*/) {
 		storeLayout();
 	};
 
@@ -262,37 +228,31 @@ void geKeyboard::addColumn(int width, ID id)
 	redraw();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geKeyboard::forEachChannel(std::function<void(geChannel& c)> f) const
 {
-	for (geColumn* column : m_columns) 
+	for (geColumn* column : m_columns)
 		column->forEachChannel(f);
 }
 
-
 void geKeyboard::forEachColumn(std::function<void(const geColumn& c)> f) const
 {
-	for (geColumn* column : m_columns) 
+	for (geColumn* column : m_columns)
 		f(*column);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 geColumn* geKeyboard::getColumn(ID id)
 {
-	for (geColumn* c : m_columns) 
+	for (geColumn* c : m_columns)
 		if (c->id == id)
 			return c;
 	assert(false);
 	return nullptr;
 }
 
-
 geColumn* geKeyboard::getColumnAtCursor(Pixel px)
 {
 	px += xposition();
@@ -302,42 +262,37 @@ geColumn* geKeyboard::getColumnAtCursor(Pixel px)
 	return nullptr;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 geChannel* geKeyboard::getChannel(ID channelId)
 {
-	for (geColumn* column : m_columns) {
+	for (geColumn* column : m_columns)
+	{
 		geChannel* c = column->getChannel(channelId);
-		if (c != nullptr) 
+		if (c != nullptr)
 			return c;
 	}
 	assert(false);
 	return nullptr;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 std::vector<std::string> geKeyboard::getDroppedFilePaths() const
-{			
+{
 	std::vector<std::string> paths = u::string::split(Fl::event_text(), "\n");
-		for (std::string& p : paths)
-			p = u::fs::stripFileUrl(p);
+	for (std::string& p : paths)
+		p = u::fs::stripFileUrl(p);
 	return paths;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geKeyboard::storeLayout()
 {
 	layout.clear();
 	for (const geColumn* c : m_columns)
-		layout.push_back({ c->id, c->w() });
+		layout.push_back({c->id, c->w()});
 }
 
-}} // giada::v::
+} // namespace giada::v
\ No newline at end of file
