@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,42 +24,34 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_KEYBOARD_H
 #define GE_KEYBOARD_H
 
-
-#include <vector>
-#include <FL/Fl_Scroll.H>
-#include "core/channels/channel.h"
-#include "core/idManager.h"
 #include "core/const.h"
-
+#include "core/idManager.h"
+#include "gui/elems/basics/scroll.h"
+#include <functional>
+#include <vector>
 
 class geButton;
-class geResizerBar;
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
+class geResizerBar;
 class geColumn;
 class geChannel;
-class geSampleChannel;
-
-class geKeyboard : public Fl_Scroll
+class geKeyboard : public geScroll
 {
 public:
-
 	struct ColumnLayout
 	{
-		ID id;
+		ID  id;
 		int width;
 	};
 
 	geKeyboard(int X, int Y, int W, int H);
 
-	int handle(int e) override;
+	int  handle(int e) override;
 	void draw() override;
 
 	/* rebuild
@@ -74,7 +66,7 @@ public:
 
 	/* deleteColumn
 	Deletes column by id. */
-	
+
 	void deleteColumn(ID id);
 
 	/* deleteAllColumns
@@ -96,18 +88,17 @@ public:
 	void forEachColumn(std::function<void(const geColumn& c)> f) const;
 
 	/* layout
-	The column layout. Each element is a column with a specific witdh. */
+	The column layout. Each element is a column with a specific width. */
 
 	std::vector<ColumnLayout> layout;
 
 private:
-
 	static constexpr int COLUMN_GAP = 20;
 
-	static void cb_addColumn(Fl_Widget* v, void* p);
-	void cb_addColumn();
+	static void cb_addColumn(Fl_Widget* /*w*/, void* p);
+	void        cb_addColumn();
 
-	void addColumn(int width=G_DEFAULT_COLUMN_WIDTH, ID id=0);
+	void addColumn(int width = G_DEFAULT_COLUMN_WIDTH, ID id = 0);
 
 	/* getDroppedFilePaths
 	Returns a vector of audio file paths after a drag-n-drop from desktop
@@ -127,15 +118,14 @@ private:
 
 	/* storeLayout
 	Stores the current column layout into the layout vector. */
-	
+
 	void storeLayout();
 
-	m::IdManager m_columnId;
+	m::IdManager           m_columnId;
 	std::vector<geColumn*> m_columns;
 
 	geButton* m_addColumnBtn;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
