@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,38 +24,32 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_MIDI_CHANNEL_H
 #define GE_MIDI_CHANNEL_H
 
-
 #include "channel.h"
 #include "channelButton.h"
 
-
-namespace giada {
-namespace m
+namespace giada
 {
-class MidiChannel;
-}
 namespace v
 {
 class geMidiChannel : public geChannel
 {
 public:
+	geMidiChannel(int x, int y, int w, int h, c::channel::Data d);
 
-    geMidiChannel(int x, int y, int w, int h, ID channelId);
+	void resize(int x, int y, int w, int h) override;
 
-    void resize(int x, int y, int w, int h) override;
+  private:
+	static void cb_playButton(Fl_Widget* /*w*/, void* p);
+	static void cb_openMenu(Fl_Widget* /*w*/, void* p);
+	void        cb_playButton();
+	void        cb_openMenu();
 
-private:
-
-	static void cb_playButton(Fl_Widget* v, void* p);
-	static void cb_openMenu(Fl_Widget* v, void* p);
-	void cb_playButton();
-	void cb_openMenu();
+	c::channel::Data m_data;
 };
-}} // giada::v::
-
+} // namespace v
+} // namespace giada
 
 #endif
