@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,31 +24,20 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_SAMPLE_CHANNEL_H
 #define GE_SAMPLE_CHANNEL_H
 
-
 #include "channel.h"
+#include "glue/channel.h"
 
-
-class geStatusButton;
-
-
-namespace giada {
-namespace m 
-{ 
-class SampleChannel; 
-}
-namespace v
+namespace giada::v
 {
+class geStatusButton;
 class geChannelMode;
-
 class geSampleChannel : public geChannel
 {
 public:
-
-	geSampleChannel(int x, int y, int w, int h, ID channelId);
+	geSampleChannel(int x, int y, int w, int h, c::channel::Data d);
 
 	void resize(int x, int y, int w, int h) override;
 	void draw() override;
@@ -59,15 +48,13 @@ public:
 	geStatusButton* readActions;
 
 private:
-
-	static void cb_playButton(Fl_Widget* v, void* p);
-	static void cb_openMenu(Fl_Widget* v, void* p);
-	static void cb_readActions(Fl_Widget* v, void* p);
-	void cb_playButton();
-	void cb_openMenu();
-	void cb_readActions();
+	static void cb_playButton(Fl_Widget* /*w*/, void* p);
+	static void cb_openMenu(Fl_Widget* /*w*/, void* p);
+	static void cb_readActions(Fl_Widget* /*w*/, void* p);
+	void        cb_playButton();
+	void        cb_openMenu();
+	void        cb_readActions();
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
