@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,69 +24,61 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_MAIN_IO_H
 #define GE_MAIN_IO_H
 
-
-#include <FL/Fl_Pack.H>
-
-
-class geSoundMeter;
-class geDial;
+#include "gui/elems/basics/button.h"
+#include "gui/elems/basics/dial.h"
+#include "gui/elems/basics/pack.h"
+#include "gui/elems/soundMeter.h"
 #ifdef WITH_VST
-class geStatusButton;
-class geButton;
+#include "gui/elems/basics/statusButton.h"
 #endif
+#include "glue/main.h"
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-class geMainIO : public Fl_Pack
+class geMainIO : public gePack
 {
 public:
-
 	geMainIO(int x, int y);
 
 	void refresh();
 	void rebuild();
 
 	void setOutVol(float v);
-	void setInVol (float v);
+	void setInVol(float v);
 #ifdef WITH_VST
 	void setMasterFxOutFull(bool v);
 	void setMasterFxInFull(bool v);
 #endif
 
 private:
-
-	static void cb_outVol     (Fl_Widget* v, void* p);
-	static void cb_inVol      (Fl_Widget* v, void* p);
+	static void cb_outVol(Fl_Widget* /*w*/, void* p);
+	static void cb_inVol(Fl_Widget* /*w*/, void* p);
+	static void cb_inToOut(Fl_Widget* /*w*/, void* p);
+	void        cb_outVol();
+	void        cb_inVol();
+	void        cb_inToOut();
 #ifdef WITH_VST
-	static void cb_masterFxOut(Fl_Widget* v, void* p);
-	static void cb_masterFxIn (Fl_Widget* v, void* p);
-	static void cb_inToOut    (Fl_Widget* v, void* p);
-#endif
-	void cb_outVol();
-	void cb_inVol();
-#ifdef WITH_VST
-	void cb_masterFxOut();
-	void cb_masterFxIn();
-	void cb_inToOut();
+	static void cb_masterFxOut(Fl_Widget* /*w*/, void* p);
+	static void cb_masterFxIn(Fl_Widget* /*w*/, void* p);
+	void        cb_masterFxOut();
+	void        cb_masterFxIn();
 #endif
 
-	geSoundMeter* outMeter;
-	geSoundMeter* inMeter;
-	geDial*       outVol;
-	geDial*       inVol;
+	c::main::IO m_io;
+
+	geSoundMeter outMeter;
+	geSoundMeter inMeter;
+	geDial       outVol;
+	geDial       inVol;
+	geButton     inToOut;
 #ifdef WITH_VST
-  geStatusButton* masterFxOut;
-  geStatusButton* masterFxIn;
-  geButton*       inToOut;
+	geStatusButton masterFxOut;
+	geStatusButton masterFxIn;
 #endif
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
