@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,39 +24,31 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_MAIN_MENU_H
 #define GE_MAIN_MENU_H
 
-
-#include <FL/Fl_Pack.H>
-
+#include "gui/elems/basics/pack.h"
 
 class geButton;
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-class geMainMenu : public Fl_Pack
+class geMainMenu : public gePack
 {
 public:
-
 	geMainMenu(int x, int y);
 
 private:
-
-	static void cb_file(Fl_Widget* v, void* p);
-	static void cb_edit(Fl_Widget* v, void* p);
-	void cb_file();
-	void cb_edit();
+	static void cb_file(Fl_Widget* /*w*/, void* p);
+	static void cb_edit(Fl_Widget* /*w*/, void* p);
+	void        cb_file();
+	void        cb_edit();
 
 	geButton* file;
 	geButton* edit;
 	geButton* config;
 	geButton* about;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
