@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,27 +24,24 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_MAIN_TIMER_H
 #define GE_MAIN_TIMER_H
 
-
-#include <FL/Fl_Group.H>
-
+#include "glue/main.h"
+#include "gui/elems/basics/button.h"
+#include "gui/elems/basics/choice.h"
+#include "gui/elems/basics/pack.h"
 
 class geButton;
-class geChoice;
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
-class geMainTimer : public Fl_Group
+class geChoice;
+class geMainTimer : public gePack
 {
 public:
-
 	geMainTimer(int x, int y);
-	
+
 	void refresh();
 	void rebuild();
 
@@ -54,30 +51,30 @@ public:
 	void setQuantizer(int q);
 
 	/* setLock
-	Locks bpm, beter and multipliers. Used during audio recordings. */
+	Locks bpm, meter and multipliers. Used during audio recordings. */
 
 	void setLock(bool v);
 
-private:
+  private:
+	static void cb_bpm(Fl_Widget* /*w*/, void* p);
+	static void cb_meter(Fl_Widget* /*w*/, void* p);
+	static void cb_quantizer(Fl_Widget* /*w*/, void* p);
+	static void cb_multiplier(Fl_Widget* /*w*/, void* p);
+	static void cb_divider(Fl_Widget* /*w*/, void* p);
+	void        cb_bpm();
+	void        cb_meter();
+	void        cb_quantizer();
+	void        cb_multiplier();
+	void        cb_divider();
 
-	static void cb_bpm       (Fl_Widget* v, void* p);
-	static void cb_meter     (Fl_Widget* v, void* p);
-	static void cb_quantizer (Fl_Widget* v, void* p);
-	static void cb_multiplier(Fl_Widget* v, void* p);
-	static void cb_divider   (Fl_Widget* v, void* p);
-	void cb_bpm();
-	void cb_meter();
-	void cb_quantizer();
-	void cb_multiplier();
-	void cb_divider();
+	c::main::Timer m_timer;
 
-	geButton* bpm;
-	geButton* meter;
-	geChoice* quantizer;
-	geButton* multiplier;
-	geButton* divider;
+	geButton m_bpm;
+	geButton m_meter;
+	geChoice m_quantizer;
+	geButton m_multiplier;
+	geButton m_divider;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
