@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,48 +24,38 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifdef WITH_VST
 
-
 #ifndef GE_PLUGIN_PARAMETER_H
 #define GE_PLUGIN_PARAMETER_H
 
-
-#include <FL/Fl_Group.H>
 #include "core/types.h"
-
+#include "glue/plugin.h"
+#include <FL/Fl_Group.H>
 
 class geBox;
 class geSlider;
 
-
-namespace giada {
-namespace v
+namespace giada::v
 {
 class gePluginParameter : public Fl_Group
 {
 public:
+	gePluginParameter(int x, int y, int w, int labelWidth, const c::plugin::Param);
 
-	gePluginParameter(int paramIndex, ID pluginId, int x, int y, int w,
-		int labelWidth);
+	void update(const c::plugin::Param& p, bool changeSlider);
 
-	void update(bool changeSlider);
+  private:
+	static void cb_setValue(Fl_Widget* /*w*/, void* p);
+	void        cb_setValue();
 
-private:
-
-	static void cb_setValue(Fl_Widget* v, void* p);
-	void cb_setValue();
-
-	ID  m_pluginId;
-	int m_paramIndex;
+	const c::plugin::Param m_param;
 
 	geBox*    m_label;
 	geSlider* m_slider;
 	geBox*    m_value;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
 
