@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,46 +24,41 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_BOOST_TOOL_H
 #define GE_BOOST_TOOL_H
 
-
 #include <FL/Fl_Pack.H>
 
-
 class geDial;
 class geInput;
 class geButton;
 class geBox;
 
-
-namespace giada {
-namespace v 
+namespace giada
+{
+namespace v
 {
 class geBoostTool : public Fl_Pack
 {
 public:
-
 	geBoostTool(int x, int y);
 
 	void rebuild();
 
-private:
-
-	static void cb_setBoost(Fl_Widget* w, void* p);
-	static void cb_setBoostNum(Fl_Widget* w, void* p);
-	static void cb_normalize(Fl_Widget* w, void* p);
-	void cb_setBoost();
-	void cb_setBoostNum();
-	void cb_normalize();
+  private:
+	static void cb_setBoost(Fl_Widget* /*w*/, void* p);
+	static void cb_setBoostNum(Fl_Widget* /*w*/, void* p);
+	static void cb_normalize(Fl_Widget* /*w*/, void* p);
+	void        cb_setBoost();
+	void        cb_setBoostNum();
+	void        cb_normalize();
 
 	geBox*    label;
 	geDial*   dial;
 	geInput*  input;
 	geButton* normalize;
 };
-}} // giada::v::
-
+} // namespace v
+} // namespace giada
 
 #endif
