@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,46 +24,42 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_RANGE_TOOL_H
 #define GE_RANGE_TOOL_H
 
+#include "core/types.h"
+#include "gui/elems/basics/box.h"
+#include "gui/elems/basics/button.h"
+#include "gui/elems/basics/input.h"
+#include "gui/elems/basics/pack.h"
 
-#include <FL/Fl_Pack.H>
-
-
-class geInput;
-class geButton;
-class geBox;
-
-
-namespace giada {
-namespace v 
+namespace giada::c::sampleEditor
 {
-class geRangeTool : public Fl_Pack
+struct Data;
+}
+namespace giada::v
+{
+class geRangeTool : public gePack
 {
 public:
+	geRangeTool(const c::sampleEditor::Data& d, int x, int y);
 
-	geRangeTool(ID channelId, ID waveId, int x, int y);
+	void rebuild(const c::sampleEditor::Data& d);
+	void update(Frame begin, Frame end);
 
-	void rebuild();
+  private:
+	static void cb_setChanPos(Fl_Widget* /*w*/, void* p);
+	static void cb_resetStartEnd(Fl_Widget* /*w*/, void* p);
+	void        cb_setChanPos();
+	void        cb_resetStartEnd();
 
-private:
+	const c::sampleEditor::Data* m_data;
 
-	static void cb_setChanPos   (Fl_Widget* w, void* p);
-	static void cb_resetStartEnd(Fl_Widget* w, void* p);
-	void cb_setChanPos();
-	void cb_resetStartEnd();
-
-	ID m_channelId;
-	ID m_waveId;
-
-	geBox*    m_label;
-	geInput*  m_begin;
-	geInput*  m_end;
-	geButton* m_reset;
+	geBox    m_label;
+	geInput  m_begin;
+	geInput  m_end;
+	geButton m_reset;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
