@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,88 +24,80 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cmath>
-#include <cstdlib>
-#include <FL/Fl_Pack.H>
-#include "core/channels/sampleChannel.h"
+#include "volumeTool.h"
 #include "core/const.h"
-#include "core/model/model.h"
-#include "glue/channel.h"
+#include "glue/events.h"
+#include "gui/dialogs/sampleEditor.h"
+#include "gui/elems/mainWindow/keyboard/channel.h"
 #include "utils/gui.h"
 #include "utils/math.h"
 #include "utils/string.h"
-#include "gui/dialogs/sampleEditor.h"
-#include "gui/elems/basics/dial.h"
-#include "gui/elems/basics/input.h"
-#include "gui/elems/basics/box.h"
-#include "gui/elems/mainWindow/keyboard/channel.h"
-#include "volumeTool.h"
+#include <FL/Fl_Pack.H>
+#include <cmath>
+#include <cstdlib>
 
-
-namespace giada {
-namespace v 
+namespace giada
 {
-geVolumeTool::geVolumeTool(ID channelId, int X, int Y)
-: Fl_Pack    (X, Y, 150, G_GUI_UNIT),
-  m_channelId(channelId)
+namespace v
 {
-	type(Fl_Pack::HORIZONTAL);
-	spacing(G_GUI_INNER_MARGIN);
+geVolumeTool::geVolumeTool(const c::sampleEditor::Data& d, int x, int y)
+: gePack(x, y, Direction::HORIZONTAL)
+, m_data(nullptr)
+, m_label(0, 0, 60, G_GUI_UNIT, "Volume", FL_ALIGN_LEFT)
+, m_dial(0, 0, G_GUI_UNIT, G_GUI_UNIT)
+, m_input(0, 0, 70, G_GUI_UNIT)
+{
+	add(&m_label);
+	add(&m_dial);
+	add(&m_input);
 
-	begin();
-		label = new geBox  (0, 0, u::gui::getStringWidth("Volume"), G_GUI_UNIT, "Volume", FL_ALIGN_RIGHT);
-		dial  = new geDial (0, 0, G_GUI_UNIT, G_GUI_UNIT);
-		input = new geInput(0, 0, 70, G_GUI_UNIT);
-	end();
+	m_dial.range(0.0f, 1.0f);
+	m_dial.callback(cb_setVolume, (void*)this);
 
-	dial->range(0.0f, 1.0f);
-	dial->callback(cb_setVolume, (void*)this);
+	m_input.callback(cb_setVolumeNum, (void*)this);
 
-	input->callback(cb_setVolumeNum, (void*)this);
+	rebuild(d);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void geVolumeTool::rebuild()
+void geVolumeTool::rebuild(const c::sampleEditor::Data& d)
 {
-	float volume;
-	m::model::onGet(m::model::channels, m_channelId, [&](m::Channel& c) { volume = c.volume; });
+	m_data = &d;
+	update(m_data->volume, /*isDial=*/false);
+}
 
+/* -------------------------------------------------------------------------- */
+
+void geVolumeTool::update(float v, bool isDial)
+{
 	std::string tmp = "-inf";
-	float dB = u::math::linearToDB(volume);
-	if (dB > -INFINITY) 
-		tmp = u::string::fToString(dB, 2);  // 2 digits
-	input->value(tmp.c_str());
-	dial->value(volume);
+	float       dB  = u::math::linearToDB(v);
+	if (dB > -INFINITY)
+		tmp = u::string::fToString(dB, 2); // 2 digits
+	m_input.value(tmp.c_str());
+	if (!isDial)
+		m_dial.value(v);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void geVolumeTool::cb_setVolume   (Fl_Widget* w, void* p) { ((geVolumeTool*)p)->cb_setVolume(); }
-void geVolumeTool::cb_setVolumeNum(Fl_Widget* w, void* p) { ((geVolumeTool*)p)->cb_setVolumeNum(); }
-
+void geVolumeTool::cb_setVolume(Fl_Widget* /*w*/, void* p) { ((geVolumeTool*)p)->cb_setVolume(); }
+void geVolumeTool::cb_setVolumeNum(Fl_Widget* /*w*/, void* p) { ((geVolumeTool*)p)->cb_setVolumeNum(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void geVolumeTool::cb_setVolume()
 {
-	c::channel::setVolume(m_channelId, dial->value(), false, true);
+	c::events::setChannelVolume(m_data->channelId, m_dial.value(), Thread::MAIN);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void geVolumeTool::cb_setVolumeNum()
 {
-	float value = pow(10, (atof(input->value()) / 20)); // linear = 10^(dB/20)
-	c::channel::setVolume(m_channelId, value, false, true);
+	c::events::setChannelVolume(m_data->channelId, u::math::dBtoLinear(atof(m_input.value())),
+	    Thread::MAIN);
 }
-
-}} // giada::v::
+} // namespace v
+} // namespace giada
