@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,44 +24,40 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_VOLUME_TOOL_H
 #define GE_VOLUME_TOOL_H
 
+#include "gui/elems/basics/box.h"
+#include "gui/elems/basics/dial.h"
+#include "gui/elems/basics/input.h"
+#include "gui/elems/basics/pack.h"
 
-#include <FL/Fl_Pack.H>
-
-
-class geDial;
-class geInput;
-class geBox;
-
-
-namespace giada {
-namespace v 
+namespace giada::c::sampleEditor
 {
-class geVolumeTool : public Fl_Pack
+struct Data;
+}
+namespace giada::v
+{
+class geVolumeTool : public gePack
 {
 public:
+	geVolumeTool(const c::sampleEditor::Data& d, int x, int y);
 
-	geVolumeTool(ID channelId, int x, int y);
+	void rebuild(const c::sampleEditor::Data& d);
+	void update(float v, bool isDial = false);
 
-	void rebuild();
-	
-private:
+  private:
+	static void cb_setVolume(Fl_Widget* /*w*/, void* p);
+	static void cb_setVolumeNum(Fl_Widget* /*w*/, void* p);
+	void        cb_setVolume();
+	void        cb_setVolumeNum();
 
-	ID m_channelId;
+	const c::sampleEditor::Data* m_data;
 
-	geBox*   label;
-	geDial*  dial;
-	geInput* input;
-
-	static void cb_setVolume   (Fl_Widget* w, void* p);
-	static void cb_setVolumeNum(Fl_Widget* w, void* p);
-	void cb_setVolume   ();
-	void cb_setVolumeNum();
+	geBox   m_label;
+	geDial  m_dial;
+	geInput m_input;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
