@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,23 +24,23 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_WAVE_TOOLS_H
 #define GE_WAVE_TOOLS_H
 
-
 #include <FL/Fl_Scroll.H>
 
+namespace giada::c::sampleEditor
+{
+struct Data;
+}
 
-namespace giada {
-namespace v 
+namespace giada::v
 {
 class geWaveform;
 class geWaveTools : public Fl_Scroll
 {
 public:
-
-	geWaveTools(ID channelId, ID waveId, int x, int y, int w, int h);
+	geWaveTools(int x, int y, int w, int h, bool gridEnabled, int gridVal);
 
 	void resize(int x, int y, int w, int h) override;
 	int  handle(int e) override;
@@ -49,7 +49,7 @@ public:
 	Updates the waveform by realloc-ing new data (i.e. when the waveform has
 	changed). */
 
-	void rebuild();
+	void rebuild(const c::sampleEditor::Data& d);
 
 	/* refresh
 	Redraws the waveform, called by the video thread. This is meant to be called
@@ -57,17 +57,16 @@ public:
 	method is smart enough to skip painting if the channel is stopped. */
 
 	void refresh();
-	
+
+	const c::sampleEditor::Data& getChannelData() const { return *m_data; }
+
 	v::geWaveform* waveform;
 
-	ID channelId;
-	ID waveId;
-
 private:
-
 	void openMenu();
-};
-}} // giada::v::
 
+	const c::sampleEditor::Data* m_data;
+};
+} // namespace giada::v
 
 #endif
