@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,31 +24,36 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_WAVEFORM_H
 #define GE_WAVEFORM_H
 
-
-#include <vector>
-#include <FL/Fl_Widget.H>
 #include "core/const.h"
+#include "core/types.h"
+#include <FL/Fl_Widget.H>
+#include <vector>
 
+namespace giada::c::sampleEditor
+{
+struct Data;
+}
 
-namespace giada {
-namespace v 
+namespace giada::v
 {
 class geWaveform : public Fl_Widget
 {
 public:
-
 #ifdef G_OS_WINDOWS
-	/* Fuck... */
-	#undef IN
-	#undef OUT
+/* Fuck... */
+#undef IN
+#undef OUT
 #endif
-	enum class Zoom	{ IN, OUT };
+	enum class Zoom
+	{
+		IN,
+		OUT
+	};
 
-	geWaveform(ID channelId, ID waveId, int x, int y, int w, int h);
+	geWaveform(int x, int y, int w, int h, bool gridEnabled, int gridVal);
 
 	void draw() override;
 	int  handle(int e) override;
@@ -62,7 +67,7 @@ public:
 	int getSelectionB() const;
 
 	bool getSnap() const;
-	int getSize() const;
+	int  getSize() const;
 
 	/* recalcPoints
 	Recomputes m_chanStart, m_chanEnd, ... */
@@ -82,7 +87,7 @@ public:
 	/* rebuild
 	Redraws the waveform. */
 
-	void rebuild();
+	void rebuild(const c::sampleEditor::Data& d);
 
 	/* setGridLevel
 	Sets a new frequency level for the grid. 0 means disabled. */
@@ -99,13 +104,12 @@ public:
 	/* setWaveId
 	Call this when the Wave ID has changed (e.g. after a reload). */
 
-	void setWaveId(ID id) { m_waveId = id; };
+	void setWaveId(ID /*id*/){/* TODO m_waveId = id;*/};
 
 private:
-
 	static const int FLAG_WIDTH  = 20;
 	static const int FLAG_HEIGHT = 20;
-	static const int BORDER      = 8;  // window border <-> widget border
+	static const int BORDER      = 8; // window border <-> widget border
 	static const int SNAPPING    = 16;
 
 	/* selection
@@ -122,18 +126,18 @@ private:
 
 	struct
 	{
-		std::vector<int> sup;   // upper part of the waveform
-		std::vector<int> inf;   // lower part of the waveform
-		int  size;  // width of the waveform to draw (in pixel)
-	} m_data;
+		std::vector<int> sup;  // upper part of the waveform
+		std::vector<int> inf;  // lower part of the waveform
+		int              size; // width of the waveform to draw (in pixel)
+	} m_waveform;
 
 	struct
 	{
-		bool snap;
-		int level;
+		bool             snap;
+		int              level;
 		std::vector<int> points;
 	} m_grid;
-	
+
 	/* mouseOnStart/end
 	Is mouse on start or end flag? */
 
@@ -151,8 +155,8 @@ private:
 
 	bool smaller() const;
 
-	int pixelToFrame(int p) const;  // TODO - move these to utils::, will be needed in actionEditor 
-	int frameToPixel(int f) const;  // TODO - move these to utils::, will be needed in actionEditor 
+	int pixelToFrame(int p) const; // TODO - move these to utils::, will be needed in actionEditor
+	int frameToPixel(int f) const; // TODO - move these to utils::, will be needed in actionEditor
 
 	/* fixSelection
 	Helper function which flattens the selection if it was made from right to left 
@@ -186,10 +190,9 @@ private:
 	Allocates memory for the picture. It's smart enough not to reallocate if 
 	datasize hasn't changed, but it can be forced otherwise. */
 
-	int alloc(int datasize, bool force=false);
+	int alloc(int datasize, bool force = false);
 
-	ID m_channelId;
-	ID m_waveId;
+	const c::sampleEditor::Data* m_data;
 
 	int   m_chanStart;
 	bool  m_chanStartLit;
@@ -203,7 +206,6 @@ private:
 	int   m_mouseX;
 	int   m_mouseY;
 };
-}} // giada::v::
-
+} // namespace giada::v
 
 #endif
