@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,52 +24,80 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cmath>
-#include <FL/fl_draw.H>
+#include "soundMeter.h"
 #include "core/const.h"
 #include "core/kernelAudio.h"
+#include "core/types.h"
+#include "gui/drawing.h"
 #include "utils/math.h"
-#include "soundMeter.h"
+#include <FL/fl_draw.H>
+#include <algorithm>
+#include <cmath>
 
+namespace giada::v
+{
+namespace
+{
+Pixel dbToPx_(float db, Pixel max)
+{
+	const float maxf = max;
+	return std::clamp(u::math::map(db, -G_MIN_DB_SCALE, 0.0f, 0.0f, maxf), 0.0f, maxf);
+}
+} // namespace
 
-namespace giada {
-namespace v
-{
-geSoundMeter::geSoundMeter(int x, int y, int w, int h, const char* l)
-: Fl_Box      (x, y, w, h, l),
-  mixerPeak   (0.0f),
-  m_dbLevelCur(0.0f),
-  m_dbLevelOld(0.0f)
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+float geSoundMeter::Meter::compute(float peak)
 {
+	/*  dBFS (full scale) calculation, plus decay of -2dB per call. */
+
+	float dbLevelCur = u::math::linearToDB(std::fabs(peak));
+
+	if (dbLevelCur < m_dbLevelOld && m_dbLevelOld > -G_MIN_DB_SCALE)
+		dbLevelCur = m_dbLevelOld - 2.0f;
+
+	m_dbLevelOld = dbLevelCur;
+
+	return dbLevelCur;
 }
 
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+geSoundMeter::geSoundMeter(int x, int y, int w, int h, const char* l)
+: Fl_Box(x, y, w, h, l)
+{
+}
 
 /* -------------------------------------------------------------------------- */
 
-
 void geSoundMeter::draw()
 {
-	fl_rect(x(), y(), w(), h(), G_COLOR_GREY_4);
+	const geompp::Rect outline(x(), y(), w(), h());
+	const geompp::Rect body(outline.reduced(1));
 
-	/* Compute peak level on 0.0 -> 1.0 scale. 1.0 is considered clip. */
+	drawRect(outline, G_COLOR_GREY_4);
 
-	bool clip = std::fabs(mixerPeak) >= 1.0f ? true : false;
+	if (!ready)
+	{
+		drawRectf(body, G_COLOR_BLUE);
+		return;
+	}
 
-	/*  dBFS (full scale) calculation, plus decay of -2dB per frame. */
+	drawRectf(body, G_COLOR_GREY_2); // Cleanup
 
-	m_dbLevelCur = u::math::linearToDB(std::fabs(mixerPeak));
+	const float dbL    = m_left.compute(peak.left);
+	const float dbR    = m_right.compute(peak.right);
+	const int   colorL = std::fabs(peak.left) > 1.0f ? G_COLOR_BLUE : G_COLOR_GREY_4;
+	const int   colorR = std::fabs(peak.right) > 1.0f ? G_COLOR_BLUE : G_COLOR_GREY_4;
 
-	if (m_dbLevelCur < m_dbLevelOld && m_dbLevelOld > -G_MIN_DB_SCALE)
-		m_dbLevelCur = m_dbLevelOld - 2.0f;
+	const geompp::Rect bodyL(body.withTrimmedBottom(h() / 2));
+	const geompp::Rect bodyR(body.withTrimmedTop(h() / 2));
 
-	m_dbLevelOld = m_dbLevelCur;
-
-	/* Paint the meter on screen. */
-
-	float pxLevel = ((w()/G_MIN_DB_SCALE) * m_dbLevelCur) + w();
-
-	fl_rectf(x()+1, y()+1, w()-2, h()-2, G_COLOR_GREY_2);
-	fl_rectf(x()+1, y()+1, (int) pxLevel, h()-2, clip || !m::kernelAudio::isReady() ? G_COLOR_RED_ALERT : G_COLOR_GREY_4);
+	drawRectf(bodyL.withW(dbToPx_(dbL, w() - 2)), colorL);
+	drawRectf(bodyR.withW(dbToPx_(dbR, w() - 2)), colorR);
 }
-}} // giada::v::
+} // namespace giada::v
\ No newline at end of file
