@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,17 +24,31 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_V_UPDATER_H
 #define G_V_UPDATER_H
 
-
-namespace giada {
-namespace v {
-namespace updater
+namespace giada::m::model
 {
-void update(void* p);
-}}} // giada::v::updater
+class Model;
+}
 
+namespace giada::v
+{
+class Ui;
+class Updater final
+{
+public:
+	Updater(Ui& ui);
+
+	void init(m::model::Model&);
+	void close();
+
+private:
+	static void update(void*);
+	void        update();
+
+	Ui& m_ui;
+};
+} // namespace giada::v
 
 #endif
\ No newline at end of file
