@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,38 +24,36 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cmath>
 #include "math.h"
+#include <cmath>
 
-
-namespace giada {
-namespace u     {
-namespace math 
+namespace giada
+{
+namespace u
+{
+namespace math
 {
 float linearToDB(float f)
 {
 	return 20 * std::log10(f);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 int quantize(int x, int step)
 {
 	/* Source:
 	https://en.wikipedia.org/wiki/Quantization_(signal_processing)#Rounding_example */
-	return step * std::floor((x / (float) step) + 0.5f);
+	return step * std::floor((x / (float)step) + 0.5f);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 float dBtoLinear(float f)
 {
-	return std::pow(10, f/20.0f); 
+	return std::pow(10, f / 20.0f);
 }
 
-}}}  // giada::u::math::
\ No newline at end of file
+} // namespace math
+} // namespace u
+} // namespace giada
\ No newline at end of file
