@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,19 +24,17 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_UTILS_MATH_H
 #define G_UTILS_MATH_H
 
+#include <cassert>
+#include <type_traits>
 
-namespace giada {
-namespace u     {
-namespace math 
+namespace giada::u::math
 {
 float linearToDB(float f);
 float dBtoLinear(float f);
-int quantize(int x, int step);
-
+int   quantize(int x, int step);
 
 /* -------------------------------------------------------------------------- */
 
@@ -47,9 +45,13 @@ Maps 'x' in range [a, b] to a new range [w, z]. Source:
 template <typename TI, typename TO>
 TO map(TI x, TI a, TI b, TO w, TO z)
 {
-	return (((x - a) / (double) (b - a)) * (z - w)) + w;
-}
+	static_assert(std::is_arithmetic_v<TI>);
+	static_assert(std::is_arithmetic_v<TO>);
 
+	if (a == b) // Prevents division by zero (undefined behavior)
+		return x;
+	return (((x - a) / (double)(b - a)) * (z - w)) + w;
+}
 
 /* map (2)
 Maps 'x' in range [0, b) to a new range [0, z]. */
@@ -57,33 +59,8 @@ Maps 'x' in range [0, b) to a new range [0, z]. */
 template <typename TI, typename TO>
 TO map(TI x, TI b, TO z)
 {
-	return (x / (double) b) * z;
+	return map(x, static_cast<TI>(0), b, static_cast<TO>(0), z);
 }
-
-
-/* -------------------------------------------------------------------------- */
-
-/* bound (1)
-Returns 'def' if 'x' is outside the range ('min', 'max'). */
-
-template <typename T>
-T bound(T x, T min, T max, T def)
-{
-    return x < min || x > max ? def : x;
-}
-
-
-/* bound (2)
-Clamps 'x' in the range ('min', 'max'). */
-
-template <typename T>
-T bound(T x, T min, T max)
-{
-    if (x < min) return min; 
-	if (x > max) return max;
-	return x;
-}
-}}}  // giada::u::math::
-
+} // namespace giada::u::math
 
 #endif
