@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,43 +26,18 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <iomanip>
-#include <cstdarg>
-#include <climits>
-#include "../core/const.h"
 #include "string.h"
+#include "core/const.h"
+#include <climits>
+#include <cstdarg>
+#include <iomanip>
 
-
-namespace giada {
-namespace u     {
-namespace string 
+namespace giada
 {
-std::string getRealPath(const std::string& path)
+namespace u
+{
+namespace string
 {
-	std::string out = "";
-
-#if defined(G_OS_LINUX) || defined(G_OS_FREEBSD) || defined(G_OS_MAC)
-
-	char *buf = realpath(path.c_str(), nullptr);
-
-#else // Windows
-
-	char *buf = _fullpath(nullptr, path.c_str(), PATH_MAX);
-
-#endif
-
-	if (buf) {
-		out = buf;
-		free(buf);
-	}
-	return out;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 /* TODO - use std::to_string() */
 
 std::string fToString(float f, int precision)
@@ -72,35 +47,30 @@ std::string fToString(float f, int precision)
 	return out.str();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 std::string trim(const std::string& s)
 {
 	std::size_t first = s.find_first_not_of(" \n\t");
 	std::size_t last  = s.find_last_not_of(" \n\t");
-	return s.substr(first, last-first+1);
+	return s.substr(first, last - first + 1);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 std::string replace(std::string in, const std::string& search, const std::string& replace)
 {
-	size_t pos = 0;
-	while ((pos = in.find(search, pos)) != std::string::npos) {
+	std::size_t pos = 0;
+	while ((pos = in.find(search, pos)) != std::string::npos)
+	{
 		in.replace(pos, search.length(), replace);
 		pos += replace.length();
 	}
 	return in;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 std::string format(const char* format, ...)
 {
 	va_list args;
@@ -109,9 +79,9 @@ std::string format(const char* format, ...)
 	into account). */
 
 	va_start(args, format);
-	size_t size = vsnprintf(nullptr, 0, format, args) + 1;
+	std::size_t size = vsnprintf(nullptr, 0, format, args) + 1;
 	va_end(args);
-	
+
 	/* Create a new temporary char array to hold the new expanded std::string. */
 
 	std::unique_ptr<char[]> tmp(new char[size]);
@@ -125,26 +95,26 @@ std::string format(const char* format, ...)
 	return std::string(tmp.get(), tmp.get() + size - 1);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 std::vector<std::string> split(std::string in, std::string sep)
 {
 	std::vector<std::string> out;
-	std::string full  = in;
-	std::string token = "";
-	size_t curr = 0;
-	size_t next = -1;
-	do {
+	std::string              full  = in;
+	std::string              token = "";
+	std::size_t              curr  = 0;
+	std::size_t              next  = -1;
+	do
+	{
 		curr  = next + 1;
 		next  = full.find_first_of(sep, curr);
 		token = full.substr(curr, next - curr);
 		if (token != "")
 			out.push_back(token);
-	}
-	while (next != std::string::npos);
+	} while (next != std::string::npos);
 	return out;
 }
 
-}}} // giada::u::string
+} // namespace string
+} // namespace u
+} // namespace giada
