@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,18 +26,20 @@
  *
  * -------------------------------------------------------------------------- */
 
-
+#include "time.h"
 #include <chrono>
 #include <thread>
-#include "time.h"
 
-
-namespace giada {
-namespace u     {
-namespace time 
+namespace giada
+{
+namespace u
+{
+namespace time
 {
 void sleep(int millisecs)
 {
 	std::this_thread::sleep_for(std::chrono::milliseconds(millisecs));
 }
-}}};  // giada::u::time::
+} // namespace time
+} // namespace u
+} // namespace giada
