@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,49 +24,66 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_UTILS_VECTOR_H
 #define G_UTILS_VECTOR_H
 
-
-#include <vector>
 #include <algorithm>
 #include <functional>
+#include <vector>
 
-
-namespace giada {
-namespace u {
-namespace vector 
+namespace giada::u::vector
 {
 template <typename T, typename P>
-size_t indexOf(T& v, const P& p)
+std::size_t indexOf(const T& v, const P& p)
 {
-	return std::distance(v.begin(), std::find(v.begin(), v.end(), p));
+	return std::distance(std::cbegin(v), std::find(std::cbegin(v), std::cend(v), p));
 }
 
-
-template <typename T, typename P>
-size_t indexOfIf(T& v, P p)
-{
-	return std::distance(v.begin(), std::find_if(v.begin(), v.end(), p));
-}
-
-
 /* -------------------------------------------------------------------------- */
 
+template <typename T, typename F>
+auto findIf(const T& v, F&& func)
+{
+	return std::find_if(std::cbegin(v), std::cend(v), func);
+}
+
+/* -------------------------------------------------------------------------- */
+
+template <typename T, typename F>
+bool has(const T& v, F&& func)
+{
+	return findIf(v, func) != std::cend(v);
+}
+
+/* -------------------------------------------------------------------------- */
 
 template <typename T, typename F>
 void removeIf(T& v, F&& func)
 {
-    v.erase(std::remove_if(v.begin(), v.end(), func), v.end());
+	v.erase(std::remove_if(v.begin(), v.end(), func), v.end());
 }
 
-
 template <typename T, typename V>
-void remove(T& v, V val)
+void remove(T& v, const V& o)
 {
-    v.erase(std::remove(v.begin(), v.end(), val), v.end());
+	v.erase(std::remove(v.begin(), v.end(), o), v.end());
 }
-}}};  // giada::u::vector::
+
+/* -------------------------------------------------------------------------- */
+
+template <typename T, typename I>
+std::vector<T> cast(const I& i)
+{
+	return {i.begin(), i.end()};
+}
+
+/* -------------------------------------------------------------------------- */
+
+template <typename Vector, typename Default>
+auto atOr(const Vector& v, int index, Default d)
+{
+	return index >= 0 && static_cast<size_t>(index) < v.size() ? v[index] : d;
+}
+} // namespace giada::u::vector
 
 #endif
