@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2021 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,21 +24,17 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "core/const.h"
-#ifdef G_OS_MAC
-	#include <RtMidi.h>
-#else
-	#include <rtmidi/RtMidi.h>
-#endif
-#include <sndfile.h>
-#include "deps/rtaudio/RtAudio.h"
 #include "ver.h"
+#include "core/const.h"
+#include "deps/rtaudio/RtAudio.h"
+#include <RtMidi.h>
+#include <sndfile.h>
 
-
-namespace giada {
-namespace u {
-namespace ver  
+namespace giada
+{
+namespace u
+{
+namespace ver
 {
 std::string getLibsndfileVersion()
 {
@@ -47,10 +43,8 @@ std::string getLibsndfileVersion()
 	return std::string(buffer);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 std::string getRtAudioVersion()
 {
 #ifdef TESTS
@@ -60,10 +54,8 @@ std::string getRtAudioVersion()
 #endif
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 std::string getRtMidiVersion()
 {
 #ifdef TESTS
@@ -72,4 +64,6 @@ std::string getRtMidiVersion()
 	return RtMidi::getVersion();
 #endif
 }
-}}};  // giada::u::ver::
+} // namespace ver
+} // namespace u
+} // namespace giada
